@@ -6,7 +6,7 @@
  * Date        : 2008-02-29
  * Description : Drag object info containers.
  *
- * SPDX-FileCopyrightText: 2008-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -16,9 +16,10 @@
 
 // Qt includes
 
+#include <QDir>
+#include <QIODevice>
 #include <QByteArray>
 #include <QDataStream>
-#include <QIODevice>
 
 // Local includes
 
@@ -58,7 +59,7 @@ DItemDrag::DItemDrag(const QList<QUrl>& urls,
 
 #ifdef Q_OS_WIN
 
-        txt.append(QString::fromUtf8("%1\r\n").arg(url.toLocalFile()));
+        txt.append(QString::fromUtf8("%1\r\n").arg(QDir::toNativeSeparators(url.toLocalFile())));
 
 #else
 
@@ -375,3 +376,5 @@ bool DCameraDragObject::decode(const QMimeData* e, CameraType& ctype)
 }
 
 } // namespace Digikam
+
+#include "moc_ddragobjects.cpp"
