@@ -6,22 +6,13 @@
  * Date        : 2009-04-16
  * Description : Qt Model for Items - drag and drop handling
  *
- * Copyright (C) 2002-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2002-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2006-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2009      by Andi Clemens <andi dot clemens at gmail dot com>
- * Copyright (C) 2013      by Michael G. Hansen <mike at mghansen dot de>
+ * SPDX-FileCopyrightText: 2002-2005 by Renchi Raju <renchi dot raju at gmail dot com>
+ * SPDX-FileCopyrightText: 2002-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2009      by Andi Clemens <andi dot clemens at gmail dot com>
+ * SPDX-FileCopyrightText: 2013      by Michael G. Hansen <mike at mghansen dot de>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -47,7 +38,6 @@
 #include "ddragobjects.h"
 #include "dio.h"
 #include "itemcategorizedview.h"
-#include "iteminfo.h"
 #include "iteminfolist.h"
 #include "tableview_treeview.h"
 #include "digikamitemview.h"
@@ -98,11 +88,31 @@ static DropAction copyOrMove(const QDropEvent* const e,
                              bool allowMove = true,
                              bool askForGrouping = false)
 {
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+    if      (e->modifiers() & Qt::ControlModifier)
+
+#else
+
     if      (e->keyboardModifiers() & Qt::ControlModifier)
+
+#endif
+
     {
         return CopyAction;
     }
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+    else if (e->modifiers() & Qt::ShiftModifier)
+
+#else
+
     else if (e->keyboardModifiers() & Qt::ShiftModifier)
+
+#endif
+
     {
         return MoveAction;
     }
@@ -215,8 +225,11 @@ static DropAction s_groupAction(const QDropEvent* const, QWidget* const view)
     QAction* sortAction                = nullptr;
 
     if (imgView &&
-        ((sortOrder == ItemSortSettings::SortByManualOrderAndName) ||
-         (sortOrder == ItemSortSettings::SortByManualOrderAndDate)))
+        (
+         (sortOrder == ItemSortSettings::SortByManualOrderAndName) ||
+         (sortOrder == ItemSortSettings::SortByManualOrderAndDate)
+        )
+       )
     {
         sortAction = addSortAction(&popMenu);
         popMenu.addSeparator();
@@ -244,8 +257,7 @@ static DropAction s_groupAction(const QDropEvent* const, QWidget* const view)
 // -------------------------------------------------------------------------------------
 
 ItemDragDropHandler::ItemDragDropHandler(ItemModel* const model)
-    : AbstractItemDragDropHandler(model),
-      m_readOnly(false)
+    : AbstractItemDragDropHandler(model)
 {
 }
 
@@ -275,7 +287,17 @@ bool ItemDragDropHandler::dropEvent(QAbstractItemView* abstractview, const QDrop
 
     if (view)
     {
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+        album = view->albumAt(e->position().toPoint());
+
+#else
+
         album = view->albumAt(e->pos());
+
+#endif
+
     }
     else
     {
@@ -283,7 +305,17 @@ bool ItemDragDropHandler::dropEvent(QAbstractItemView* abstractview, const QDrop
 
         if (tableViewTreeView)
         {
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+            album = tableViewTreeView->albumAt(e->position().toPoint());
+
+#else
+
             album = tableViewTreeView->albumAt(e->pos());
+
+#endif
+
         }
     }
 
@@ -363,7 +395,8 @@ bool ItemDragDropHandler::dropEvent(QAbstractItemView* abstractview, const QDrop
 
         if      (m_readOnly)
         {
-            emit itemInfosDropped(ItemInfoList(imageIDs));
+            Q_EMIT itemInfosDropped(ItemInfoList(imageIDs));
+
             return true;
         }
         else if (palbum)
@@ -372,11 +405,6 @@ bool ItemDragDropHandler::dropEvent(QAbstractItemView* abstractview, const QDrop
 
             QList<ItemInfo> extImages, intImages;
 
-            if (imageIDs.isEmpty())
-            {
-                return false;
-            }
-
             for (QList<qlonglong>::const_iterator it = imageIDs.constBegin() ;
                  it != imageIDs.constEnd() ; ++it)
             {
@@ -398,15 +426,29 @@ bool ItemDragDropHandler::dropEvent(QAbstractItemView* abstractview, const QDrop
 
             // Check for drop of image on itself
 
-            if ((intImages.size()  == 1) &&
-                (intImages.first() == droppedOnInfo))
+            if (
+                (intImages.size()  == 1) &&
+                (intImages.first() == droppedOnInfo)
+               )
             {
                 return false;
             }
 
-            if (onlyInternal        &&
+            if (
+                onlyInternal        &&
                 droppedOn.isValid() &&
-                (e->keyboardModifiers() == Qt::NoModifier))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+                (e->modifiers() == Qt::NoModifier)
+
+#else
+
+                (e->keyboardModifiers() == Qt::NoModifier)
+
+#endif
+               )
+
             {
                 action = s_groupAction(e, view);
             }
@@ -469,11 +511,17 @@ bool ItemDragDropHandler::dropEvent(QAbstractItemView* abstractview, const QDrop
         }
         else if (talbum)
         {
+            if (talbum->hasProperty(TagPropertyName::person()))
+            {
+                return false;
+            }
+
             action = tagAction(e, view, droppedOn.isValid());
 
             if (action == AssignTagAction)
             {
-                emit assignTags(ItemInfoList(imageIDs), QList<int>() << talbum->id());
+                Q_EMIT assignTags(ItemInfoList(imageIDs), QList<int>() << talbum->id());
+
                 return true;
             }
         }
@@ -494,7 +542,8 @@ bool ItemDragDropHandler::dropEvent(QAbstractItemView* abstractview, const QDrop
                 return false;
             }
 
-            emit addToGroup(droppedOnInfo, ItemInfoList(imageIDs));
+            Q_EMIT addToGroup(droppedOnInfo, ItemInfoList(imageIDs));
+
             return true;
         }
 
@@ -505,7 +554,8 @@ bool ItemDragDropHandler::dropEvent(QAbstractItemView* abstractview, const QDrop
                 return false;
             }
 
-            emit dragDropSort(droppedOnInfo, ItemInfoList(imageIDs));
+            Q_EMIT dragDropSort(droppedOnInfo, ItemInfoList(imageIDs));
+
             return true;
         }
 
@@ -516,8 +566,10 @@ bool ItemDragDropHandler::dropEvent(QAbstractItemView* abstractview, const QDrop
                 return false;
             }
 
-            emit addToGroup(droppedOnInfo, ItemInfoList(imageIDs));
+            Q_EMIT addToGroup(droppedOnInfo, ItemInfoList(imageIDs));
+
             DIO::move(ItemInfoList(imageIDs), palbum);
+
             return true;
         }
 
@@ -536,7 +588,8 @@ bool ItemDragDropHandler::dropEvent(QAbstractItemView* abstractview, const QDrop
 
         if (m_readOnly)
         {
-            emit urlsDropped(srcURLs);
+            Q_EMIT urlsDropped(srcURLs);
+
             return true;
         }
 
@@ -574,9 +627,11 @@ bool ItemDragDropHandler::dropEvent(QAbstractItemView* abstractview, const QDrop
 
         if (talbum && talbum->hasProperty(TagPropertyName::person()))
         {
-            if ((tagIDs.first() == FaceTags::unconfirmedPersonTagId()) ||
+            if (
+                (tagIDs.first() == FaceTags::unconfirmedPersonTagId()) ||
                 (tagIDs.first() == FaceTags::unknownPersonTagId())     ||
-                !FaceTags::isPerson(tagIDs.first()))
+                !FaceTags::isPerson(tagIDs.first())
+               )
             {
                 return false;
             }
@@ -606,8 +661,16 @@ bool ItemDragDropHandler::dropEvent(QAbstractItemView* abstractview, const QDrop
             popFaceTagMenu.addAction(QIcon::fromTheme(QLatin1String("dialog-cancel")), i18n("&Cancel"));
             popFaceTagMenu.setMouseTracking(true);
 
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+            QAction* const res = popFaceTagMenu.exec(dview->mapToGlobal(e->position().toPoint()));
+
+#else
+
             QAction* const res = popFaceTagMenu.exec(dview->mapToGlobal(e->pos()));
 
+#endif
+
             if (res)
             {
                 if      (res == assignFace)
@@ -623,7 +686,7 @@ bool ItemDragDropHandler::dropEvent(QAbstractItemView* abstractview, const QDrop
             return true;
         }
 
-        // Standart tags
+        // Standard tags
 
         QMenu popMenu(view);
 
@@ -651,17 +714,26 @@ bool ItemDragDropHandler::dropEvent(QAbstractItemView* abstractview, const QDrop
         popMenu.addAction(QIcon::fromTheme(QLatin1String("dialog-cancel")), i18n("&Cancel"));
 
         popMenu.setMouseTracking(true);
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+        QAction* const choice = popMenu.exec(view->mapToGlobal(e->position().toPoint()));
+
+#else
+
         QAction* const choice = popMenu.exec(view->mapToGlobal(e->pos()));
 
+#endif
+
         if (choice)
         {
             if      (choice == assignToSelectedAction)    // Selected Items
             {
-                emit assignTags(selectedInfos, tagIDs);
+                Q_EMIT assignTags(selectedInfos, tagIDs);
             }
             else if (choice == assignToAllAction)    // All Items
             {
-                emit assignTags(view->allItemInfos(), tagIDs);
+                Q_EMIT assignTags(view->allItemInfos(), tagIDs);
             }
             else if (choice == assignToThisAction)    // Dropped item only.
             {
@@ -673,7 +745,7 @@ bool ItemDragDropHandler::dropEvent(QAbstractItemView* abstractview, const QDrop
                     dropIndex = thumbBar->imageFilterModel()->mapToSourceItemModel(droppedOn);
                 }
 
-                emit assignTags(QList<ItemInfo>() << model()->imageInfo(dropIndex), tagIDs);
+                Q_EMIT assignTags(QList<ItemInfo>() << model()->imageInfo(dropIndex), tagIDs);
             }
         }
 
@@ -702,8 +774,17 @@ bool ItemDragDropHandler::dropEvent(QAbstractItemView* abstractview, const QDrop
         popMenu.addSeparator();
         popMenu.addAction(QIcon::fromTheme(QLatin1String("dialog-cancel")), i18n("C&ancel"));
         popMenu.setMouseTracking(true);
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+        QAction* const choice        = popMenu.exec(iconView->mapToGlobal(e->position().toPoint()));
+
+#else
+
         QAction* const choice        = popMenu.exec(iconView->mapToGlobal(e->pos()));
 
+#endif
+
         if (choice)
         {
             if      (choice == downAction)
@@ -731,11 +812,31 @@ Qt::DropAction ItemDragDropHandler::accepts(const QDropEvent* e, const QModelInd
 
     if (DItemDrag::canDecode(e->mimeData()) || e->mimeData()->hasUrls())
     {
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+        if (e->modifiers() & Qt::ControlModifier)
+
+#else
+
         if (e->keyboardModifiers() & Qt::ControlModifier)
+
+#endif
+
         {
             return Qt::CopyAction;
         }
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+        else if (e->modifiers() & Qt::ShiftModifier)
+
+#else
+
         else if (e->keyboardModifiers() & Qt::ShiftModifier)
+
+#endif
+
         {
             return Qt::MoveAction;
         }
@@ -743,9 +844,11 @@ Qt::DropAction ItemDragDropHandler::accepts(const QDropEvent* e, const QModelInd
         return Qt::MoveAction;
     }
 
-    if (DTagListDrag::canDecode(e->mimeData())        ||
+    if (
+        DTagListDrag::canDecode(e->mimeData())        ||
         DCameraItemListDrag::canDecode(e->mimeData()) ||
-        DCameraDragObject::canDecode(e->mimeData()))
+        DCameraDragObject::canDecode(e->mimeData())
+       )
     {
         return Qt::MoveAction;
     }
@@ -774,7 +877,7 @@ QMimeData* ItemDragDropHandler::createMimeData(const QList<QModelIndex>& indexes
     QList<int>       albumIDs;
     QList<qlonglong> imageIDs;
 
-    foreach (const ItemInfo& info, infos)
+    Q_FOREACH (const ItemInfo& info, infos)
     {
         urls.append(info.fileUrl());
         albumIDs.append(info.albumId());
@@ -790,3 +893,5 @@ QMimeData* ItemDragDropHandler::createMimeData(const QList<QModelIndex>& indexes
 }
 
 } // namespace Digikam
+
+#include "moc_itemdragdrop.cpp"
