@@ -263,12 +263,12 @@ void DigikamItemView::dragDropSort(const ItemInfo& pick, const QList<ItemInfo>&
     imageFilterModel()->invalidate();
  }
 
-bool DigikamItemView::allNeedGroupResolving(const ApplicationSettings::OperationType type) const
+bool DigikamItemView::allNeedGroupResolving(const OperationType type) const
 {
     return needGroupResolving(type, allItemInfos());
 }
 
-bool DigikamItemView::selectedNeedGroupResolving(const ApplicationSettings::OperationType type) const
+bool DigikamItemView::selectedNeedGroupResolving(const OperationType type) const
 {
     return needGroupResolving(type, selectedItemInfos());
 }
@@ -281,6 +281,7 @@ int DigikamItemView::fitToWidthIcons()
 void DigikamItemView::slotSetupChanged()
 {
     imageFilterModel()->setStringTypeNatural(ApplicationSettings::instance()->isStringTypeNatural());
+    setInitialSelectedItem(ApplicationSettings::instance()->getSelectFirstAlbumItem());
     setToolTipEnabled(ApplicationSettings::instance()->showToolTipsIsValid());
     setFont(ApplicationSettings::instance()->getIconViewFont());
 
@@ -297,7 +298,7 @@ bool DigikamItemView::hasHiddenGroupedImages(const ItemInfo& info) const
 }
 
 ItemInfoList DigikamItemView::imageInfos(const QList<QModelIndex>& indexes,
-                                         ApplicationSettings::OperationType type) const
+                                         OperationType type) const
 {
     ItemInfoList infos = ItemCategorizedView::imageInfos(indexes);
 
@@ -419,22 +420,25 @@ void DigikamItemView::confirmFaces(const QList<QModelIndex>& indexes, int tagId)
 
     Q_FOREACH (const QModelIndex& index, indexes)
     {
-        faces << d->faceDelegate->face(index);
-        infos << ItemModel::retrieveItemInfo(index);
-
-        if (needFastRemove)
+        if (index.isValid())
         {
-            sourceIndexes << imageSortFilterModel()->mapToSourceItemModel(index);
+            faces << d->faceDelegate->face(index);
+            infos << ItemModel::retrieveItemInfo(index);
+
+            if (needFastRemove)
+            {
+                sourceIndexes << imageSortFilterModel()->mapToSourceItemModel(index);
+            }
         }
     }
 
-    imageAlbumModel()->removeIndexes(sourceIndexes);
-
     for (int i = 0 ; i < infos.size() ; ++i)
     {
         d->editPipeline.confirm(infos[i], faces[i], tagId);
     }
 
+    imageAlbumModel()->removeIndexes(sourceIndexes);
+
     clearSelection();
 }
 
@@ -446,18 +450,21 @@ void DigikamItemView::removeFaces(const QList<QModelIndex>& indexes)
 
     Q_FOREACH (const QModelIndex& index, indexes)
     {
-        faces         << d->faceDelegate->face(index);
-        infos         << ItemModel::retrieveItemInfo(index);
-        sourceIndexes << imageSortFilterModel()->mapToSourceItemModel(index);
+        if (index.isValid())
+        {
+            faces         << d->faceDelegate->face(index);
+            infos         << ItemModel::retrieveItemInfo(index);
+            sourceIndexes << imageSortFilterModel()->mapToSourceItemModel(index);
+        }
     }
 
-    imageAlbumModel()->removeIndexes(sourceIndexes);
-
     for (int i = 0 ; i < infos.size() ; ++i)
     {
         d->editPipeline.remove(infos[i], faces[i]);
     }
 
+    imageAlbumModel()->removeIndexes(sourceIndexes);
+
     clearSelection();
 }
 
@@ -469,19 +476,22 @@ void DigikamItemView::unknownFaces(const QList<QModelIndex>& indexes)
 
     Q_FOREACH (const QModelIndex& index, indexes)
     {
-        faces         << d->faceDelegate->face(index);
-        infos         << ItemModel::retrieveItemInfo(index);
-        sourceIndexes << imageSortFilterModel()->mapToSourceItemModel(index);
+        if (index.isValid())
+        {
+            faces         << d->faceDelegate->face(index);
+            infos         << ItemModel::retrieveItemInfo(index);
+            sourceIndexes << imageSortFilterModel()->mapToSourceItemModel(index);
+        }
     }
 
-    imageAlbumModel()->removeIndexes(sourceIndexes);
-
     for (int i = 0 ; i < infos.size() ; ++i)
     {
         d->editPipeline.editTag(infos[i], faces[i],
                                 FaceTags::unknownPersonTagId());
     }
 
+    imageAlbumModel()->removeIndexes(sourceIndexes);
+
     clearSelection();
 }
 
@@ -493,13 +503,14 @@ void DigikamItemView::rejectFaces(const QList<QModelIndex>& indexes)
 
     Q_FOREACH (const QModelIndex& index, indexes)
     {
-        faces         << d->faceDelegate->face(index);
-        infos         << ItemModel::retrieveItemInfo(index);
-        sourceIndexes << imageSortFilterModel()->mapToSourceItemModel(index);
+        if (index.isValid())
+        {
+            faces         << d->faceDelegate->face(index);
+            infos         << ItemModel::retrieveItemInfo(index);
+            sourceIndexes << imageSortFilterModel()->mapToSourceItemModel(index);
+        }
     }
 
-    imageAlbumModel()->removeIndexes(sourceIndexes);
-
     for (int i = 0 ; i < infos.size() ; ++i)
     {
         if      (FaceTags::isTheUnknownPerson(faces[i].tagId()))
@@ -522,6 +533,8 @@ void DigikamItemView::rejectFaces(const QList<QModelIndex>& indexes)
         }
     }
 
+    imageAlbumModel()->removeIndexes(sourceIndexes);
+
     clearSelection();
 }
 
@@ -533,19 +546,22 @@ void DigikamItemView::ignoreFaces(const QList<QModelIndex>& indexes)
 
     Q_FOREACH (const QModelIndex& index, indexes)
     {
-        faces         << d->faceDelegate->face(index);
-        infos         << ItemModel::retrieveItemInfo(index);
-        sourceIndexes << imageSortFilterModel()->mapToSourceItemModel(index);
+        if (index.isValid())
+        {
+            faces         << d->faceDelegate->face(index);
+            infos         << ItemModel::retrieveItemInfo(index);
+            sourceIndexes << imageSortFilterModel()->mapToSourceItemModel(index);
+        }
     }
 
-    imageAlbumModel()->removeIndexes(sourceIndexes);
-
     for (int i = 0 ; i < infos.size() ; ++i)
     {
         d->editPipeline.editTag(infos[i], faces[i],
                                 FaceTags::ignoredPersonTagId());
     }
 
+    imageAlbumModel()->removeIndexes(sourceIndexes);
+
     clearSelection();
 }
 
@@ -555,7 +571,10 @@ QList<int> DigikamItemView::getFaceIds(const QList<QModelIndex>& indexes) const
 
     Q_FOREACH (const QModelIndex& index, indexes)
     {
-        ids << d->faceDelegate->face(index).tagId();
+        if (index.isValid())
+        {
+            ids << d->faceDelegate->face(index).tagId();
+        }
     }
 
     return ids;
@@ -603,6 +622,7 @@ void DigikamItemView::showContextMenuOnInfo(QContextMenuEvent* event, const Item
 void DigikamItemView::showGroupContextMenu(const QModelIndex& index, QContextMenuEvent* event)
 {
     Q_UNUSED(index);
+
     Q_EMIT signalShowGroupContextMenu(event, selectedItemInfosCurrentFirst(), imageFilterModel());
 }
 
@@ -636,7 +656,7 @@ void DigikamItemView::deleteSelectedDirectly(const ItemViewUtilities::DeleteMode
 
 void DigikamItemView::assignRating(const QList<QModelIndex>& indexes, int rating)
 {
-    ItemInfoList infos = imageInfos(indexes, ApplicationSettings::Metadata);
+    ItemInfoList infos = imageInfos(indexes, MetadataOps);
     FileActionMngr::instance()->assignRating(infos, rating);
 }
 
@@ -658,7 +678,7 @@ void DigikamItemView::rename()
 {
     ItemInfoList infos = selectedItemInfos();
 
-    if (needGroupResolving(ApplicationSettings::Rename, infos))
+    if (needGroupResolving(RenameOps, infos))
     {
         infos = resolveGrouping(infos);
     }
@@ -708,19 +728,19 @@ void DigikamItemView::rename()
 
 void DigikamItemView::slotRotateLeft(const QList<QModelIndex>& indexes)
 {
-    ItemInfoList infos = imageInfos(indexes, ApplicationSettings::Metadata);
+    ItemInfoList infos = imageInfos(indexes, MetadataOps);
     FileActionMngr::instance()->transform(infos, MetaEngineRotation::Rotate270);
 }
 
 void DigikamItemView::slotRotateRight(const QList<QModelIndex>& indexes)
 {
-    ItemInfoList infos = imageInfos(indexes, ApplicationSettings::Metadata);
+    ItemInfoList infos = imageInfos(indexes, MetadataOps);
     FileActionMngr::instance()->transform(infos, MetaEngineRotation::Rotate90);
 }
 
 void DigikamItemView::slotFullscreen(const QList<QModelIndex>& indexes)
 {
-   QList<ItemInfo> infos = imageInfos(indexes, ApplicationSettings::Slideshow);
+   QList<ItemInfo> infos = imageInfos(indexes, SlideshowOps);
 
    if (infos.isEmpty())
    {
@@ -732,8 +752,8 @@ void DigikamItemView::slotFullscreen(const QList<QModelIndex>& indexes)
    const ItemInfo& info = infos.at(0);
 
    QList<DPluginAction*> actions = DPluginLoader::instance()->
-                                      pluginActions(QLatin1String("org.kde.digikam.plugin.generic.SlideShow"),
-                                      DigikamApp::instance());
+                                   pluginActions(QLatin1String("org.kde.digikam.plugin.generic.SlideShow"),
+                                   DigikamApp::instance());
 
    if (actions.isEmpty())
    {
