@@ -52,14 +52,22 @@ DigikamApp::DigikamApp()
         ScanController::instance()->completeCollectionScanDeferFiles();
     }
 
-    if (ApplicationSettings::instance()->getShowSplashScreen() &&
-        !qApp->isSessionRestored())
+    if (
+        ApplicationSettings::instance()->getShowSplashScreen() &&
+        !qApp->isSessionRestored()
+       )
     {
         d->splashScreen = new DSplashScreen();
         d->splashScreen->show();
     }
 
-    // We need here QCoreApplication::processEvents().
+#if (KXMLGUI_VERSION >= QT_VERSION_CHECK(5, 88, 0))
+
+    setStateConfigGroup(configGroupName());
+
+#endif
+
+    // We need here QCoreApplication::processEvents() ?
 
     qApp->processEvents();
 
@@ -84,7 +92,7 @@ DigikamApp::DigikamApp()
 #ifdef HAVE_GEOLOCATION
 
     connect(GeolocationSettings::instance(), &GeolocationSettings::signalSetupGeolocation,
-            this, [=](int tab)
+            this, [this](int tab)
         {
             Setup::execGeolocation(this, tab);
         }
@@ -95,7 +103,7 @@ DigikamApp::DigikamApp()
 #endif
 
     connect(LocalizeSettings::instance(), &LocalizeSettings::signalOpenLocalizeSetup,
-            this, [=]()
+            this, [this]()
         {
             Setup::execLocalize(this);
         }
@@ -175,8 +183,10 @@ DigikamApp::DigikamApp()
 
     // Clean up database if enabled in the settings
 
-    if (ApplicationSettings::instance()->getCleanAtStart() &&
-        CollectionScanner::databaseInitialScanDone())
+    if (
+        ApplicationSettings::instance()->getCleanAtStart() &&
+        CollectionScanner::databaseInitialScanDone()
+       )
     {
         if (d->splashScreen)
         {
@@ -225,12 +235,13 @@ DigikamApp::DigikamApp()
 
     // Create BalooWrap object, because it need to register a listener
     // to update digiKam data when changes in Baloo occur
+
     BalooWrap* const baloo = BalooWrap::instance();
     Q_UNUSED(baloo);
 
 #endif // HAVE_KFILEMETADATA
 
-    setAutoSaveSettings(group, true);
+    setAutoSaveSettings(configGroupName(), true);
 
     LoadSaveThread::setInfoProvider(new DatabaseLoadSaveFileInfoProvider);
 
@@ -378,8 +389,10 @@ void DigikamApp::show()
 
     // Enable finished the collection scan as deferred process
 
-    if (settings->getScanAtStart()                  ||
-        !CollectionScanner::databaseInitialScanDone())
+    if (
+        settings->getScanAtStart()                  ||
+        !CollectionScanner::databaseInitialScanDone()
+       )
     {
         NewItemsFinder* const tool = new NewItemsFinder(NewItemsFinder::ScanDeferredFiles);
 
@@ -405,7 +418,8 @@ void DigikamApp::show()
         QString msg = i18n("ExifTool is not available in your digiKam installation or "
                            "is not working correctly. Go to the digiKam settings and "
                            "check the availability of the ExifTool binary file in "
-                           "the metadata section.");
+                           "the metadata section.\nError message: %1",
+                           parser->currentErrorString());
 
         Q_EMIT signalNotificationError(msg, DNotificationWidget::Warning);
     }
@@ -978,40 +992,58 @@ void DigikamApp::slotSetCheckedExifOrientationAction(const ItemInfo& info)
     switch (orientation)
     {
         case 1:
+        {
             d->imageSetExifOrientation1Action->setChecked(true);
             break;
+        }
 
         case 2:
+        {
             d->imageSetExifOrientation2Action->setChecked(true);
             break;
+        }
 
         case 3:
+        {
             d->imageSetExifOrientation3Action->setChecked(true);
             break;
+        }
 
         case 4:
+        {
             d->imageSetExifOrientation4Action->setChecked(true);
             break;
+        }
 
         case 5:
+        {
             d->imageSetExifOrientation5Action->setChecked(true);
             break;
+        }
 
         case 6:
+        {
             d->imageSetExifOrientation6Action->setChecked(true);
             break;
+        }
 
         case 7:
+        {
             d->imageSetExifOrientation7Action->setChecked(true);
             break;
+        }
 
         case 8:
+        {
             d->imageSetExifOrientation8Action->setChecked(true);
             break;
+        }
 
         default:
+        {
             slotResetExifOrientationActions();
             break;
+        }
     }
 }
 
@@ -1159,12 +1191,16 @@ void DigikamApp::toggleShowBar()
     {
         case StackedView::PreviewImageMode:
         case StackedView::MediaPlayerMode:
+        {
             d->showBarAction->setEnabled(true);
             break;
+        }
 
         default:
+        {
             d->showBarAction->setEnabled(false);
             break;
+        }
     }
 }
 
@@ -1203,29 +1239,39 @@ void DigikamApp::slotColorManagementOptionsChanged()
 
 DInfoInterface* DigikamApp::infoIface(DPluginAction* const ac)
 {
-    ApplicationSettings::OperationType aset = ApplicationSettings::Unspecified;
+    OperationType aset = UnspecifiedOps;
 
     switch (ac->actionCategory())
     {
         case DPluginAction::GenericExport:
         case DPluginAction::GenericImport:
-            aset = ApplicationSettings::ImportExport;
+        {
+            aset = ImportExportOps;
             break;
+        }
 
         case DPluginAction::GenericMetadata:
-            aset = ApplicationSettings::Metadata;
+        {
+            aset = MetadataOps;
             break;
+        }
 
         case DPluginAction::GenericTool:
-            aset = ApplicationSettings::Tools;
+        {
+            aset = ToolsOps;
             break;
+        }
 
         case DPluginAction::GenericView:
-            aset = ApplicationSettings::Slideshow;
+        {
+            aset = SlideshowOps;
             break;
+        }
 
         default:
+        {
             break;
+        }
     }
 
     DBInfoIface* const iface = new DBInfoIface(this, QList<QUrl>(), aset);
@@ -1233,7 +1279,7 @@ DInfoInterface* DigikamApp::infoIface(DPluginAction* const ac)
     connect(iface, SIGNAL(signalImportedImage(QUrl)),
             this, SLOT(slotImportedImagefromScanner(QUrl)));
 
-    if (aset == ApplicationSettings::Slideshow)
+    if (aset == SlideshowOps)
     {
         connect(iface, SIGNAL(signalLastItemUrl(QUrl)),
                 d->view, SLOT(slotSetCurrentUrlWhenAvailable(QUrl)));
