@@ -6,7 +6,7 @@
  * Date        : 2002-16-10
  * Description : main digiKam interface implementation - Configure
  *
- * SPDX-FileCopyrightText: 2002-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2002-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -35,6 +35,7 @@ void DigikamApp::slotSetup()
 void DigikamApp::slotSetupChanged()
 {
     // raw loading options might have changed
+
     LoadingCacheInterface::cleanCache();
 
     // TODO: clear history when location changed
@@ -89,8 +90,15 @@ void DigikamApp::slotThemeChanged()
     ApplicationSettings* const settings = ApplicationSettings::instance();
     QString theme                       = ThemeManager::instance()->currentThemeName();
 
-    if (qApp->activeWindow()                 &&
-        (settings->getCurrentTheme() != theme))
+    if (
+        qApp->activeWindow()                                      &&
+        (settings->getCurrentTheme() != theme)                    &&
+        (
+         (settings->getIconTheme() == QLatin1String(""))          ||
+         (settings->getIconTheme() == QLatin1String("breeze"))    ||
+         (settings->getIconTheme() == QLatin1String("breeze-dark"))
+        )
+       )
     {
         qApp->processEvents();
 
@@ -98,7 +106,25 @@ void DigikamApp::slotThemeChanged()
         QString iconTheme;
         QString msgText;
 
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+        if      (isRunningOnNativeKDE())
+        {
+            msgText   = i18n("We now switch to the system icon theme. The icon "
+                             "colors are automatically adjusted on a Plasma 6 "
+                             "desktop. The icon theme is available after "
+                             "a restart of digiKam.");
+
+            iconTheme = QLatin1String("");
+        }
+        else if (color.lightness() > 127)
+
+#else
+
         if (color.lightness() > 127)
+
+#endif
+
         {
             msgText   = i18n("You have chosen a bright color scheme. We switch "
                              "to a dark icon theme. The icon theme is "
