@@ -6,7 +6,7 @@
  * Date        : 2002-16-10
  * Description : main digiKam interface implementation - Internal setup
  *
- * SPDX-FileCopyrightText: 2002-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2002-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -137,9 +137,18 @@ void DigikamApp::setupActions()
     ac->addAction(QLatin1String("album_back"), d->backwardActionMenu);
     ac->setDefaultShortcut(d->backwardActionMenu, Qt::ALT | Qt::Key_Left);
 
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+    connect(d->backwardActionMenu->popupMenu(), SIGNAL(aboutToShow()),
+            this, SLOT(slotAboutToShowBackwardMenu()));
+
+#else
+
     connect(d->backwardActionMenu->menu(), SIGNAL(aboutToShow()),
             this, SLOT(slotAboutToShowBackwardMenu()));
 
+#endif
+
     connect(d->backwardActionMenu, &QAction::triggered,
             this, [this]() { d->view->slotAlbumHistoryBack(1); });
 
@@ -151,9 +160,18 @@ void DigikamApp::setupActions()
     ac->addAction(QLatin1String("album_forward"), d->forwardActionMenu);
     ac->setDefaultShortcut(d->forwardActionMenu, Qt::ALT | Qt::Key_Right);
 
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+    connect(d->forwardActionMenu->popupMenu(), SIGNAL(aboutToShow()),
+            this, SLOT(slotAboutToShowForwardMenu()));
+
+#else
+
     connect(d->forwardActionMenu->menu(), SIGNAL(aboutToShow()),
             this, SLOT(slotAboutToShowForwardMenu()));
 
+#endif
+
     connect(d->forwardActionMenu, &QAction::triggered,
             this, [this]() { d->view->slotAlbumHistoryForward(1); });
 
@@ -320,7 +338,7 @@ void DigikamApp::setupActions()
     connect(d->imagePreviewAction, SIGNAL(triggered()), d->view, SLOT(slotImagePreview()));
     d->imageViewSelectionAction->addAction(d->imagePreviewAction);
 
-#ifdef HAVE_MARBLE
+#ifdef HAVE_GEOLOCATION
 
     d->imageMapViewAction = new QAction(QIcon::fromTheme(QLatin1String("globe")),
                                         i18nc("@action: Switch to map view", "Map"), this);
@@ -329,7 +347,7 @@ void DigikamApp::setupActions()
     connect(d->imageMapViewAction, SIGNAL(triggered()), d->view, SLOT(slotMapWidgetView()));
     d->imageViewSelectionAction->addAction(d->imageMapViewAction);
 
-#endif // HAVE_MARBLE
+#endif // HAVE_GEOLOCATION
 
     d->imageTableViewAction = new QAction(QIcon::fromTheme(QLatin1String("view-list-details")),
                                           i18nc("@action: Switch to table view", "Table"), this);
@@ -514,7 +532,7 @@ void DigikamApp::setupActions()
     d->albumSortAction = new KSelectAction(i18nc("@action: setup", "&Sort Albums"), this);
     d->albumSortAction->setWhatsThis(i18nc("@info: setup", "Sort Albums in tree-view."));
 
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
 
     connect(d->albumSortAction, SIGNAL(indexTriggered(int)),
             d->view, SLOT(slotSortAlbums(int)));
