@@ -35,8 +35,8 @@ ItemIconView::ItemIconView(QWidget* const parent, DModelFactory* const modelColl
     d->tagModificationHelper    = new TagModificationHelper(this, this);
     d->searchModificationHelper = new SearchModificationHelper(this, this);
 
-    const int spacing           = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
-                                       QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
+    const int spacing           = layoutSpacing();
+
 
     d->splitter    = new SidebarSplitter;
     d->splitter->setFrameStyle(QFrame::NoFrame | QFrame::Plain);
@@ -250,7 +250,9 @@ void ItemIconView::applySettings()
         sidebarWidget->applySettings();
     }
 
-    d->iconView->imageFilterModel()->setVersionItemFilterSettings(VersionItemFilterSettings(ApplicationSettings::instance()->getVersionManagerSettings()));
+    d->iconView->imageFilterModel()->setVersionItemFilterSettings(
+        VersionItemFilterSettings(
+            ApplicationSettings::instance()->getVersionManagerSettings()));
 
     refreshView();
 }
