@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_CHANNEL_MIXER_PLUGIN_H
-#define DIGIKAM_CHANNEL_MIXER_PLUGIN_H
+#pragma once
 
 // Local includes
 
@@ -35,7 +34,7 @@ class ChannelMixerPlugin : public DPluginBqm
 public:
 
     explicit ChannelMixerPlugin(QObject* const parent = nullptr);
-    ~ChannelMixerPlugin()                override;
+    ~ChannelMixerPlugin()                override = default;
 
     QString name()                 const override;
     QString iid()                  const override;
@@ -51,5 +50,3 @@ public:
 };
 
 } // namespace DigikamBqmChannelMixerPlugin
-
-#endif // DIGIKAM_CHANNEL_MIXER_PLUGIN_H
