@@ -58,12 +58,6 @@ namespace DigikamPNGDImgPlugin
 
 DImgPNGLoader::DImgPNGLoader(DImg* const image)
     : DImgLoader(image)
-{
-    m_hasAlpha   = false;
-    m_sixteenBit = false;
-}
-
-DImgPNGLoader::~DImgPNGLoader()
 {
 }
 
