@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_EDITOR_CHANNEL_MIXER_TOOL_H
-#define DIGIKAM_EDITOR_CHANNEL_MIXER_TOOL_H
+#pragma once
 
 // Local includes
 
@@ -54,9 +53,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamEditorChannelMixerToolPlugin
-
-#endif // DIGIKAM_EDITOR_CHANNEL_MIXER_TOOL_H
