@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_META_DATA_EDIT_PAGE_H
-#define DIGIKAM_META_DATA_EDIT_PAGE_H
+#pragma once
 
 // Qt includes
 
@@ -30,9 +29,7 @@ class MetadataEditPage : public QScrollArea
 public:
 
     explicit MetadataEditPage(QWidget* const parent);
-    ~MetadataEditPage() override;
+    ~MetadataEditPage() override = default;
 };
 
 } // namespace DigikamGenericMetadataEditPlugin
-
-#endif // DIGIKAM_META_DATA_EDIT_PAGE_H
