@@ -29,6 +29,7 @@
 
 // Local includes
 
+#include "digikam_globals.h"
 #include "squeezedcombobox.h"
 #include "metadatacheckbox.h"
 
@@ -41,27 +42,19 @@ class Q_DECL_HIDDEN MultiValuesEdit::Private
 {
 public:
 
-    explicit Private()
-      : addValueButton(nullptr),
-        delValueButton(nullptr),
-        repValueButton(nullptr),
-        valueBox      (nullptr),
-        valueCheck    (nullptr),
-        dataList      (nullptr)
-    {
-    }
+    Private() = default;
 
     QStringList       oldValues;
 
-    QPushButton*      addValueButton;
-    QPushButton*      delValueButton;
-    QPushButton*      repValueButton;
+    QPushButton*      addValueButton    = nullptr;
+    QPushButton*      delValueButton    = nullptr;
+    QPushButton*      repValueButton    = nullptr;
 
-    QListWidget*      valueBox;
+    QListWidget*      valueBox          = nullptr;
 
-    MetadataCheckBox* valueCheck;
+    MetadataCheckBox* valueCheck        = nullptr;
 
-    SqueezedComboBox* dataList;
+    SqueezedComboBox* dataList          = nullptr;
 };
 
 MultiValuesEdit::MultiValuesEdit(QWidget* const parent, const QString& title, const QString& desc)
@@ -107,8 +100,7 @@ MultiValuesEdit::MultiValuesEdit(QWidget* const parent, const QString& title, co
     grid->setColumnStretch(0, 10);
     grid->setColumnStretch(4, 100);
     grid->setContentsMargins(QMargins());
-    grid->setSpacing(qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
-                             QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing)));
+    grid->setSpacing(layoutSpacing());
 
     // --------------------------------------------------------
 
