@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_XMP_KEYWORDS_H
-#define DIGIKAM_XMP_KEYWORDS_H
+#pragma once
 
 // Qt includes
 
@@ -55,9 +54,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamGenericMetadataEditPlugin
-
-#endif // DIGIKAM_XMP_KEYWORDS_H
