@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_GALLERY_NAME_HELPER_H
-#define DIGIKAM_GALLERY_NAME_HELPER_H
+#pragma once
 
 // Qt includes
 
@@ -30,8 +29,8 @@ class GalleryNameHelper
 {
 public:
 
-    explicit GalleryNameHelper();
-    ~GalleryNameHelper();
+    GalleryNameHelper()  = default;
+    ~GalleryNameHelper() = default;
 
     QString makeNameUnique(const QString& name);
 
@@ -41,5 +40,3 @@ private:
 };
 
 } // namespace DigikamGenericHtmlGalleryPlugin
-
-#endif // DIGIKAM_GALLERY_NAME_HELPER_H
