@@ -6,7 +6,7 @@
  * Date        : 2005-04-21
  * Description : slide show tool using preview of pictures.
  *
- * SPDX-FileCopyrightText: 2005-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText:      2004 by Enrico Ros <eros dot kde at email dot it>
  * SPDX-FileCopyrightText: 2019-2020 by Minh Nghia Duong <minhnghiaduong997 at gmail dot com>
  *
@@ -15,16 +15,11 @@
  * ============================================================ */
 
 #include "slideshowloader.h"
-#include "digikam_config.h"
 
 // Qt includes
 
 #include <QMimeDatabase>
 #include <QApplication>
-#include <QWheelEvent>
-#include <QMouseEvent>
-#include <QPaintEvent>
-#include <QKeyEvent>
 #include <QScreen>
 #include <QWindow>
 #include <QCursor>
@@ -55,6 +50,10 @@
 #   include "slidevideo.h"
 #endif //HAVE_MEDIAPLAYER
 
+#ifdef Q_OS_WIN
+#   include "windows.h"
+#endif
+
 using namespace Digikam;
 
 namespace DigikamGenericSlideShowPlugin
@@ -65,43 +64,26 @@ class Q_DECL_HIDDEN SlideShowLoader::Private
 
 public:
 
-    explicit Private()
-        : fileIndex         (-1),
-          screenSaverCookie (-1),
-          mouseMoveTimer    (nullptr),
-          imageView         (nullptr),
+    Private() = default;
+
+    int                    fileIndex            = -1;
+    int                    screenSaverCookie    = -1;
+
+    QTimer*                mouseMoveTimer       = nullptr;  ///< To hide cursor when not moved.
+
+    SlideImage*            imageView            = nullptr;
 
 #ifdef HAVE_MEDIAPLAYER
 
-          videoView         (nullptr),
+    SlideVideo*            videoView            = nullptr;
 
 #endif
 
-          errorView         (nullptr),
-          endView           (nullptr),
-          osd               (nullptr),
-          settings          (nullptr)
-    {
-    }
+    SlideError*            errorView            = nullptr;
+    SlideEnd*              endView              = nullptr;
+    SlideOSD*              osd                  = nullptr;
 
-    int                    fileIndex;
-    int                    screenSaverCookie;
-
-    QTimer*                mouseMoveTimer;  ///< To hide cursor when not moved.
-
-    SlideImage*            imageView;
-
-#ifdef HAVE_MEDIAPLAYER
-
-    SlideVideo*            videoView;
-
-#endif
-
-    SlideError*            errorView;
-    SlideEnd*              endView;
-    SlideOSD*              osd;
-
-    SlideShowSettings*     settings;
+    SlideShowSettings*     settings             = nullptr;
 
     QMap<QString, QString> shortcutPrefixes;
 };
@@ -254,6 +236,7 @@ void SlideShowLoader::setCurrentView(SlideShowViewMode view)
 
             setCurrentIndex(view);
             d->osd->setCurrentUrl(currentItem());
+
             break;
         }
 
@@ -269,25 +252,25 @@ void SlideShowLoader::setCurrentView(SlideShowViewMode view)
 
             setCurrentIndex(view);
             d->osd->setCurrentUrl(currentItem());
+
             break;
         }
 
-        case VideoView:
-        {
-
 #ifdef HAVE_MEDIAPLAYER
 
+        case VideoView:
+        {
             d->osd->video(true);
             d->osd->pause(false);
             setCurrentIndex(view);
             d->osd->setCurrentUrl(currentItem());
 
-#endif
-
             break;
         }
 
-        default : // EndView
+#endif
+
+        default: // EndView
         {
 
 #ifdef HAVE_MEDIAPLAYER
@@ -299,6 +282,7 @@ void SlideShowLoader::setCurrentView(SlideShowViewMode view)
 
             d->osd->pause(true);
             setCurrentIndex(view);
+
             break;
         }
     }
@@ -357,6 +341,7 @@ void SlideShowLoader::slotLoadNextItem()
                                    .name().startsWith(QLatin1String("video/")))
         {
             d->videoView->setCurrentUrl(currentItem());
+
             return;
         }
 
@@ -403,6 +388,7 @@ void SlideShowLoader::slotLoadPrevItem()
                                    .name().startsWith(QLatin1String("video/")))
         {
             d->videoView->setCurrentUrl(currentItem());
+
             return;
         }
 
@@ -477,7 +463,13 @@ void SlideShowLoader::slotVideoLoaded(bool loaded)
 {
     if (loaded)
     {
+
+#ifdef HAVE_MEDIAPLAYER
+
         setCurrentView(VideoView);
+
+#endif
+
     }
     else
     {
@@ -550,8 +542,6 @@ void SlideShowLoader::preloadNextItem()
 
 void SlideShowLoader::wheelEvent(QWheelEvent* e)
 {
-    d->osd->toolBar()->closeConfigurationDialog();
-
     if (e->angleDelta().y() < 0)
     {
         d->osd->pause(true);
@@ -574,8 +564,6 @@ void SlideShowLoader::wheelEvent(QWheelEvent* e)
 
 void SlideShowLoader::mousePressEvent(QMouseEvent* e)
 {
-    d->osd->toolBar()->closeConfigurationDialog();
-
     if      (e->button() == Qt::LeftButton)
     {
         if (d->fileIndex == -1)
@@ -613,7 +601,8 @@ void SlideShowLoader::keyPressEvent(QKeyEvent* e)
 
     if (e->key() == Qt::Key_F4)
     {
-        d->osd->toggleProperties();
+        d->osd->setVisible(!d->osd->isVisible());
+
         return;
     }
 
@@ -633,6 +622,7 @@ bool SlideShowLoader::eventFilter(QObject* obj, QEvent* ev)
 #endif
 
         d->mouseMoveTimer->start();
+
         return false;
     }
 
@@ -658,19 +648,24 @@ void SlideShowLoader::slotMouseMoveTimeOut()
 
 /**
  * Inspired from Okular's presentation widget
- * TODO: Add OSX and Windows support
+ * TODO: Add OSX support
  */
 void SlideShowLoader::inhibitScreenSaver()
 {
 
-#ifdef HAVE_DBUS
+#ifdef Q_OS_WIN
+
+    SetThreadExecutionState(ES_DISPLAY_REQUIRED | ES_CONTINUOUS);
+
+#elif defined HAVE_DBUS
 
     QDBusMessage message = QDBusMessage::createMethodCall(QLatin1String("org.freedesktop.ScreenSaver"),
                                                           QLatin1String("/ScreenSaver"),
                                                           QLatin1String("org.freedesktop.ScreenSaver"),
                                                           QLatin1String("Inhibit"));
     message << QLatin1String("digiKam");
-    message << i18nc("Reason for inhibiting the screensaver activation, when the presentation mode is active", "Giving a slideshow");
+    message << i18nc("Reason for inhibiting the screensaver activation, when the presentation mode is active",
+                     "Giving a slideshow");
 
     QDBusReply<uint> reply = QDBusConnection::sessionBus().call(message);
 
@@ -686,7 +681,11 @@ void SlideShowLoader::inhibitScreenSaver()
 void SlideShowLoader::allowScreenSaver()
 {
 
-#ifdef HAVE_DBUS
+#ifdef Q_OS_WIN
+
+    SetThreadExecutionState(ES_CONTINUOUS);
+
+#elif defined HAVE_DBUS
 
     if (d->screenSaverCookie != -1)
     {
@@ -776,7 +775,8 @@ void SlideShowLoader::slotHandleShortcut(const QString& shortcut, int val)
         return;
     }
 
-    qCWarning(DIGIKAM_GENERAL_LOG) << "Shortcut is not yet supported in SlideShowLoader::slotHandleShortcut():" << shortcut;
+    qCWarning(DIGIKAM_GENERAL_LOG) << "Shortcut is not yet supported in SlideShowLoader::slotHandleShortcut():"
+                                   << shortcut;
 }
 
 void SlideShowLoader::dispatchCurrentInfoChange(const QUrl& url)
@@ -851,3 +851,5 @@ void SlideShowLoader::slotScreenSelected(int screen)
 }
 
 } // namespace DigikamGenericSlideShowPlugin
+
+#include "moc_slideshowloader.cpp"
