@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_SLIDE_SHOW_LOADER_H
-#define DIGIKAM_SLIDE_SHOW_LOADER_H
+#pragma once
 
 // Qt includes
 
@@ -122,9 +121,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamGenericSlideShowPlugin
-
-#endif // DIGIKAM_SLIDE_SHOW_LOADER_H
