@@ -6,7 +6,7 @@
  * Date        : 2014-09-18
  * Description : slideshow OSD widget
  *
- * SPDX-FileCopyrightText: 2014-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2014-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2019-2020 by Minh Nghia Duong <minhnghiaduong997 at gmail dot com>
  * SPDX-FileCopyrightText:      2021 by Phuoc Khanh Le <phuockhanhnk94 at gmail dot com>
  *
@@ -14,8 +14,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_SLIDE_OSD_PLUGIN_H
-#define DIGIKAM_SLIDE_OSD_PLUGIN_H
+#pragma once
 
 // Qt includes
 
@@ -49,7 +48,6 @@ public:
     void video(bool b);
     bool isPaused()                 const;
     bool isUnderMouse()             const;
-    void toggleProperties();
     void setLoadingReady(bool b);
 
 
@@ -69,9 +67,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace DigikamGenericSlideShowPlugin
-
-#endif // DIGIKAM_SLIDE_OSD_PLUGIN_H
