@@ -6,21 +6,13 @@
  * Date        : 2014-09-30
  * Description : a tool to export items to Piwigo web service
  *
- * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * Copyright (C) 2006      by Colin Guthrie <kde at colin dot guthr dot ie>
- * Copyright (C) 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2008      by Andrea Diamantini <adjam7 at gmail dot com>
- * Copyright (C) 2010-2014 by Frederic Coiffier <frederic dot coiffier at free dot com>
+ * SPDX-FileCopyrightText: 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
+ * SPDX-FileCopyrightText: 2006      by Colin Guthrie <kde at colin dot guthr dot ie>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008      by Andrea Diamantini <adjam7 at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2014 by Frederic Coiffier <frederic dot coiffier at free dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -42,7 +34,6 @@
 #include <QVBoxLayout>
 #include <QTextStream>
 #include <QFile>
-#include <QProgressDialog>
 #include <QApplication>
 #include <QIcon>
 #include <QMenu>
@@ -60,9 +51,10 @@
 #include "digikam_debug.h"
 #include "piwigosession.h"
 #include "piwigologindlg.h"
-#include "piwigoitem.h"
 #include "piwigotalker.h"
 #include "imagedialog.h"
+#include "ditemslist.h"
+#include "dprogresswdg.h"
 
 namespace DigikamGenericPiwigoPlugin
 {
@@ -74,44 +66,43 @@ public:
     explicit Private(PiwigoWindow* const parent,
                      DInfoInterface* const interface);
 
-    QWidget*                       widget;
+public:
 
-    QTreeWidget*                   albumView;
+    QWidget*                       widget           = nullptr;
 
-    QPushButton*                   confButton;
+    QTreeWidget*                   albumView        = nullptr;
 
-    QCheckBox*                     resizeCheckBox;
-    QSpinBox*                      widthSpinBox;
-    QSpinBox*                      heightSpinBox;
-    QSpinBox*                      qualitySpinBox;
+    QPushButton*                   confButton       = nullptr;
+    QPushButton*                   reloadButton     = nullptr;
+
+    QCheckBox*                     resizeCheckBox   = nullptr;
+    QSpinBox*                      widthSpinBox     = nullptr;
+    QSpinBox*                      heightSpinBox    = nullptr;
+    QSpinBox*                      qualitySpinBox   = nullptr;
 
     QHash<QString, PiwigoAlbum>    albumDict;
 
-    PiwigoTalker*                  talker;
-    PiwigoSession*                 pPiwigo;
-    DInfoInterface*                iface;
+    PiwigoTalker*                  talker           = nullptr;
+    PiwigoSession*                 pPiwigo          = nullptr;
+    DInfoInterface*                iface            = nullptr;
+    DItemsList*                    imageList        = nullptr;
+    DProgressWdg*                  progressBar      = nullptr;
 
-    QProgressDialog*               progressDlg;
-    unsigned int                   uploadCount;
-    unsigned int                   uploadTotal;
+    unsigned int                   uploadCount      = 0;
+    unsigned int                   uploadTotal      = 0;
     QStringList                    pUploadList;
+    QString                        currPhotoPath;
+
+    QLabel*                        userNameLbl      = nullptr;
+    QLabel*                        userName         = nullptr;
+    QLabel*                        urlLbl           = nullptr;
+    QLabel*                        url              = nullptr;
 };
 
 PiwigoWindow::Private::Private(PiwigoWindow* const parent,
                                DInfoInterface* const interface)
-    : widget        (new QWidget(parent)),
-      albumView     (nullptr),
-      confButton    (nullptr),
-      resizeCheckBox(nullptr),
-      widthSpinBox  (nullptr),
-      heightSpinBox (nullptr),
-      qualitySpinBox(nullptr),
-      talker        (nullptr),
-      pPiwigo       (nullptr),
-      iface         (interface),
-      progressDlg   (nullptr),
-      uploadCount   (0),
-      uploadTotal   (0)
+    : widget(new QWidget(parent)),
+      iface (interface)
 {
     parent->setMainWidget(widget);
     parent->setModal(false);
@@ -143,19 +134,48 @@ PiwigoWindow::Private::Private(PiwigoWindow* const parent,
 
     // ---------------------------------------------------------------------------
 
-    albumView = new QTreeWidget;
+    imageList              = new DItemsList(nullptr);
+    imageList->setObjectName(QLatin1String("Piwigo ImagesList"));
+    imageList->setIface(iface);
+    imageList->listView()->clear();
+    imageList->loadImagesFromCurrentSelection();
+
+    progressBar            = new DProgressWdg(imageList);
+    progressBar->setMaximum(0);
+    progressBar->reset();
+    imageList->appendControlButtonsWidget(progressBar);
+    QBoxLayout* const blay = imageList->setControlButtonsPlacement(DItemsList::ControlButtonsBelow);
+    blay->setStretchFactor(progressBar, 20);
+    progressBar->hide();
+
+    // ---------------------------------------------------------------------------
+
+    albumView                   = new QTreeWidget;
     QStringList labels;
-    labels << i18n("Albums");
+    labels << i18n("Remote Albums");
     albumView->setHeaderLabels(labels);
     albumView->setSortingEnabled(true);
     albumView->sortByColumn(0, Qt::AscendingOrder);
 
+    reloadButton                = new QPushButton();
+    reloadButton->setText(i18nc("reload album list", "Reload"));
+    reloadButton->setIcon(QIcon::fromTheme(QLatin1String("view-refresh")));
+    reloadButton->setToolTip(i18n("Reload album list"));
+    reloadButton->setEnabled(false);
+
     // ---------------------------------------------------------------------------
 
-    QFrame* const optionFrame = new QFrame;
-    QVBoxLayout* const vlay   = new QVBoxLayout();
+    QFrame* const optionFrame   = new QFrame;
+    QVBoxLayout* const vlay     = new QVBoxLayout();
 
-    confButton = new QPushButton;
+    userNameLbl                 = new QLabel(i18nc("piwigo account settings", "Name:"), optionFrame);
+    userName                    = new QLabel(optionFrame);
+    urlLbl                      = new QLabel(i18nc("piwigo url settings", "Url:"), optionFrame);
+    url                         = new QLabel(optionFrame);
+    url->setOpenExternalLinks(true);
+    url->setFocusPolicy(Qt::NoFocus);
+
+    confButton                  = new QPushButton;
     confButton->setText(i18n("Change Account"));
     confButton->setIcon(QIcon::fromTheme(QLatin1String("system-switch-user")));
     confButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
@@ -163,25 +183,25 @@ PiwigoWindow::Private::Private(PiwigoWindow* const parent,
     QGroupBox* const optionsBox = new QGroupBox(i18n("Options"));
     QVBoxLayout* const vlay2    = new QVBoxLayout();
 
-    resizeCheckBox           = new QCheckBox(optionsBox);
+    resizeCheckBox              = new QCheckBox(optionsBox);
     resizeCheckBox->setText(i18n("Resize photos before uploading"));
 
-    QGridLayout* const glay  = new QGridLayout;
-    QLabel* const widthLabel = new QLabel(i18n("Maximum width:"));
+    QGridLayout* const glay     = new QGridLayout;
+    QLabel* const widthLabel    = new QLabel(i18n("Maximum width:"));
 
-    widthSpinBox   = new QSpinBox;
+    widthSpinBox                = new QSpinBox;
     widthSpinBox->setRange(1,8000);
     widthSpinBox->setValue(1600);
 
     QLabel* const heightLabel   = new QLabel(i18n("Maximum height:"));
 
-    heightSpinBox  = new QSpinBox;
+    heightSpinBox               = new QSpinBox;
     heightSpinBox->setRange(1,8000);
     heightSpinBox->setValue(1600);
 
-    QLabel* const qualityLabel= new QLabel(i18n("Resized JPEG quality:"));
+    QLabel* const qualityLabel  = new QLabel(i18n("Resized JPEG quality:"));
 
-    qualitySpinBox = new QSpinBox;
+    qualitySpinBox              = new QSpinBox;
     qualitySpinBox->setRange(1,100);
     qualitySpinBox->setValue(95);
 
@@ -209,15 +229,21 @@ PiwigoWindow::Private::Private(PiwigoWindow* const parent,
 
     // ---------------------------------------------------------------------------
 
+    vlay->addWidget(logo);
+    vlay->addWidget(userNameLbl);
+    vlay->addWidget(userName);
+    vlay->addWidget(urlLbl);
+    vlay->addWidget(url);
     vlay->addWidget(confButton);
+    vlay->addWidget(albumView);
+    vlay->addWidget(reloadButton);
     vlay->addWidget(optionsBox);
 
     optionFrame->setLayout(vlay);
 
     // ---------------------------------------------------------------------------
 
-    hlay->addWidget(logo);
-    hlay->addWidget(albumView);
+    hlay->addWidget(imageList);
     hlay->addWidget(optionFrame);
 
     widget->setLayout(hlay);
@@ -228,16 +254,16 @@ PiwigoWindow::Private::Private(PiwigoWindow* const parent,
 PiwigoWindow::PiwigoWindow(DInfoInterface* const iface,
                            QWidget* const /*parent*/)
     : WSToolDialog(nullptr, QLatin1String("PiwigoSync Dialog")),
-      d(new Private(this, iface))
+      d           (new Private(this, iface))
 {
     d->pPiwigo = new PiwigoSession();
 
-    setWindowTitle(i18n("Piwigo Export"));
+    setWindowTitle(i18nc("@title:window", "Piwigo Export"));
     setModal(false);
 
     // "Start Upload" button
 
-    startButton()->setText(i18n("Start Upload"));
+    startButton()->setText(i18nc("@action:button", "Start Upload"));
     startButton()->setEnabled(false);
 
     connect(startButton(), SIGNAL(clicked()),
@@ -245,16 +271,7 @@ PiwigoWindow::PiwigoWindow(DInfoInterface* const iface,
 
     // we need to let d->talker work..
 
-    d->talker      = new PiwigoTalker(iface, d->widget);
-
-    // setting progressDlg and its numeric hints
-
-    d->progressDlg = new QProgressDialog(this);
-    d->progressDlg->setModal(true);
-    d->progressDlg->setAutoReset(true);
-    d->progressDlg->setAutoClose(true);
-    d->progressDlg->setMaximum(0);
-    d->progressDlg->reset();
+    d->talker  = new PiwigoTalker(iface, d->widget);
 
     // connect functions
 
@@ -262,7 +279,7 @@ PiwigoWindow::PiwigoWindow(DInfoInterface* const iface,
 
     KSharedConfigPtr config = KSharedConfig::openConfig();
 
-    if (!config->hasGroup("Piwigo Settings"))
+    if (!config->hasGroup(QLatin1String("Piwigo Settings")))
     {
         QPointer<PiwigoLoginDlg> dlg = new PiwigoLoginDlg(QApplication::activeWindow(),
                                                           d->pPiwigo, i18n("Edit Piwigo Data"));
@@ -279,7 +296,7 @@ PiwigoWindow::~PiwigoWindow()
     // write config
 
     KSharedConfigPtr config = KSharedConfig::openConfig();
-    KConfigGroup group      = config->group("PiwigoSync Galleries");
+    KConfigGroup group      = config->group(QLatin1String("PiwigoSync Galleries"));
 
     group.writeEntry("Resize",         d->resizeCheckBox->isChecked());
     group.writeEntry("Maximum Width",  d->widthSpinBox->value());
@@ -299,10 +316,13 @@ void PiwigoWindow::connectSignals()
     connect(d->confButton, SIGNAL(clicked()),
             this, SLOT(slotSettings()));
 
+    connect(d->reloadButton, SIGNAL(clicked()),
+            this, SLOT(slotReloadAlbums()));
+
     connect(d->resizeCheckBox, SIGNAL(stateChanged(int)),
             this, SLOT(slotEnableSpinBox(int)));
 
-    connect(d->progressDlg, SIGNAL(canceled()),
+    connect(d->progressBar, SIGNAL(signalProgressCanceled()),
             this, SLOT(slotAddPhotoCancel()));
 
     connect(d->talker, SIGNAL(signalProgressInfo(QString)),
@@ -330,7 +350,7 @@ void PiwigoWindow::connectSignals()
 void PiwigoWindow::readSettings()
 {
     KSharedConfigPtr config = KSharedConfig::openConfig();
-    KConfigGroup group      = config->group("PiwigoSync Galleries");
+    KConfigGroup group      = config->group(QLatin1String("PiwigoSync Galleries"));
 
     if (group.readEntry("Resize", false))
     {
@@ -350,6 +370,11 @@ void PiwigoWindow::readSettings()
     d->qualitySpinBox->setValue(group.readEntry("Quality",       95));
 }
 
+void PiwigoWindow::slotReloadAlbums()
+{
+    d->talker->listAlbums();
+}
+
 void PiwigoWindow::slotDoLogin()
 {
     QUrl url(d->pPiwigo->url());
@@ -369,11 +394,20 @@ void PiwigoWindow::slotDoLogin()
     }
 
     d->talker->login(url, d->pPiwigo->username(), d->pPiwigo->password());
+
+    d->userName->setText(QString::fromLatin1("<b>%1</b>").arg(d->pPiwigo->username()));
+    d->url->setText(QString::fromLatin1(
+                            "<b><a href='%1'>"
+                            "<font color=\"#9ACD32\">%2</font>"
+                            "</a></b>")
+                            .arg(url.url())
+                            .arg(url.toDisplayString())
+    );
 }
 
 void PiwigoWindow::slotLoginFailed(const QString& msg)
 {
-    if (QMessageBox::question(this, i18n("Login Failed"),
+    if (QMessageBox::question(this, i18nc("@title:window", "Login Failed"),
                               i18n("Failed to login into remote piwigo. ") + msg +
                               i18n("\nDo you want to check your settings and try again?"))
             != QMessageBox::Yes)
@@ -402,23 +436,28 @@ void PiwigoWindow::slotBusy(bool val)
     {
         setCursor(Qt::WaitCursor);
         startButton()->setEnabled(false);
+        d->reloadButton->setEnabled(false);
     }
     else
     {
         setCursor(Qt::ArrowCursor);
         bool loggedIn = d->talker->loggedIn();
-        startButton()->setEnabled(loggedIn && d->albumView->currentItem());
+        d->reloadButton->setEnabled(loggedIn);
+
+        bool b = (loggedIn && d->albumView->currentItem());
+        qCDebug(DIGIKAM_WEBSERVICES_LOG) << "busy : " << b;
+        startButton()->setEnabled(b);
     }
 }
 
 void PiwigoWindow::slotProgressInfo(const QString& msg)
 {
-    d->progressDlg->setLabelText(msg);
+    d->progressBar->progressStatusChanged(msg);
 }
 
 void PiwigoWindow::slotError(const QString& msg)
 {
-    d->progressDlg->hide();
+    setUiInProgressState(false);
     QMessageBox::critical(this, QString(), msg);
 }
 
@@ -461,7 +500,7 @@ void PiwigoWindow::slotAlbums(const QList<PiwigoAlbum>& albumList)
             bool found                  = false;
             int i                       = 0;
 
-            while (!found && i < parentItemList.size())
+            while (!found && (i < parentItemList.size()))
             {
                 parentItem = parentItemList.at(i);
 
@@ -520,7 +559,7 @@ void PiwigoWindow::slotAlbumSelected()
 
 void PiwigoWindow::slotAddPhoto()
 {
-    const QList<QUrl> urls(d->iface->currentSelectedItems());
+    const QList<QUrl> urls(d->imageList->imageUrls());
 
     if (urls.isEmpty())
     {
@@ -536,9 +575,10 @@ void PiwigoWindow::slotAddPhoto()
     }
 
     d->uploadTotal = d->pUploadList.count();
-    d->progressDlg->reset();
-    d->progressDlg->setMaximum(d->uploadTotal);
+    d->progressBar->reset();
+    d->progressBar->setMaximum(d->uploadTotal);
     d->uploadCount = 0;
+    startButton()->setEnabled(false);
     slotAddPhotoNext();
 }
 
@@ -546,8 +586,10 @@ void PiwigoWindow::slotAddPhotoNext()
 {
     if (d->pUploadList.isEmpty())
     {
-        d->progressDlg->reset();
-        d->progressDlg->hide();
+        d->progressBar->reset();
+        setUiInProgressState(false);
+        startButton()->setEnabled(true);
+
         return;
     }
 
@@ -555,8 +597,9 @@ void PiwigoWindow::slotAddPhotoNext()
     int column                  = d->albumView->currentColumn();
     QString albumTitle          = item->text(column);
     const PiwigoAlbum& album    = d->albumDict.value(albumTitle);
-    QString photoPath           = d->pUploadList.takeFirst();
-    bool res                    = d->talker->addPhoto(album.m_refNum, photoPath,
+    d->currPhotoPath            = d->pUploadList.takeFirst();
+    bool res                    = d->talker->addPhoto(album.m_refNum,
+                                                      d->currPhotoPath,
                                                       d->resizeCheckBox->isChecked(),
                                                       d->widthSpinBox->value(),
                                                       d->heightSpinBox->value(),
@@ -565,31 +608,34 @@ void PiwigoWindow::slotAddPhotoNext()
     if (!res)
     {
         slotAddPhotoFailed(i18n("The file %1 is not a supported image or video format",
-                                QUrl(photoPath).fileName()));
+                                QUrl(d->currPhotoPath).fileName()));
         return;
     }
 
-    d->progressDlg->setLabelText(i18n("Uploading file %1", QUrl(photoPath).fileName()));
+    d->progressBar->progressStatusChanged(i18n("Uploading file %1", QUrl(d->currPhotoPath).fileName()));
+    d->imageList->processing(QUrl::fromLocalFile(d->currPhotoPath));
 
-    if (d->progressDlg->isHidden())
+    if (d->progressBar->isHidden())
     {
-        d->progressDlg->show();
+        setUiInProgressState(true);
     }
 }
 
 void PiwigoWindow::slotAddPhotoSucceeded()
 {
     d->uploadCount++;
-    d->progressDlg->setValue(d->uploadCount);
+    d->progressBar->setValue(d->uploadCount);
+    d->imageList->processed(QUrl::fromLocalFile(d->currPhotoPath), true);
     slotAddPhotoNext();
 }
 
 void PiwigoWindow::slotAddPhotoFailed(const QString& msg)
 {
-    d->progressDlg->reset();
-    d->progressDlg->hide();
+    d->imageList->processed(QUrl::fromLocalFile(d->currPhotoPath), false);
+    d->progressBar->reset();
+    setUiInProgressState(false);
 
-    if (QMessageBox::question(this, i18n("Uploading Failed"),
+    if (QMessageBox::question(this, i18nc("@title:window", "Uploading Failed"),
                               i18n("Failed to upload media into remote Piwigo. ") + msg +
                               i18n("\nDo you want to continue?"))
             != QMessageBox::Yes)
@@ -604,8 +650,9 @@ void PiwigoWindow::slotAddPhotoFailed(const QString& msg)
 
 void PiwigoWindow::slotAddPhotoCancel()
 {
-    d->progressDlg->reset();
-    d->progressDlg->hide();
+    d->imageList->processed(QUrl::fromLocalFile(d->currPhotoPath), false);
+    d->progressBar->reset();
+    setUiInProgressState(false);
     d->talker->cancel();
 }
 
@@ -616,17 +663,23 @@ void PiwigoWindow::slotEnableSpinBox(int n)
     switch (n)
     {
         case 0:
+        {
             b = false;
             break;
+        }
 
         case 1:
         case 2:
+        {
             b = true;
             break;
+        }
 
         default:
+        {
             b = false;
             break;
+        }
     }
 
     d->widthSpinBox->setEnabled(b);
@@ -660,4 +713,21 @@ QString PiwigoWindow::cleanName(const QString& str) const
     return plain;
 }
 
+void PiwigoWindow::setUiInProgressState(bool inProgress)
+{
+    setRejectButtonMode(inProgress ? QDialogButtonBox::Cancel : QDialogButtonBox::Close);
+
+    if (inProgress)
+    {
+        d->progressBar->show();
+    }
+    else
+    {
+        d->progressBar->hide();
+        d->progressBar->progressCompleted();
+    }
+}
+
 } // namespace DigikamGenericPiwigoPlugin
+
+#include "moc_piwigowindow.cpp"
