@@ -31,7 +31,10 @@
 #include "digikam_debug.h"
 #include "album.h"
 #include "albummanager.h"
+#include "thememanager.h"
 #include "applicationsettings.h"
+#include "collectionlocation.h"
+#include "collectionmanager.h"
 #include "coredb.h"
 #include "coredbaccess.h"
 #include "iteminfo.h"
@@ -40,6 +43,7 @@
 #include "thumbnailloadthread.h"
 #include "thumbnailsize.h"
 #include "thumbnailcreator.h"
+#include "dio.h"
 
 namespace Digikam
 {
@@ -62,26 +66,17 @@ class Q_DECL_HIDDEN AlbumThumbnailLoader::Private
 {
 public:
 
-    explicit Private()
-      : iconSize            (ApplicationSettings::instance()->getTreeViewIconSize()),
-        faceSize            (ApplicationSettings::instance()->getTreeViewFaceSize()),
-        minBlendSize        (20),
-        iconTagThumbThread  (nullptr),
-        iconFaceThumbThread (nullptr),
-        iconAlbumThumbThread(nullptr),
-        fallBackIcon        (QIcon::fromTheme(QLatin1String("dialog-cancel")))
-    {
-    }
+    Private() = default;
 
-    int                                  iconSize;
-    int                                  faceSize;
-    int                                  minBlendSize;
+    int                                  iconSize               = ApplicationSettings::instance()->getTreeViewIconSize();
+    int                                  faceSize               = ApplicationSettings::instance()->getTreeViewFaceSize();
+    int                                  minBlendSize           = 20;
 
-    ThumbnailLoadThread*                 iconTagThumbThread;
-    ThumbnailLoadThread*                 iconFaceThumbThread;
-    ThumbnailLoadThread*                 iconAlbumThumbThread;
+    ThumbnailLoadThread*                 iconTagThumbThread     = nullptr;
+    ThumbnailLoadThread*                 iconFaceThumbThread    = nullptr;
+    ThumbnailLoadThread*                 iconAlbumThumbThread   = nullptr;
 
-    QIcon                                fallBackIcon;
+    QIcon                                fallBackIcon           = QIcon::fromTheme(QLatin1String("dialog-cancel"));
 
     IdAlbumMap                           idAlbumMap;
 
@@ -118,6 +113,13 @@ AlbumThumbnailLoader::AlbumThumbnailLoader()
 
     connect(AlbumManager::instance(), SIGNAL(signalAlbumDeleted(Album*)),
             this, SLOT(slotIconChanged(Album*)));
+
+    connect(ThemeManager::instance(), &ThemeManager::signalThemeChanged,
+            this, [this]()
+        {
+            d->iconCache.clear();
+        }
+    );
 }
 
 AlbumThumbnailLoader::~AlbumThumbnailLoader()
@@ -179,9 +181,14 @@ QPixmap AlbumThumbnailLoader::getStandardAlbumIcon(PAlbum* const album, Relative
     }
     else if (album->isTrashAlbum())
     {
-        if (album->countTrashAlbum() > 0)
+        PAlbum* const palbum = static_cast<PAlbum*>(album->parent());
+
+        if (palbum)
         {
-            return getStandardFullTrashIcon(relativeSize);
+            if (DIO::getTrashCounter(palbum->folderPath()) > 0)
+            {
+                return getStandardFullTrashIcon(relativeSize);
+            }
         }
 
         return getStandardEmptyTrashIcon(relativeSize);
@@ -215,6 +222,11 @@ QPixmap AlbumThumbnailLoader::getStandardAlbumRootIcon(RelativeSize relativeSize
     return loadIcon(QLatin1String("folder-pictures"), computeIconSize(relativeSize));
 }
 
+QPixmap AlbumThumbnailLoader::getStandardOfflineIcon(RelativeSize relativeSize)
+{
+    return loadIcon(QLatin1String("data-error"), computeIconSize(relativeSize));
+}
+
 QPixmap AlbumThumbnailLoader::getStandardAlbumIcon(RelativeSize relativeSize)
 {
     return loadIcon(QLatin1String("folder"), computeIconSize(relativeSize));
@@ -308,6 +320,7 @@ QPixmap AlbumThumbnailLoader::getTagThumbnailDirectly(TAlbum* const album)
     if      (album->iconId() && (d->iconSize > d->minBlendSize))
     {
         // icon cached?
+
         AlbumThumbnailMap::const_iterator it = d->thumbnailMap.constFind(album->globalID());
 
         if (it != d->thumbnailMap.constEnd())
@@ -332,6 +345,7 @@ QPixmap AlbumThumbnailLoader::getFaceThumbnailDirectly(TAlbum* const album)
     if      (album->iconId() && (d->faceSize > d->minBlendSize))
     {
         // icon cached?
+
         AlbumThumbnailMap::const_iterator it = d->thumbnailMap.constFind(album->globalID());
 
         if (it != d->thumbnailMap.constEnd())
@@ -386,6 +400,16 @@ bool AlbumThumbnailLoader::getAlbumThumbnail(PAlbum* const album)
 
 QPixmap AlbumThumbnailLoader::getAlbumThumbnailDirectly(PAlbum* const album)
 {
+    if (album->isAlbumRoot())
+    {
+        CollectionLocation location = CollectionManager::instance()->locationForAlbumRootId(album->albumRootId());
+
+        if (location.isNull() || !location.isAvailable())
+        {
+            return getStandardOfflineIcon();
+        }
+    }
+
     if (album->iconId() && !album->isTrashAlbum() && (d->iconSize > d->minBlendSize))
     {
         // icon cached?
@@ -465,9 +489,8 @@ void AlbumThumbnailLoader::addUrl(Album* const album, qlonglong id)
                 d->iconTagThumbThread->setThumbnailSize(d->iconSize);
                 d->iconTagThumbThread->setSendSurrogatePixmap(false);
 
-                connect(d->iconTagThumbThread,
-                        SIGNAL(signalThumbnailLoaded(LoadingDescription,QPixmap)),
-                        SLOT(slotGotThumbnailFromIcon(LoadingDescription,QPixmap)),
+                connect(d->iconTagThumbThread, SIGNAL(signalThumbnailLoaded(LoadingDescription,QPixmap)),
+                        this, SLOT(slotGotThumbnailFromIcon(LoadingDescription,QPixmap)),
                         Qt::QueuedConnection);
             }
 
@@ -477,9 +500,8 @@ void AlbumThumbnailLoader::addUrl(Album* const album, qlonglong id)
                 d->iconFaceThumbThread->setThumbnailSize(d->faceSize);
                 d->iconFaceThumbThread->setSendSurrogatePixmap(false);
 
-                connect(d->iconFaceThumbThread,
-                        SIGNAL(signalThumbnailLoaded(LoadingDescription,QPixmap)),
-                        SLOT(slotGotThumbnailFromIcon(LoadingDescription,QPixmap)),
+                connect(d->iconFaceThumbThread, SIGNAL(signalThumbnailLoaded(LoadingDescription,QPixmap)),
+                        this, SLOT(slotGotThumbnailFromIcon(LoadingDescription,QPixmap)),
                         Qt::QueuedConnection);
             }
 
@@ -500,9 +522,8 @@ void AlbumThumbnailLoader::addUrl(Album* const album, qlonglong id)
                 d->iconAlbumThumbThread->setThumbnailSize(d->iconSize);
                 d->iconAlbumThumbThread->setSendSurrogatePixmap(false);
 
-                connect(d->iconAlbumThumbThread,
-                        SIGNAL(signalThumbnailLoaded(LoadingDescription,QPixmap)),
-                        SLOT(slotGotThumbnailFromIcon(LoadingDescription,QPixmap)),
+                connect(d->iconAlbumThumbThread, SIGNAL(signalThumbnailLoaded(LoadingDescription,QPixmap)),
+                        this, SLOT(slotGotThumbnailFromIcon(LoadingDescription,QPixmap)),
                         Qt::QueuedConnection);
             }
 
@@ -575,11 +596,16 @@ void AlbumThumbnailLoader::slotGotThumbnailFromIcon(const LoadingDescription& lo
 
     QRect faceRect = QRect();
 
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
     if (loadingDescription.previewParameters.extraParameter.typeId() == QVariant::Rect)
+
 #else
+
     if (loadingDescription.previewParameters.extraParameter.type() == QVariant::Rect)
+
 #endif
+
     {
         faceRect = loadingDescription.previewParameters.extraParameter.toRect();
     }
@@ -623,6 +649,7 @@ void AlbumThumbnailLoader::slotGotThumbnailFromIcon(const LoadingDescription& lo
                 if (album)
                 {
                     d->thumbnailMap.insert(album->globalID(), thumbnail);
+
                     Q_EMIT signalThumbnail(album, thumbnail);
                 }
             }
@@ -691,3 +718,5 @@ QImage AlbumThumbnailLoader::getAlbumPreviewDirectly(PAlbum* const album, int si
 */
 
 } // namespace Digikam
+
+#include "moc_albumthumbnailloader.cpp"
