@@ -14,8 +14,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ALBUM_MANAGER_P_H
-#define DIGIKAM_ALBUM_MANAGER_P_H
+#pragma once
 
 #include "albummanager.h"
 
@@ -117,7 +116,7 @@ class Q_DECL_HIDDEN PAlbumPath
 {
 public:
 
-    PAlbumPath();
+    PAlbumPath() = default;
     PAlbumPath(int albumRootId, const QString& albumPath);
     explicit PAlbumPath(const PAlbum* const album);
 
@@ -209,7 +208,7 @@ public:
     explicit ChangingDB(AlbumManager::Private* const dd);
     ~ChangingDB();
 
-    AlbumManager::Private* const d;
+    AlbumManager::Private* const d = nullptr;
 };
 
 // -----------------------------------------------------------------------------------
@@ -222,5 +221,3 @@ public:
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_ALBUM_MANAGER_P_H
