@@ -70,9 +70,11 @@ void AlbumManager::scanSAlbums()
         {
             SAlbum* const album = oldSearches[info.id];
 
-            if ((info.name  != album->title())      ||
+            if (
+                (info.name  != album->title())      ||
                 (info.type  != album->searchType()) ||
-                (info.query != album->query()))
+                (info.query != album->query())
+               )
             {
                 QString oldName = album->title();
 
@@ -100,14 +102,16 @@ void AlbumManager::scanSAlbums()
     Q_FOREACH (SAlbum* const album, oldSearches)
     {
         Q_EMIT signalAlbumAboutToBeDeleted(album);
+
         d->allAlbumsIdHash.remove(album->globalID());
 
         Q_EMIT signalAlbumDeleted(album);
 
-        quintptr deletedAlbum = reinterpret_cast<quintptr>(album);
-        delete album;
+        album->prepareForDeletion();
 
-        Q_EMIT signalAlbumHasBeenDeleted(deletedAlbum);
+        Q_EMIT signalAlbumHasBeenDeleted(album);
+
+        delete album;
     }
 
     // add new albums
@@ -194,7 +198,9 @@ SAlbum* AlbumManager::createSAlbum(const QString& name,
     }
 
     album = new SAlbum(name, id);
+
     Q_EMIT signalAlbumAboutToBeAdded(album, d->rootSAlbum, d->rootSAlbum->lastChild());
+
     album->setSearch(type, query);
     album->setParent(d->rootSAlbum);
 
@@ -258,10 +264,11 @@ bool AlbumManager::deleteSAlbum(SAlbum* album)
 
     Q_EMIT signalAlbumDeleted(album);
 
-    quintptr deletedAlbum = reinterpret_cast<quintptr>(album);
-    delete album;
+    album->prepareForDeletion();
 
-    Q_EMIT signalAlbumHasBeenDeleted(deletedAlbum);
+    Q_EMIT signalAlbumHasBeenDeleted(album);
+
+    delete album;
 
     return true;
 }
@@ -292,9 +299,11 @@ void AlbumManager::slotSearchChange(const SearchChangeset& changeset)
             {
                 Album* const currentAlbum = d->currentAlbums.first();
 
-                if (currentAlbum                            &&
+                if (
+                    currentAlbum                            &&
                     (currentAlbum->type() == Album::SEARCH) &&
-                    (currentAlbum->id()   == changeset.searchId()))
+                    (currentAlbum->id()   == changeset.searchId())
+                   )
                 {
                     // the pointer is the same, but the contents changed
 
