@@ -73,7 +73,8 @@ void AbstractAlbumTreeView::setAlbumModel(AbstractSpecificAlbumModel* const mode
 
     if (m_albumModel)
     {
-        disconnect(m_albumModel, nullptr, this, nullptr);
+        disconnect(m_albumModel, nullptr,
+                   this, nullptr);
     }
 
     m_albumModel = model;
@@ -1185,10 +1186,12 @@ void AbstractAlbumTreeView::slotScrollBarValueChanged(int value)
 
 void AbstractAlbumTreeView::slotScrollBarActionTriggered(int action)
 {
-    if ((action == QAbstractSlider::SliderMove)        ||
+    if (
+        (action == QAbstractSlider::SliderMove)        ||
         (action == QAbstractSlider::SliderToMinimum)   ||
         (action == QAbstractSlider::SliderPageStepSub) ||
-        (action == QAbstractSlider::SliderSingleStepSub))
+        (action == QAbstractSlider::SliderSingleStepSub)
+       )
     {
         m_lastScrollBarValue = -1;
     }
