@@ -412,13 +412,17 @@ qlonglong CollectionScanner::scanFile(const QFileInfo& fi, int albumId, qlonglon
         {
             case NormalScan:
             case ModifiedScan:
+            {
                 imageId = scanNewFile(fi, albumId);
                 break;
+            }
 
             case Rescan:
             case CleanScan:
+            {
                 imageId = scanNewFileFullScan(fi, albumId);
                 break;
+            }
         }
     }
     else
@@ -428,20 +432,28 @@ qlonglong CollectionScanner::scanFile(const QFileInfo& fi, int albumId, qlonglon
         switch (mode)
         {
             case NormalScan:
+            {
                 scanFileNormal(fi, scanInfo);
                 break;
+            }
 
             case ModifiedScan:
+            {
                 scanModifiedFile(fi, scanInfo);
                 break;
+            }
 
             case Rescan:
+            {
                 rescanFile(fi, scanInfo);
                 break;
+            }
 
             case CleanScan:
+            {
                 cleanScanFile(fi, scanInfo);
                 break;
+            }
         }
     }
 
@@ -479,8 +491,7 @@ void CollectionScanner::scanAlbumRoot(const CollectionLocation& location)
             }
             else
             {
-                modified = QFileInfo(folder).lastModified();
-                modified.setTimeSpec(Qt::UTC);
+                modified = asDateTimeUTC(QFileInfo(folder).lastModified());
             }
 
             if (s_modificationDateEquals(modified, it.value()))
@@ -545,6 +556,7 @@ void CollectionScanner::scanForStaleAlbums(const QList<int>& locationIdsToScan)
         if (d->wantSignals && counter && (counter % 10 == 0))
         {
             Q_EMIT scannedFiles(counter);
+
             counter = 0;
         }
 
@@ -587,8 +599,7 @@ void CollectionScanner::scanForStaleAlbums(const QList<int>& locationIdsToScan)
             }
             else
             {
-                QDateTime dateTime = fileInfo.lastModified();
-                dateTime.setTimeSpec(Qt::UTC);
+                QDateTime dateTime = asDateTimeUTC(fileInfo.lastModified());
                 d->albumDateCache.insert(fileInfo.filePath(), dateTime);
             }
         }
@@ -626,8 +637,10 @@ void CollectionScanner::scanForStaleAlbums(const QList<int>& locationIdsToScan)
 
             for (it2 = albumList.constBegin() ; it2 != albumList.constEnd() ; ++it2)
             {
-                if ((it2->albumRootId  == it.key().albumRootId) &&
-                    (it2->relativePath == it.key().relativePath))
+                if (
+                    (it2->albumRootId  == it.key().albumRootId) &&
+                    (it2->relativePath == it.key().relativePath)
+                   )
                 {
                     toBeDeletedIndex = -1;
                     break;
@@ -701,8 +714,7 @@ void CollectionScanner::scanAlbum(const CollectionLocation& location, const QStr
     }
 
     int albumID                          = checkAlbum(location, album);
-    QDateTime albumDateTime              = QFileInfo(dir.path()).lastModified();
-    albumDateTime.setTimeSpec(Qt::UTC);
+    QDateTime albumDateTime              = asDateTimeUTC(QFileInfo(dir.path()).lastModified());
     QDateTime albumModified              = CoreDbAccess().db()->getAlbumModificationDate(albumID);
 
     if (checkDate && s_modificationDateEquals(albumDateTime, albumModified))
@@ -764,6 +776,7 @@ void CollectionScanner::scanAlbum(const CollectionLocation& location, const QStr
             if (d->wantSignals && counter && (counter % 100 == 0))
             {
                 Q_EMIT scannedFiles(counter);
+
                 counter = 0;
             }
 
@@ -824,8 +837,10 @@ void CollectionScanner::scanAlbum(const CollectionLocation& location, const QStr
 
                     if (itemDate.isValid())
                     {
-                        if ((settings.albumDateFrom == MetaEngineSettingsContainer::NewestItemDate) ||
-                            (settings.albumDateFrom == MetaEngineSettingsContainer::AverageDate))
+                        if (
+                            (settings.albumDateFrom == MetaEngineSettingsContainer::NewestItemDate) ||
+                            (settings.albumDateFrom == MetaEngineSettingsContainer::AverageDate)
+                           )
                         {
                             // Change album date only if the item date is newer.
 
@@ -836,8 +851,10 @@ void CollectionScanner::scanAlbum(const CollectionLocation& location, const QStr
                             }
                         }
 
-                        if ((settings.albumDateFrom == MetaEngineSettingsContainer::OldestItemDate) ||
-                            (settings.albumDateFrom == MetaEngineSettingsContainer::AverageDate))
+                        if (
+                            (settings.albumDateFrom == MetaEngineSettingsContainer::OldestItemDate) ||
+                            (settings.albumDateFrom == MetaEngineSettingsContainer::AverageDate)
+                           )
                         {
                             // Change album date only if the item date is older.
 
@@ -850,11 +867,12 @@ void CollectionScanner::scanAlbum(const CollectionLocation& location, const QStr
                     }
                 }
 
-                // Q_EMIT signals for scanned files with much higher granularity
+                // Emit signals for scanned files with much higher granularity
 
                 if (d->wantSignals && counter && (counter % 2 == 0))
                 {
                     Q_EMIT scannedFiles(counter);
+
                     counter = 0;
                 }
             }
@@ -950,13 +968,14 @@ void CollectionScanner::scanFileNormal(const QFileInfo& fi, const ItemScanInfo&
                                        bool checkSidecar, const QFileInfo* const sidecarInfo)
 {
     bool hasAnyHint            = d->hints && d->hints->hasAnyNormalHint(scanInfo.id);
-    QDateTime modificationDate = fi.lastModified();
-    modificationDate.setTimeSpec(Qt::UTC);
+    QDateTime modificationDate = asDateTimeUTC(fi.lastModified());
 
     // if the date is null, this signals a full rescan
 
-    if (scanInfo.modificationDate.isNull() ||
-        (hasAnyHint && d->hints->hasRescanHint(scanInfo.id)))
+    if      (
+             scanInfo.modificationDate.isNull() ||
+             (hasAnyHint && d->hints->hasRescanHint(scanInfo.id))
+            )
     {
         if (hasAnyHint)
         {
@@ -1003,8 +1022,10 @@ void CollectionScanner::scanFileNormal(const QFileInfo& fi, const ItemScanInfo&
     {
         // if the file need not be scanned because of modification, update the hash
 
-        if (s_modificationDateEquals(modificationDate, scanInfo.modificationDate) &&
-            (fi.size() == scanInfo.fileSize))
+        if (
+            s_modificationDateEquals(modificationDate, scanInfo.modificationDate) &&
+            (fi.size() == scanInfo.fileSize)
+           )
         {
             scanFileUpdateHashReuseThumbnail(fi, scanInfo, false);
 
@@ -1018,8 +1039,7 @@ void CollectionScanner::scanFileNormal(const QFileInfo& fi, const ItemScanInfo&
     {
         if      (sidecarInfo)
         {
-            QDateTime sidecarDate = sidecarInfo->lastModified();
-            sidecarDate.setTimeSpec(Qt::UTC);
+            QDateTime sidecarDate = asDateTimeUTC(sidecarInfo->lastModified());
 
             if (sidecarDate > modificationDate)
             {
@@ -1029,8 +1049,7 @@ void CollectionScanner::scanFileNormal(const QFileInfo& fi, const ItemScanInfo&
         else if (DMetadata::hasSidecar(fi.filePath()))
         {
             QString filePath      = DMetadata::sidecarPath(fi.filePath());
-            QDateTime sidecarDate = QFileInfo(filePath).lastModified();
-            sidecarDate.setTimeSpec(Qt::UTC);
+            QDateTime sidecarDate = asDateTimeUTC(QFileInfo(filePath).lastModified());
 
             if (sidecarDate > modificationDate)
             {
@@ -1039,8 +1058,10 @@ void CollectionScanner::scanFileNormal(const QFileInfo& fi, const ItemScanInfo&
         }
     }
 
-    if (!s_modificationDateEquals(modificationDate, scanInfo.modificationDate) ||
-        (fi.size() != scanInfo.fileSize))
+    if (
+        !s_modificationDateEquals(modificationDate, scanInfo.modificationDate) ||
+        (fi.size() != scanInfo.fileSize)
+       )
     {
         if (settings.rescanImageIfModified)
         {
@@ -1289,7 +1310,7 @@ bool CollectionScanner::databaseInitialScanDone()
 {
     CoreDbAccess access;
 
-    return !access.db()->getSetting(QLatin1String("Scanned")).isEmpty();
+    return (!access.db()->getSetting(QLatin1String("Scanned")).isEmpty());
 }
 
 } // namespace Digikam
