@@ -29,10 +29,6 @@ DBJobsThread::DBJobsThread(QObject* const parent)
     setObjectName(QLatin1String("DBJobsThread"));
 }
 
-DBJobsThread::~DBJobsThread()
-{
-}
-
 bool DBJobsThread::hasErrors()
 {
     return !m_errorsList.isEmpty();
@@ -64,10 +60,6 @@ AlbumsDBJobsThread::AlbumsDBJobsThread(QObject* const parent)
 {
 }
 
-AlbumsDBJobsThread::~AlbumsDBJobsThread()
-{
-}
-
 void AlbumsDBJobsThread::albumsListing(const AlbumsDBJobInfo& info)
 {
     AlbumsJob* const j = new AlbumsJob(info);
@@ -98,10 +90,6 @@ TagsDBJobsThread::TagsDBJobsThread(QObject* const parent)
 {
 }
 
-TagsDBJobsThread::~TagsDBJobsThread()
-{
-}
-
 void TagsDBJobsThread::tagsListing(const TagsDBJobInfo& info)
 {
     TagsJob* const j = new TagsJob(info);
@@ -137,10 +125,6 @@ DatesDBJobsThread::DatesDBJobsThread(QObject* const parent)
 {
 }
 
-DatesDBJobsThread::~DatesDBJobsThread()
-{
-}
-
 void DatesDBJobsThread::datesListing(const DatesDBJobInfo& info)
 {
     DatesJob* const j = new DatesJob(info);
@@ -171,10 +155,6 @@ GPSDBJobsThread::GPSDBJobsThread(QObject* const parent)
 {
 }
 
-GPSDBJobsThread::~GPSDBJobsThread()
-{
-}
-
 void GPSDBJobsThread::GPSListing(const GPSDBJobInfo& info)
 {
     GPSJob* const j = new GPSJob(info);
@@ -201,14 +181,7 @@ void GPSDBJobsThread::GPSListing(const GPSDBJobInfo& info)
 // -------------------------------------------------
 
 SearchesDBJobsThread::SearchesDBJobsThread(QObject* const parent)
-    : DBJobsThread(parent),
-      m_isAlbumUpdate(false),
-      m_processedImages(0),
-      m_totalImages2Scan(0)
-{
-}
-
-SearchesDBJobsThread::~SearchesDBJobsThread()
+    : DBJobsThread(parent)
 {
 }
 
@@ -231,9 +204,11 @@ void SearchesDBJobsThread::searchesListing(const SearchesDBJobInfo& info)
         QSet<qlonglong>::const_iterator end   = info.imageIds().constBegin();
 
         // Split job on multiple threads
+
         for (int i = 0; i < threadsCount; ++i)
         {
             // The last thread should read until the end of the list.
+
             if (i == threadsCount - 1)
             {
                 end = info.imageIds().constEnd();
@@ -241,7 +216,8 @@ void SearchesDBJobsThread::searchesListing(const SearchesDBJobInfo& info)
             else
             {
                 // TODO: port to std::advance https://en.cppreference.com/w/cpp/iterator/advance
-                for (int j = 0; end != info.imageIds().constEnd() && j < images2ScanPerThread; ++j, ++end);
+
+                for (int j = 0; ((end != info.imageIds().constEnd()) && (j < images2ScanPerThread)) ; ++j, ++end);
             }
 
             SearchesJob* const job = new SearchesJob(info, begin, end, m_haarIface.data());
