@@ -6,34 +6,24 @@
  * Date        : 2007-06-07
  * Description : Database engine abstract database backend
  *
- * Copyright (C) 2007-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2010-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2007-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DB_ENGINE_BACKEND_H
-#define DIGIKAM_DB_ENGINE_BACKEND_H
+#pragma once
 
 // Qt includes
 
 #include <QMap>
-#include <QMutex>
 #include <QObject>
 #include <QString>
 #include <QStringList>
 #include <QSqlQuery>
 #include <QSqlError>
+#include <QRecursiveMutex>
 
 // Local includes
 
@@ -52,12 +42,12 @@ class DIGIKAM_EXPORT DbEngineLocking
 {
 public:
 
-    explicit DbEngineLocking();
+    DbEngineLocking() = default;
 
 public:
 
-    QMutex mutex;
-    int    lockCount;
+    QRecursiveMutex mutex;
+    int             lockCount = 0;  ///< create a recursive mutex
 };
 
 // -----------------------------------------------------------------
@@ -139,6 +129,12 @@ public:
      */
     bool isCompatible(const DbEngineParameters& parameters);
 
+    /**
+     * Check or set WAL mode for SQLite database if enabled in settings.
+     * @returns true the WAL mode is confirmed enabled.
+     */
+    bool checkOrSetWALMode();
+
     /**
      * Open the database connection.
      * @returns true on success
@@ -157,10 +153,7 @@ public:
     {
     public:
 
-        QueryState()
-            : value(BdEngineBackend::NoErrors)
-        {
-        }
+        QueryState() = default;
 
         explicit QueryState(const QueryStateEnum value)    // krazy:exclude=explicit
             : value(value)
@@ -179,7 +172,7 @@ public:
 
     private:
 
-        QueryStateEnum value;
+        QueryStateEnum value = BdEngineBackend::NoErrors;
     };
 
 public:
@@ -227,9 +220,11 @@ public:
      * Queries by the specified parameters mustn't have named parameters.
      * The result values (if any) are stored within the values list.
      */
-    QueryState execDBAction(const DbEngineAction& action, QList<QVariant>* const values = nullptr, QVariant* const lastInsertId = nullptr);
+    QueryState execDBAction(const DbEngineAction& action, QList<QVariant>* const values = nullptr,
+                            QVariant* const lastInsertId = nullptr);
 
-    QueryState execDBAction(const QString& action, QList<QVariant>* const values = nullptr, QVariant* const lastInsertId = nullptr);
+    QueryState execDBAction(const QString& action, QList<QVariant>* const values = nullptr,
+                            QVariant* const lastInsertId = nullptr);
 
     /**
      * Performs the database action on the current database.
@@ -543,7 +538,7 @@ public:
 
 protected:
 
-    BdEngineBackendPrivate* const d_ptr;
+    BdEngineBackendPrivate* const d_ptr = nullptr;
 
 private:
 
@@ -556,5 +551,3 @@ private:
 } // namespace Digikam
 
 Q_DECLARE_METATYPE(QSqlError)
-
-#endif // DIGIKAM_DB_ENGINE_BACKEND_H
