@@ -20,10 +20,6 @@
 
 #include <QRegularExpression>
 
-// Local includes
-
-#include "digikam_globals.h"
-
 namespace Digikam
 {
 
@@ -36,8 +32,6 @@ ItemQueryBuilder::ItemQueryBuilder()
         m_shortMonths[i-1] = QLocale().standaloneMonthName(i, QLocale::ShortFormat).toLower();
         m_longMonths[i-1]  = QLocale().standaloneMonthName(i, QLocale::LongFormat).toLower();
     }
-
-    m_imageTagPropertiesJoined = false;
 }
 
 void ItemQueryBuilder::setImageTagPropertiesJoined(bool isJoined)
@@ -48,6 +42,7 @@ void ItemQueryBuilder::setImageTagPropertiesJoined(bool isJoined)
 QString ItemQueryBuilder::buildQuery(const QString& q, QList<QVariant> *boundValues, ItemQueryPostHooks* const hooks) const
 {
     // Handle legacy query descriptions
+
     if (q.startsWith(QLatin1String("digikamsearch:")))
     {
         return buildQueryFromUrl(QUrl(q), boundValues);
@@ -108,6 +103,7 @@ void ItemQueryBuilder::buildGroup(QString& sql, SearchXmlCachingReader& reader,
         }
 
         // subgroup
+
         if (reader.isGroupElement())
         {
             hasContent = true;
@@ -148,6 +144,7 @@ bool ItemQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
     FieldQueryBuilder fieldQuery(sql, reader, boundValues, hooks, relation);
 
     // First catch all noeffect fields. Those are only used for message passing when no Signal-Slot-communication is possible
+
     if      (name.startsWith(QLatin1String("noeffect_")))
     {
         return false;
@@ -300,6 +297,7 @@ bool ItemQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
         else if (relation == SearchXml::AllOf)
         {
             // there must be an entry in ImageTags for every given tag id
+
             QList<int> ids = reader.valueToIntOrIntList();
 
             bool firstCondition = true;
@@ -413,7 +411,8 @@ bool ItemQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
             int pageOrientation = reader.valueToInt();
 
             // "1" is landscape, "2" is portrait, "3" is landscape regardless of Exif, "4" is portrait regardless of Exif
-            if (pageOrientation == 1)
+
+            if      (pageOrientation == 1)
             {
                 sql += QString::fromUtf8(" ( (ImageInformation.orientation <= ? AND ImageInformation.width >= ImageInformation.height) "
                        "  OR (ImageInformation.orientation >= ? AND ImageInformation.width <= ImageInformation.height) ) ");
@@ -428,6 +427,7 @@ bool ItemQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
             else if (pageOrientation == 3 || pageOrientation == 4)
             {
                 // ignoring Exif orientation
+
                 sql += QString::fromUtf8(" ( ImageInformation.width ");
                 ItemQueryBuilder::addSqlRelation(sql, pageOrientation == 3 ? SearchXml::GreaterThanOrEqual : SearchXml::LessThanOrEqual);
                 sql += QString::fromUtf8(" ImageInformation.height) ");
@@ -461,7 +461,7 @@ bool ItemQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
 
         if (readerString.contains(QRegularExpression(QLatin1String("^\\d+:\\d+$"))))
         {
-            QStringList ratioNum = readerString.split(QLatin1Char(':'), QT_SKIP_EMPTY_PARTS);
+            QStringList ratioNum = readerString.split(QLatin1Char(':'), Qt::SkipEmptyParts);
             int num              = ratioNum.at(0).toInt();
             int denominator = ratioNum.at(1).toInt();
             query                = QString::fromUtf8("ABS((ImageInformation.width/CAST(ImageInformation.height AS DOUBLE)) - ?)  < 0.1");
@@ -515,7 +515,7 @@ bool ItemQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
 
                  if (value.contains(QLatin1Char(':')))
                  {
-                     QStringList ratioNum = value.split(QLatin1Char(':'), QT_SKIP_EMPTY_PARTS);
+                     QStringList ratioNum = value.split(QLatin1Char(':'), Qt::SkipEmptyParts);
                      int num              = ratioNum.at(0).toInt();
                      int denominator      = ratioNum.at(1).toInt();
                      ratioValues << (double)num / denominator;
@@ -542,7 +542,7 @@ bool ItemQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
 
             if (value.contains(QLatin1Char(':')))
             {
-                QStringList ratioNum = value.split(QLatin1Char(':'), QT_SKIP_EMPTY_PARTS);
+                QStringList ratioNum = value.split(QLatin1Char(':'), Qt::SkipEmptyParts);
                 int num              = ratioNum.at(0).toInt();
                 int denominator      = ratioNum.at(1).toInt();
                 *boundValues << (double)num / denominator;
@@ -554,6 +554,7 @@ bool ItemQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
     else if (name == QLatin1String("videoaudiobitrate"))
     {
         //fieldQuery.addIntField("VideoMetadata.audioBitRate");
+
         QList<int> values = reader.valueToIntList();
 
         if (values.size() != 2)
@@ -652,6 +653,7 @@ bool ItemQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
     else if (name == QLatin1String("videoframerate"))
     {
         //fieldQuery.addChoiceStringField("VideoMetadata.frameRate");
+
         QList<double> values = reader.valueToDoubleList();
 
         if (values.size() != 2)
@@ -802,10 +804,12 @@ bool ItemQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
     {
         sql += QString::fromUtf8(" (ImagePositions.latitudeNumber IS NULL AND ImagePositions.longitudeNumber IS NULL) ");
     }
-    else if ((name == QLatin1String("provinceState")) ||
+    else if (
+             (name == QLatin1String("provinceState")) ||
              (name == QLatin1String("location"))      ||
              (name == QLatin1String("country"))       ||
-             (name == QLatin1String("city")))
+             (name == QLatin1String("city"))
+            )
     {
         if (relation == SearchXml::OneOf)
         {
@@ -1043,6 +1047,7 @@ bool ItemQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
         if ((relation == SearchXml::Equal) || (relation == SearchXml::InTree))
         {
             // First, read attributes
+
             QStringView tagAttribute = reader.attributes().value(QLatin1String("tagid"));
             int tagId                = 0;
 
@@ -1052,6 +1057,7 @@ bool ItemQueryBuilder::buildField(QString& sql, SearchXmlCachingReader& reader,
             }
 
             // read values: one or two strings
+
             QStringList values = reader.valueToStringOrStringList();
 
             if ((values.size() < 1) || (values.size() > 2))
@@ -1213,16 +1219,19 @@ void ItemQueryBuilder::addSqlOperator(QString& sql, SearchXml::Operator op, bool
             sql += QLatin1String("AND");
             break;
         }
+
         case SearchXml::Or:
         {
             sql += QLatin1String("OR");
             break;
         }
+
         case SearchXml::AndNot:
         {
             sql += QLatin1String("AND NOT");
             break;
         }
+
         case SearchXml::OrNot:
         {
             sql += QLatin1String("OR NOT");
@@ -1241,41 +1250,49 @@ void ItemQueryBuilder::addSqlRelation(QString& sql, SearchXml::Relation rel)
             sql += QLatin1Char('=');
             break;
         }
+
         case SearchXml::Unequal:
         {
             sql += QLatin1String("<>");
             break;
         }
+
         case SearchXml::Like:
         {
             sql += QLatin1String("LIKE");
             break;
         }
+
         case SearchXml::NotLike:
         {
             sql += QLatin1String("NOT LIKE");
             break;
         }
+
         case SearchXml::LessThan:
         {
             sql += QLatin1Char('<');
             break;
         }
+
         case SearchXml::GreaterThan:
         {
             sql += QLatin1Char('>');
             break;
         }
+
         case SearchXml::LessThanOrEqual:
         {
             sql += QLatin1String("<=");
             break;
         }
+
         case SearchXml::GreaterThanOrEqual:
         {
             sql += QLatin1String(">=");
             break;
         }
+
         case SearchXml::OneOf:
         {
             sql += QLatin1String("IN");
@@ -1296,6 +1313,7 @@ void ItemQueryBuilder::addNoEffectContent(QString& sql, SearchXml::Operator op)
             sql += QLatin1String(" 1 ");
             break;
         }
+
         case SearchXml::AndNot:
         case SearchXml::OrNot:
         {
@@ -1410,7 +1428,7 @@ QString ItemQueryBuilder::convertFromUrlToXml(const QUrl& url) const
     writer.writeAttribute(QLatin1String("convertedFrom09Url"), QLatin1String("true"));
     writer.writeGroup();
 
-    QStringList strList = url.path().split(QLatin1Char(' '), QT_SKIP_EMPTY_PARTS);
+    QStringList strList = url.path().split(QLatin1Char(' '), Qt::SkipEmptyParts);
 
     for (QStringList::const_iterator it = strList.constBegin() ; it != strList.constEnd() ; ++it)
     {
@@ -1572,7 +1590,7 @@ QString ItemQueryBuilder::buildQueryFromUrl(const QUrl& url, QList<QVariant>* bo
 
     QString         sqlQuery;
     SubQueryBuilder subQuery;
-    QStringList     strList = url.path().split(QLatin1Char(' '), QT_SKIP_EMPTY_PARTS);
+    QStringList     strList = url.path().split(QLatin1Char(' '), Qt::SkipEmptyParts);
 
     for (QStringList::const_iterator it = strList.constBegin() ; it != strList.constEnd() ; ++it)
     {
@@ -1677,8 +1695,10 @@ QString ItemQueryBuilder::possibleDate(const QString& str, bool& exact) const
 
         for (int i = 1 ; i <= 12 ; ++i)
         {
-            if ((str.toLower() == m_shortMonths[i-1]) ||
-                (str.toLower() == m_longMonths[i-1]))
+            if (
+                (str.toLower() == m_shortMonths[i-1]) ||
+                (str.toLower() == m_longMonths[i-1])
+               )
             {
                 QString monGlob;
                 monGlob = QString().asprintf("%.2d", i);
