@@ -7,7 +7,7 @@
  * Description : Filter values for use with ItemFilterModel
  *
  * SPDX-FileCopyrightText: 2009-2011 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * SPDX-FileCopyrightText: 2011-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2011-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText:      2010 by Andi Clemens <andi dot clemens at gmail dot com>
  * SPDX-FileCopyrightText:      2011 by Michael G. Hansen <mike at mghansen dot de>
  * SPDX-FileCopyrightText:      2014 by Mohamed_Anwer <m_dot_anwer at gmx dot com>
@@ -29,8 +29,8 @@
 // Local includes
 
 #include "digikam_debug.h"
-#include "coredbfields.h"
 #include "digikam_globals.h"
+#include "coredbfields.h"
 #include "iteminfo.h"
 #include "tagscache.h"
 #include "versionmanagersettings.h"
@@ -38,17 +38,6 @@
 namespace Digikam
 {
 
-ItemFilterSettings::ItemFilterSettings()
-    : m_untaggedFilter      (false),
-      m_matchingCond        (OrCondition),
-      m_ratingFilter        (0),
-      m_ratingCond          (GreaterEqualCondition),
-      m_isUnratedExcluded   (false),
-      m_mimeTypeFilter      (MimeFilter::AllFiles),
-      m_geolocationCondition(GeolocationNoFilter)
-{
-}
-
 DatabaseFields::Set ItemFilterSettings::watchFlags() const
 {
     DatabaseFields::Set set;
@@ -175,14 +164,16 @@ bool ItemFilterSettings::isFilteringInternally() const
 
 bool ItemFilterSettings::isFiltering() const
 {
-    return (isFilteringByDay()         ||
+    return (
+            isFilteringByDay()         ||
             isFilteringByTags()        ||
             isFilteringByText()        ||
             isFilteringByRating()      ||
             isFilteringByTypeMime()    ||
             isFilteringByColorLabels() ||
             isFilteringByPickLabels()  ||
-            isFilteringByGeolocation());
+            isFilteringByGeolocation()
+           );
 }
 
 void ItemFilterSettings::setDayFilter(const QList<QDateTime>& days)
@@ -210,7 +201,9 @@ void ItemFilterSettings::setTagFilter(const QList<int>& includedTags,
     m_pickLabelTagFilter  = plTagIds;
 }
 
-void ItemFilterSettings::setRatingFilter(int rating, RatingCondition ratingCondition, bool isUnratedExcluded)
+void ItemFilterSettings::setRatingFilter(int rating,
+                                         RatingCondition ratingCondition,
+                                         bool isUnratedExcluded)
 {
     m_ratingFilter      = rating;
     m_ratingCond        = ratingCondition;
@@ -308,7 +301,7 @@ bool ItemFilterSettings::matches(const ItemInfo& info, bool* const foundText) co
 
     bool match = false;
 
-    if (!m_includeTagFilter.isEmpty() || !m_excludeTagFilter.isEmpty())
+    if      (!m_includeTagFilter.isEmpty() || !m_excludeTagFilter.isEmpty())
     {
         QList<int>                 tagIds = info.tagIds();
         QList<int>::const_iterator it;
@@ -331,6 +324,7 @@ bool ItemFilterSettings::matches(const ItemInfo& info, bool* const foundText) co
         else // AND matching condition...
         {
             // m_untaggedFilter and non-empty tag filter, combined with AND, is logically no match
+
             if (!m_untaggedFilter)
             {
                 for (it = m_includeTagFilter.begin() ; it != m_includeTagFilter.end() ; ++it)
@@ -412,6 +406,7 @@ bool ItemFilterSettings::matches(const ItemInfo& info, bool* const foundText) co
             {
                 // Searching for "has no ColorLabel" requires special handling:
                 // Scan that the tag ids contains none of the ColorLabel tags, except maybe the NoColorLabel tag
+
                 matchCL = containsNoneOfExcept(tagIds, TagsCache::instance()->colorLabelTags(), noColorLabelTagId);
             }
         }
@@ -439,13 +434,13 @@ bool ItemFilterSettings::matches(const ItemInfo& info, bool* const foundText) co
             rating = 0;
         }
 
-        if (m_isUnratedExcluded && rating == 0)
+        if (m_isUnratedExcluded && (rating == 0))
         {
             match = false;
         }
         else
         {
-            if (m_ratingCond == GreaterEqualCondition)
+            if      (m_ratingCond == GreaterEqualCondition)
             {
                 // If the rating is not >=, i.e it is <, then it does not match.
 
@@ -650,6 +645,7 @@ bool ItemFilterSettings::matches(const ItemInfo& info, bool* const foundText) co
         default:
         {
             // All Files: do nothing...
+
             break;
         }
     }
@@ -658,7 +654,7 @@ bool ItemFilterSettings::matches(const ItemInfo& info, bool* const foundText) co
 
     if (m_geolocationCondition != GeolocationNoFilter)
     {
-        if (m_geolocationCondition == GeolocationNoCoordinates)
+        if      (m_geolocationCondition == GeolocationNoCoordinates)
         {
             if (info.hasCoordinates())
             {
@@ -689,27 +685,33 @@ bool ItemFilterSettings::matches(const ItemInfo& info, bool* const foundText) co
 
         // Image name
 
-        if ((m_textFilterSettings.textFields & SearchTextFilterSettings::ImageName) &&
+        if (
+            (m_textFilterSettings.textFields & SearchTextFilterSettings::ImageName) &&
             (textRegExp.match(info.name()).hasMatch()                               ||
-            info.name().contains(m_textFilterSettings.text, m_textFilterSettings.caseSensitive)))
+            info.name().contains(m_textFilterSettings.text, m_textFilterSettings.caseSensitive))
+           )
         {
             textMatch = true;
         }
 
         // Image title
 
-        if ((m_textFilterSettings.textFields & SearchTextFilterSettings::ImageTitle) &&
+        if (
+            (m_textFilterSettings.textFields & SearchTextFilterSettings::ImageTitle) &&
             (textRegExp.match(info.title()).hasMatch()                               ||
-            info.title().contains(m_textFilterSettings.text, m_textFilterSettings.caseSensitive)))
+            info.title().contains(m_textFilterSettings.text, m_textFilterSettings.caseSensitive))
+           )
         {
             textMatch = true;
         }
 
         // Image comment
 
-        if ((m_textFilterSettings.textFields & SearchTextFilterSettings::ImageComment) &&
+        if (
+            (m_textFilterSettings.textFields & SearchTextFilterSettings::ImageComment) &&
             (textRegExp.match(info.comment()).hasMatch()                               ||
-            info.comment().contains(m_textFilterSettings.text, m_textFilterSettings.caseSensitive)))
+            info.comment().contains(m_textFilterSettings.text, m_textFilterSettings.caseSensitive))
+           )
         {
             textMatch = true;
         }
@@ -718,9 +720,11 @@ bool ItemFilterSettings::matches(const ItemInfo& info, bool* const foundText) co
 
         Q_FOREACH (int id, info.tagIds())
         {
-            if ((m_textFilterSettings.textFields & SearchTextFilterSettings::TagName) &&
+            if (
+                (m_textFilterSettings.textFields & SearchTextFilterSettings::TagName) &&
                 (textRegExp.match(m_tagNameHash.value(id)).hasMatch()                 ||
-                m_tagNameHash.value(id).contains(m_textFilterSettings.text, m_textFilterSettings.caseSensitive)))
+                m_tagNameHash.value(id).contains(m_textFilterSettings.text, m_textFilterSettings.caseSensitive))
+               )
             {
                 textMatch = true;
             }
@@ -728,9 +732,11 @@ bool ItemFilterSettings::matches(const ItemInfo& info, bool* const foundText) co
 
         // Album names
 
-        if ((m_textFilterSettings.textFields & SearchTextFilterSettings::AlbumName) &&
+        if (
+            (m_textFilterSettings.textFields & SearchTextFilterSettings::AlbumName) &&
             (textRegExp.match(m_albumNameHash.value(info.albumId())).hasMatch()     ||
-            m_albumNameHash.value(info.albumId()).contains(m_textFilterSettings.text, m_textFilterSettings.caseSensitive)))
+            m_albumNameHash.value(info.albumId()).contains(m_textFilterSettings.text, m_textFilterSettings.caseSensitive))
+           )
         {
             textMatch = true;
         }
@@ -742,21 +748,29 @@ bool ItemFilterSettings::matches(const ItemInfo& info, bool* const foundText) co
             QRegularExpression expRatio (QLatin1String("^\\d+:\\d+$"));
             QRegularExpression expFloat (QLatin1String("^\\d+(.\\d+)?$"));
 
-            if (m_textFilterSettings.text.contains(expRatio) && m_textFilterSettings.text.contains(QRegularExpression(QLatin1String(":\\d+"))))
+            if      (
+                     m_textFilterSettings.text.contains(expRatio) &&
+                     m_textFilterSettings.text.contains(QRegularExpression(QLatin1String(":\\d+")))
+                    )
             {
                 QString trimmedTextFilterSettingsText = m_textFilterSettings.text;
-                QStringList numberStringList          = trimmedTextFilterSettingsText.split(QLatin1Char(':'), QT_SKIP_EMPTY_PARTS);
+                QStringList numberStringList          = trimmedTextFilterSettingsText.split(QLatin1Char(':'),
+                                                                                            Qt::SkipEmptyParts);
 
                 if (numberStringList.length() == 2)
                 {
-                    QString numString     = (QString)numberStringList.at(0), denomString = (QString)numberStringList.at(1);
                     bool canConverseNum   = false;
                     bool canConverseDenom = false;
-                    int num               = numString.toInt(&canConverseNum, 10), denom = denomString.toInt(&canConverseDenom, 10);
+                    int num               = numberStringList.at(0).toInt(&canConverseNum, 10);
+                    int denom             = numberStringList.at(1).toInt(&canConverseDenom, 10);
 
-                    if (canConverseNum && canConverseDenom)
+                    if (canConverseNum && canConverseDenom && num && denom && info.dimensions().isValid())
                     {
-                        if (fabs(info.aspectRatio() - (double)num / denom) < 0.1)
+                        double textAspect = qMax((double)num / denom, (double)denom / num);
+                        double infoAspect = qMax((double)info.dimensions().width()  / info.dimensions().height(),
+                                                 (double)info.dimensions().height() / info.dimensions().width());
+
+                        if (fabs(infoAspect - textAspect) < 0.01)
                         {
                             textMatch = true;
                         }
@@ -788,18 +802,24 @@ bool ItemFilterSettings::matches(const ItemInfo& info, bool* const foundText) co
             int pixelSize = size.height()*size.width();
             QString text  = m_textFilterSettings.text;
 
-            if      (text.contains(QRegularExpression(QLatin1String("^>\\d{1,15}$"))) &&
-                (pixelSize > (text.remove(0, 1)).toInt()))
+            if      (
+                     text.contains(QRegularExpression(QLatin1String("^>\\d{1,15}$"))) &&
+                     (pixelSize > (text.remove(0, 1)).toInt())
+                    )
             {
                 textMatch = true;
             }
-            else if (text.contains(QRegularExpression(QLatin1String("^<\\d{1,15}$"))) &&
-                     (pixelSize < (text.remove(0, 1)).toInt()))
+            else if (
+                     text.contains(QRegularExpression(QLatin1String("^<\\d{1,15}$"))) &&
+                     (pixelSize < (text.remove(0, 1)).toInt())
+                    )
             {
                 textMatch = true;
             }
-            else if (text.contains(QRegularExpression(QLatin1String("^\\d+$"))) &&
-                     (pixelSize == text.toInt()))
+            else if (
+                     text.contains(QRegularExpression(QLatin1String("^\\d+$"))) &&
+                     (pixelSize == text.toInt())
+                    )
             {
                 textMatch = true;
             }
@@ -853,12 +873,6 @@ bool ItemFilterSettings::matches(const ItemInfo& info, bool* const foundText) co
 
 // -------------------------------------------------------------------------------------------------
 
-VersionItemFilterSettings::VersionItemFilterSettings()
-    : m_includeTagFilter  (0),
-      m_exceptionTagFilter(0)
-{
-}
-
 VersionItemFilterSettings::VersionItemFilterSettings(const VersionManagerSettings& settings)
 {
     setVersionManagerSettings(settings);
@@ -866,8 +880,10 @@ VersionItemFilterSettings::VersionItemFilterSettings(const VersionManagerSetting
 
 bool VersionItemFilterSettings::operator==(const VersionItemFilterSettings& other) const
 {
-    return ((m_excludeTagFilter == other.m_excludeTagFilter) &&
-            (m_exceptionLists   == other.m_exceptionLists));
+    return (
+            (m_excludeTagFilter == other.m_excludeTagFilter) &&
+            (m_exceptionLists   == other.m_exceptionLists)
+           );
 }
 
 bool VersionItemFilterSettings::matches(const ItemInfo& info) const
@@ -972,7 +988,7 @@ void VersionItemFilterSettings::setExceptionList(const QList<qlonglong>& idList,
 
 bool VersionItemFilterSettings::isFiltering() const
 {
-    return !m_excludeTagFilter.isEmpty();
+    return (!m_excludeTagFilter.isEmpty());
 }
 
 bool VersionItemFilterSettings::isFilteringByTags() const
@@ -982,15 +998,12 @@ bool VersionItemFilterSettings::isFilteringByTags() const
 
 // -------------------------------------------------------------------------------------------------
 
-GroupItemFilterSettings::GroupItemFilterSettings()
-    : m_allOpen(false)
-{
-}
-
 bool GroupItemFilterSettings::operator==(const GroupItemFilterSettings& other) const
 {
-    return ((m_allOpen    == other.m_allOpen) &&
-            (m_openGroups == other.m_openGroups));
+    return (
+            (m_allOpen    == other.m_allOpen) &&
+            (m_openGroups == other.m_openGroups)
+           );
 }
 
 bool GroupItemFilterSettings::matches(const ItemInfo& info) const
@@ -1037,7 +1050,7 @@ bool GroupItemFilterSettings::isAllOpen() const
 
 bool GroupItemFilterSettings::isFiltering() const
 {
-    return !m_allOpen;
+    return (!m_allOpen);
 }
 
 DatabaseFields::Set GroupItemFilterSettings::watchFlags() const
