@@ -29,19 +29,6 @@
 namespace Digikam
 {
 
-ItemSortSettings::ItemSortSettings()
-    : categorizationMode            (NoCategories),
-      categorizationSortOrder       (DefaultOrder),
-      currentCategorizationSortOrder(Qt::AscendingOrder),
-      categorizationCaseSensitivity (Qt::CaseSensitive),
-      sortRole                      (SortByFileName),
-      sortOrder                     (DefaultOrder),
-      strTypeNatural                (true),
-      currentSortOrder              (Qt::AscendingOrder),
-      sortCaseSensitivity           (Qt::CaseSensitive)
-{
-}
-
 bool ItemSortSettings::operator==(const ItemSortSettings& other) const
 {
     return (
@@ -213,8 +200,12 @@ int ItemSortSettings::compareCategories(const ItemInfo& left, const ItemInfo& ri
 
         case CategoryByMonth:
         {
-            return compareByOrder(left.dateTime().date(),
-                                  right.dateTime().date(),
+            int leftMonth  = left.dateTime().date().year()  * 100 +
+                             left.dateTime().date().month();
+            int rightMonth = right.dateTime().date().year() * 100 +
+                             right.dateTime().date().month();
+
+            return compareByOrder(leftMonth, rightMonth,
                                   currentCategorizationSortOrder);
         }
 
@@ -265,6 +256,10 @@ int ItemSortSettings::compareCategories(const ItemInfo& left, const ItemInfo& ri
             {
                 leftValue = left.getSuggestedNames().value(leftFace.region().toXml());
             }
+            else
+            {
+                leftValue = TagPropertyName::unknownPerson();
+            }
 
             if      (rightFace.type() == FaceTagsIface::ConfirmedName)
             {
@@ -274,12 +269,16 @@ int ItemSortSettings::compareCategories(const ItemInfo& left, const ItemInfo& ri
             {
                  rightValue = right.getSuggestedNames().value(rightFace.region().toXml());
             }
+            else
+            {
+                rightValue = TagPropertyName::unknownPerson();
+            }
 
-            leftValue  += fastNumberToString(leftFace.tagId()) +
-                          fastNumberToString(leftFace.type());
+            leftValue  += fastNumberToString(leftFace.type()) +
+                          fastNumberToString(leftFace.tagId());
 
-            rightValue += fastNumberToString(rightFace.tagId()) +
-                          fastNumberToString(rightFace.type());
+            rightValue += fastNumberToString(rightFace.type()) +
+                          fastNumberToString(rightFace.tagId());
 
             // Compare alphabetically based on the face name
 
@@ -396,7 +395,7 @@ int ItemSortSettings::compare(const ItemInfo& left, const ItemInfo& right, SortR
         {
             // I have the feeling that inverting the sort order for rating is the natural order
 
-            return - compareByOrder(left.rating(), right.rating(), currentSortOrder);
+            return (- compareByOrder(left.rating(), right.rating(), currentSortOrder));
         }
 
         case SortByImageSize:
@@ -405,6 +404,7 @@ int ItemSortSettings::compare(const ItemInfo& left, const ItemInfo& right, SortR
             QSize rightSize = right.dimensions();
             int leftPixels  = leftSize.width()  * leftSize.height();
             int rightPixels = rightSize.width() * rightSize.height();
+
             return compareByOrder(leftPixels, rightPixels, currentSortOrder);
         }
 
@@ -414,6 +414,7 @@ int ItemSortSettings::compare(const ItemInfo& left, const ItemInfo& right, SortR
             QSize rightSize = right.dimensions();
             int leftAR      = (double(leftSize.width())  / double(leftSize.height()))  * 1000000;
             int rightAR     = (double(rightSize.width()) / double(rightSize.height())) * 1000000;
+
             return compareByOrder(leftAR, rightAR, currentSortOrder);
         }
 
@@ -424,8 +425,9 @@ int ItemSortSettings::compare(const ItemInfo& left, const ItemInfo& right, SortR
 
             // make sure that the original image has always the highest similarity.
 
-            double leftSimilarity           = left.id()  == leftReferenceImageId  ? 1.1 : left.currentSimilarity();
-            double rightSimilarity          = right.id() == rightReferenceImageId ? 1.1 : right.currentSimilarity();
+            double leftSimilarity           = (left.id()  == leftReferenceImageId ) ? 1.1 : left.currentSimilarity();
+            double rightSimilarity          = (right.id() == rightReferenceImageId) ? 1.1 : right.currentSimilarity();
+
             return compareByOrder(leftSimilarity, rightSimilarity, currentSortOrder);
         }
 
@@ -464,20 +466,31 @@ int ItemSortSettings::compare(const ItemInfo& left, const ItemInfo& right, SortR
 
 bool ItemSortSettings::lessThan(const QVariant& left, const QVariant& right) const
 {
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
     if (left.typeId() != right.typeId())
+
 #else
+
     if (left.type() != right.type())
+
 #endif
+
     {
         return false;
     }
 
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
     switch (left.typeId())
+
 #else
+
     switch (left.type())
+
 #endif
+
     {
         case QVariant::Int:
         {
@@ -545,8 +558,11 @@ bool ItemSortSettings::lessThan(const QVariant& left, const QVariant& right) con
             }
 
 #if __GNUC__ >= 7       // krazy:exclude=cpp
+
             [[fallthrough]];
+
 #endif
+
         }
 
         default:
