@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_TAGS_CACHE_H
-#define DIGIKAM_TAGS_CACHE_H
+#pragma once
 
 // Qt includes
 
@@ -319,9 +318,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_TAGS_CACHE_H
