@@ -7,7 +7,7 @@
  * Description : scan item controller - start operations.
  *
  * SPDX-FileCopyrightText: 2005-2006 by Tom Albers <tomalbers at kde dot nl>
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2007-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -198,6 +198,17 @@ void ScanController::resumeCollectionScan()
     }
 }
 
+void ScanController::restartCollectionScan()
+{
+    QMutexLocker lock(&d->mutex);
+
+    if (d->scanSuspended)
+    {
+        d->scanSuspended = 0;
+        d->condVar.wakeAll();
+    }
+}
+
 void ScanController::slotStartCompleteScan()
 {
     d->totalFilesToScan = 0;
@@ -253,6 +264,7 @@ void ScanController::beginFileMetadataWrite(const ItemInfo& info)
 {
     {
         // throw in a lock to synchronize with all parallel writing
+
         FileReadLocker locker(info.filePath());
     }
 
