@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_WEB_BROWSER_DLG_H
-#define DIGIKAM_WEB_BROWSER_DLG_H
+#pragma once
 
 // Qt include
 
@@ -41,7 +40,7 @@ public:
     explicit WebBrowserDlg(const QUrl& url,
                            QWidget* const parent,
                            bool hideDeskBrowser = false);
-    ~WebBrowserDlg() override;
+    ~WebBrowserDlg()                override;
 
 Q_SIGNALS:
 
@@ -61,14 +60,12 @@ private Q_SLOTS:
 
 protected:
 
-    void closeEvent(QCloseEvent*) override;
+    void closeEvent(QCloseEvent*)   override;
 
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_WEB_BROWSER_DLG_H
