@@ -6,7 +6,7 @@
  * Date        : 2005-05-25
  * Description : Charcoal threaded image filter.
  *
- * SPDX-FileCopyrightText: 2005-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2005-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2010      by Martin Klapetek <martin dot klapetek at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -44,16 +44,11 @@ class Q_DECL_HIDDEN CharcoalFilter::Private
 {
 public:
 
-    explicit Private()
-      : pencil        (5.0),
-        smooth        (10.0),
-        globalProgress(0)
-    {
-    }
+    Private() = default;
 
-    double pencil;
-    double smooth;
-    int    globalProgress;
+    double pencil           = 5.0;
+    double smooth           = 10.0;
+    int    globalProgress   = 0;
 
     QMutex lock;
 };
@@ -114,7 +109,7 @@ void CharcoalFilter::filterImage()
         return;
     }
 
-    QScopedArrayPointer<double> kernel(new double[kernelWidth * kernelWidth]);
+    QScopedArrayPointer<double> kernel(new double[kernelWidth * kernelWidth]{});
 
     if (kernel.isNull())
     {
@@ -310,11 +305,17 @@ bool CharcoalFilter::convolveImage(const unsigned int order, const double* kerne
     for (int j = 0 ; runningFlag() && (j < vals.count()-1) ; ++j)
     {
         tasks.append(QtConcurrent::run(
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
                                        &CharcoalFilter::convolveImageMultithreaded, this,
+
 #else
+
                                        this, &CharcoalFilter::convolveImageMultithreaded,
+
 #endif
+
                                        vals[j],
                                        vals[j+1],
                                        normal_kernel.data(),
@@ -383,3 +384,5 @@ void CharcoalFilter::readParameters(const Digikam::FilterAction& action)
 }
 
 } // namespace Digikam
+
+#include "moc_charcoalfilter.cpp"
