@@ -3,18 +3,10 @@
  * Date        : 2008-02-10
  * Description : a tool to fix automatically camera lens aberrations
  *
- * Copyright (C) 2008      by Adrian Schroeter <adrian at suse dot de>
- * Copyright (C) 2008-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2008      by Adrian Schroeter <adrian at suse dot de>
+ * SPDX-FileCopyrightText: 2008-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -25,20 +17,26 @@
 #include <QStandardPaths>
 #include <QFile>
 #include <QDir>
+#include <QRegularExpression>
 
 // Local includes
 
 #include "digikam_debug.h"
 
-// Disable deprecated API from Lensfun.
-#if defined(Q_CC_GNU)
-#   pragma GCC diagnostic push
-#   pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-#endif
+// Disable deprecated API from older Lensfun.
+
+#if !LENSFUN_TEST_VERSION(0,3,99)
+
+#   if defined(Q_CC_GNU)
+#       pragma GCC diagnostic push
+#       pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+#   endif
+
+#   if defined(Q_CC_CLANG)
+#       pragma clang diagnostic push
+#       pragma clang diagnostic ignored "-Wdeprecated-declarations"
+#   endif
 
-#if defined(Q_CC_CLANG)
-#   pragma clang diagnostic push
-#   pragma clang diagnostic ignored "-Wdeprecated-declarations"
 #endif
 
 namespace Digikam
@@ -48,34 +46,129 @@ class Q_DECL_HIDDEN LensFunIface::Private
 {
 public:
 
-    explicit Private()
-      : lfDb      (nullptr),
-        lfCameras (nullptr),
-        usedLens  (nullptr),
-        usedCamera(nullptr)
-    {
-    }
+    Private() = default;
+
+    QString  metadataMatchDebugStr(MetadataMatch val)          const;
+    LensList findLenses(const lfCamera* const camera,
+                        const QString& lensDesc,
+                        const QString& lensMaker = QString())  const;
+
+    double checkSimilarity(const QString& a, const QString& b) const;
+
+public:
 
     // To be used for modification
+
     LensFunContainer       settings;
 
     // Database items
-    lfDatabase*            lfDb;
-    const lfCamera* const* lfCameras;
+
+    lfDatabase*            lfDb         = nullptr;
+    const lfCamera* const* lfCameras    = nullptr;
 
     QString                makeDescription;
     QString                modelDescription;
     QString                lensDescription;
 
-    LensPtr                usedLens;
-    DevicePtr              usedCamera;
+    LensPtr                usedLens     = nullptr;
+    DevicePtr              usedCamera   = nullptr;
 };
 
+QString LensFunIface::Private::metadataMatchDebugStr(MetadataMatch val) const
+{
+    QString ret;
+
+    switch (val)
+    {
+        case MetadataNoMatch:
+        {
+            ret = QLatin1String("No Match");
+            break;
+        }
+
+        case MetadataPartialMatch:
+        {
+            ret = QLatin1String("Partial Match");
+            break;
+        }
+
+        default:
+        {
+            ret = QLatin1String("Exact Match");
+            break;
+        }
+    }
+
+    return ret;
+}
+
+LensFunIface::LensList LensFunIface::Private::findLenses(const lfCamera* const lfCamera,
+                                                         const QString& lensDesc,
+                                                         const QString& lensMaker) const
+{
+    LensList lensList;
+
+    if (lfCamera)
+    {
+        const char* const maker     = lensMaker.isEmpty() ? nullptr : lensMaker.toLatin1().constData();
+        const char* const model     = lensDesc.isEmpty()  ? nullptr : lensDesc.toLatin1().constData();
+        const lfLens* const *lfLens = lfDb->FindLenses(lfCamera, maker, model);
+
+        while (lfLens && *lfLens)
+        {
+            lensList << (*lfLens);
+            ++lfLens;
+        }
+    }
+
+    return lensList;
+}
+
+// Inspired by https://www.qtcentre.org/threads/49601-String-similarity-check
+
+double LensFunIface::Private::checkSimilarity(const QString& a, const QString& b) const
+{
+    if (a.isEmpty() || b.isEmpty())
+    {
+        return 0.0;
+    }
+
+    const int chars = 3;
+    int counter     = 0;
+    QString spaces  = QString::fromLatin1(" ").repeated(chars - 1);
+    QString aa      = spaces + a + spaces;
+    QString bb      = spaces + b + spaces;
+
+    for (int i = 0 ; i < (aa.count() - (chars - 1)) ; ++i)
+    {
+        QString part = aa.mid(i, chars);
+
+        if (bb.contains(part, Qt::CaseInsensitive))
+        {
+            ++counter;
+        }
+    }
+
+    QString s = (aa.length() < bb.length()) ? aa : bb;
+
+    return (100.0 * counter / (s.length() - (chars - 1)));
+}
+
+// -------------------------------------------------------------------------------
+
 LensFunIface::LensFunIface()
     : d(new Private)
 {
+#if LENSFUN_TEST_VERSION(0,3,99)
+
+    d->lfDb          = lf_db_create();
+
+#else
+
     d->lfDb          = lf_db_new();
 
+#endif
+
     // Lensfun host XML files in a dedicated sub-directory.
 
     QString lensPath = QStandardPaths::locate(QStandardPaths::GenericDataLocation,
@@ -104,9 +197,10 @@ LensFunIface::LensFunIface()
 
     qCDebug(DIGIKAM_DIMG_LOG) << "Using root lens database dir: " << lensPath;
 
-    foreach (const QString& lens, lensDir.entryList())
+    Q_FOREACH (const QString& lens, lensDir.entryList())
     {
         qCDebug(DIGIKAM_DIMG_LOG) << "Load lens database file: " << lens;
+
         d->lfDb->Load(QFile::encodeName(lensDir.absoluteFilePath(lens)).constData());
     }
 
@@ -154,7 +248,8 @@ LensFunIface::LensPtr LensFunIface::usedLens() const
 void LensFunIface::setUsedLens(LensPtr lens)
 {
     d->usedLens            = lens;
-    d->settings.lensModel  = d->usedLens ? QLatin1String(d->usedLens->Model) : QString();
+    d->settings.lensModel  = d->usedLens ? QLatin1String(d->usedLens->Model)
+                                         : QString();
 }
 
 lfDatabase* LensFunIface::lensFunDataBase() const
@@ -197,19 +292,27 @@ LensFunIface::DevicePtr LensFunIface::findCamera(const QString& make, const QStr
     while (cameras && *cameras)
     {
         DevicePtr cam = *cameras;
-//      qCDebug(DIGIKAM_DIMG_LOG) << "Query camera:" << cam->Maker << "-" << cam->Model;
-
-        if ((QString::fromLatin1(cam->Maker).toLower() == make.toLower()) &&
-            (QString::fromLatin1(cam->Model).toLower() == model.toLower()))
+/*
+        qCDebug(DIGIKAM_DIMG_LOG) << "Query camera:" << cam->Maker << "-" << cam->Model;
+*/
+        if (
+            (QString::fromLatin1(cam->Maker).toLower() == make.toLower()) &&
+            (QString::fromLatin1(cam->Model).toLower() == model.toLower())
+           )
         {
-            qCDebug(DIGIKAM_DIMG_LOG) << "Search for camera " << make << "-" << model << " ==> true";
+            qCDebug(DIGIKAM_DIMG_LOG) << "Search for camera "
+                                      << make << "-"
+                                      << model << " ==> true";
             return cam;
         }
 
         ++cameras;
     }
 
-    qCDebug(DIGIKAM_DIMG_LOG) << "Search for camera " << make << "-" << model << " ==> false";
+    qCDebug(DIGIKAM_DIMG_LOG) << "Search for camera "
+                              << make << "-"
+                              << model << " ==> false";
+
     return nullptr;
 }
 
@@ -231,32 +334,11 @@ LensFunIface::LensPtr LensFunIface::findLens(const QString& model) const
     }
 
     qCDebug(DIGIKAM_DIMG_LOG) << "Search for lens " << model << " ==> false";
+
     return nullptr;
 }
 
-LensFunIface::LensList LensFunIface::findLenses(const lfCamera* const lfCamera,
-                                                const QString& lensDesc,
-                                                const QString& lensMaker) const
-{
-    LensList lensList;
-
-    if (lfCamera)
-    {
-        const char* const maker     = lensMaker.isEmpty() ? nullptr : lensMaker.toLatin1().constData();
-        const char* const model     = lensDesc.isEmpty()  ? nullptr : lensDesc.toLatin1().constData();
-        const lfLens* const *lfLens = d->lfDb->FindLenses(lfCamera, maker, model);
-
-        while (lfLens && *lfLens)
-        {
-            lensList << (*lfLens);
-            ++lfLens;
-        }
-    }
-
-    return lensList;
-}
-
-LensFunIface::MetadataMatch LensFunIface::findFromMetadata(DMetadata* const meta)
+LensFunIface::MetadataMatch LensFunIface::findFromMetadata(const DMetadata* const meta)
 {
     MetadataMatch ret  = MetadataNoMatch;
     d->settings        = LensFunContainer();
@@ -267,6 +349,7 @@ LensFunIface::MetadataMatch LensFunIface::findFromMetadata(DMetadata* const meta
     if (!meta || meta->isEmpty())
     {
         qCDebug(DIGIKAM_DIMG_LOG) << "No metadata available";
+
         return LensFunIface::MetadataUnavailable;
     }
 
@@ -283,7 +366,8 @@ LensFunIface::MetadataMatch LensFunIface::findFromMetadata(DMetadata* const meta
     else
     {
         // NOTE: see bug #184156:
-        // Some rules to wrap unknown camera device from Lensfun database, which have equivalent in fact.
+        // Some rules to wrap unknown camera device from Lensfun database,
+        // which have equivalent in fact.
 
         if (d->makeDescription == QLatin1String("Canon"))
         {
@@ -345,46 +429,61 @@ LensFunIface::MetadataMatch LensFunIface::findFromMetadata(DMetadata* const meta
 
                 // STAGE 1, search in LensFun database as well.
 
-                lensList = findLenses(d->usedCamera, d->lensDescription);
-                qCDebug(DIGIKAM_DIMG_LOG) << "* Check for lens by direct query (" << d->lensDescription << " : " << lensList.count() << ")";
+                lensList    = d->findLenses(d->usedCamera, d->lensDescription);
+
+                qCDebug(DIGIKAM_DIMG_LOG) << "* Check for lens by direct query ("
+                                          << d->lensDescription << " : "
+                                          << lensList.count() << ")";
+
                 lensMatches.append(lensList);
 
                 // STAGE 2, Adapt exiv2 strings to lensfun strings for Nikon.
 
-                lensCutted = d->lensDescription;
+                lensCutted  = d->lensDescription;
 
                 if (lensCutted.contains(QLatin1String("Nikon")))
                 {
                     lensCutted.remove(QLatin1String("Nikon "));
                     lensCutted.remove(QLatin1String("Zoom-"));
                     lensCutted.replace(QLatin1String("IF-ID"), QLatin1String("ED-IF"));
-                    lensList = findLenses(d->usedCamera, lensCutted);
-                    qCDebug(DIGIKAM_DIMG_LOG) << "* Check for Nikon lens (" << lensCutted << " : " << lensList.count() << ")";
+                    lensList = d->findLenses(d->usedCamera, lensCutted);
+
+                    qCDebug(DIGIKAM_DIMG_LOG) << "* Check for Nikon lens ("
+                                              << lensCutted << " : "
+                                              << lensList.count() << ")";
+
                     lensMatches.append(lensList);
                 }
 
                 // TODO : Add here more specific lens maker rules.
 
-                // LAST STAGE, Adapt exiv2 strings to lensfun strings. Some lens description use something like that :
+                // LAST STAGE, Adapt exiv2 strings to lensfun strings.
+                // Some lens description use something like that :
                 // "10.0 - 20.0 mm". This must be adapted like this : "10-20mm"
 
-                lensCutted = d->lensDescription;
-                lensCutted.replace(QRegExp(QLatin1String("\\.[0-9]")), QLatin1String("")); //krazy:exclude=doublequote_chars
+                lensCutted  = d->lensDescription;
+                lensCutted.replace(QRegularExpression(QLatin1String("\\.[0-9]")), QLatin1String("")); //krazy:exclude=doublequote_chars
                 lensCutted.replace(QLatin1String(" - "), QLatin1String("-"));
                 lensCutted.replace(QLatin1String(" mm"), QLatin1String("mn"));
-                lensList   = findLenses(d->usedCamera, lensCutted);
-                qCDebug(DIGIKAM_DIMG_LOG) << "* Check for no maker lens (" << lensCutted << " : " << lensList.count() << ")";
+                lensList    = d->findLenses(d->usedCamera, lensCutted);
+
+                qCDebug(DIGIKAM_DIMG_LOG) << "* Check for no maker lens ("
+                                          << lensCutted << " : "
+                                          << lensList.count() << ")";
+
                 lensMatches.append(lensList);
 
                 // Remove all duplicate lenses in the list by using QSet.
 
-                lensMatches = lensMatches.toSet().toList();
+                QSet<const lfLens*> set(lensMatches.begin(), lensMatches.end());
+                lensMatches = QList<const lfLens*>(set.begin(), set.end());
             }
-            else
-            {
-                qCDebug(DIGIKAM_DIMG_LOG) << "Lens description string is empty";
 
-                const LensList lensList = findLenses(d->usedCamera, QString());
+            if (lensMatches.isEmpty())
+            {
+                qCDebug(DIGIKAM_DIMG_LOG) << "Lens description string is empty or no match";
+
+                const LensList lensList = d->findLenses(d->usedCamera, QString());
 
                 if (lensList.count() == 1)
                 {
@@ -393,6 +492,7 @@ LensFunIface::MetadataMatch LensFunIface::findFromMetadata(DMetadata* const meta
                     qCDebug(DIGIKAM_DIMG_LOG) << "For the camera " << d->settings.cameraModel
                                               << " there is exactly one lens in the database: "
                                               << lensList.first()->Model;
+
                     lensMatches.append(lensList);
                 }
                 else
@@ -422,9 +522,9 @@ LensFunIface::MetadataMatch LensFunIface::findFromMetadata(DMetadata* const meta
                 const lfLens* similar = nullptr;
                 double percent        = 0.0;
 
-                foreach (const lfLens* const l, lensMatches)
+                Q_FOREACH (const lfLens* const l, lensMatches)
                 {
-                    double result = checkSimilarity(d->lensDescription, QLatin1String(l->Model));
+                    double result = d->checkSimilarity(d->lensDescription, QLatin1String(l->Model));
 
                     if (result > percent)
                     {
@@ -448,7 +548,9 @@ LensFunIface::MetadataMatch LensFunIface::findFromMetadata(DMetadata* const meta
         }
         else
         {
-            qCDebug(DIGIKAM_DIMG_LOG) << "Cannot find Lensfun camera device for (" << d->makeDescription << " - " << d->modelDescription << ")";
+            qCDebug(DIGIKAM_DIMG_LOG) << "Cannot find Lensfun camera device for ("
+                                      << d->makeDescription << " - "
+                                      << d->modelDescription << ")";
             exactMatch = false;
         }
     }
@@ -464,7 +566,9 @@ LensFunIface::MetadataMatch LensFunIface::findFromMetadata(DMetadata* const meta
         exactMatch = false;
     }
 
-    d->settings.focalLength = temp.mid(0, temp.length() - 3).toDouble(); // HACK: strip the " mm" at the end ...
+    // NOTE: strip the " mm" at the end ...
+    d->settings.focalLength = temp.mid(0, temp.length() - 3).toDouble();
+
     qCDebug(DIGIKAM_DIMG_LOG) << "Focal Length   : " << d->settings.focalLength;
 
     // ------------------------------------------------------------------------------------------------
@@ -545,29 +649,7 @@ LensFunIface::MetadataMatch LensFunIface::findFromMetadata(DMetadata* const meta
 
     ret = exactMatch ? MetadataExactMatch : MetadataPartialMatch;
 
-    qCDebug(DIGIKAM_DIMG_LOG) << "Metadata match : " << metadataMatchDebugStr(ret);
-
-    return ret;
-}
-
-QString LensFunIface::metadataMatchDebugStr(MetadataMatch val) const
-{
-    QString ret;
-
-    switch (val)
-    {
-        case MetadataNoMatch:
-            ret = QLatin1String("No Match");
-            break;
-
-        case MetadataPartialMatch:
-            ret = QLatin1String("Partial Match");
-            break;
-
-        default:
-            ret = QLatin1String("Exact Match");
-            break;
-    }
+    qCDebug(DIGIKAM_DIMG_LOG) << "Metadata match : " << d->metadataMatchDebugStr(ret);
 
     return ret;
 }
@@ -581,7 +663,15 @@ bool LensFunIface::supportsDistortion() const
 
     lfLensCalibDistortion res;
 
-    return d->usedLens->InterpolateDistortion(d->settings.focalLength, res);
+    return d->usedLens->InterpolateDistortion(
+
+#if LENSFUN_TEST_VERSION(0,3,99)
+                                              d->settings.cropFactor,
+#endif
+                                              d->settings.focalLength,
+
+                                              res
+                                             );
 }
 
 bool LensFunIface::supportsCCA() const
@@ -593,7 +683,15 @@ bool LensFunIface::supportsCCA() const
 
     lfLensCalibTCA res;
 
-    return d->usedLens->InterpolateTCA(d->settings.focalLength, res);
+    return d->usedLens->InterpolateTCA(
+
+#if LENSFUN_TEST_VERSION(0,3,99)
+                                       d->settings.cropFactor,
+#endif
+
+                                       d->settings.focalLength,
+                                       res
+                                      );
 }
 
 bool LensFunIface::supportsVig() const
@@ -605,9 +703,17 @@ bool LensFunIface::supportsVig() const
 
     lfLensCalibVignetting res;
 
-    return d->usedLens->InterpolateVignetting(d->settings.focalLength,
+    return d->usedLens->InterpolateVignetting(
+
+#if LENSFUN_TEST_VERSION(0,3,99)
+                                              d->settings.cropFactor,
+#endif
+
+                                              d->settings.focalLength,
                                               d->settings.aperture,
-                                              d->settings.subjectDistance, res);
+                                              d->settings.subjectDistance,
+                                              res
+                                             );
 }
 
 bool LensFunIface::supportsGeometry() const
@@ -617,51 +723,25 @@ bool LensFunIface::supportsGeometry() const
 
 QString LensFunIface::lensFunVersion()
 {
-    return QString::fromLatin1("%1.%2.%3-%4").arg(LF_VERSION_MAJOR)
-           .arg(LF_VERSION_MINOR)
-           .arg(LF_VERSION_MICRO)
-           .arg(LF_VERSION_BUGFIX);
+    return QString::fromLatin1("%1.%2.%3-%4")
+              .arg(LF_VERSION_MAJOR)
+              .arg(LF_VERSION_MINOR)
+              .arg(LF_VERSION_MICRO)
+              .arg(LF_VERSION_BUGFIX);
 }
 
-// Inspired by https://www.qtcentre.org/threads/49601-String-similarity-check
+// Restore warnings with older Lensfun API
 
-double LensFunIface::checkSimilarity(const QString& a, const QString& b) const
-{
-    if (a.isEmpty() || b.isEmpty())
-    {
-        return 0.0;
-    }
+#if !LENSFUN_TEST_VERSION(0,3,99)
 
-    const int chars = 3;
-    int counter     = 0;
+#   if defined(Q_CC_GNU)
+#       pragma GCC diagnostic pop
+#   endif
 
-    QString spaces  = QString::fromLatin1(" ").repeated(chars - 1);
-    QString aa      = spaces + a + spaces;
-    QString bb      = spaces + b + spaces;
+#   if defined(Q_CC_CLANG)
+#       pragma clang diagnostic pop
+#   endif
 
-    for (int i = 0 ; i < (aa.count() - (chars - 1)) ; ++i)
-    {
-        QString part = aa.mid(i, chars);
-
-        if (bb.contains(part, Qt::CaseInsensitive))
-        {
-            ++counter;
-        }
-    }
-
-    QString s = (aa.length() < bb.length()) ? aa : bb;
-
-    return (100.0 * counter / (s.length() - (chars - 1)));
-}
-
-// Restore warnings
-
-#if defined(Q_CC_GNU)
-#   pragma GCC diagnostic pop
-#endif
-
-#if defined(Q_CC_CLANG)
-#   pragma clang diagnostic pop
 #endif
 
 } // namespace Digikam
