@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DPLUGIN_CONF_VIEW_EDITOR_H
-#define DIGIKAM_DPLUGIN_CONF_VIEW_EDITOR_H
+#pragma once
 
 // Qt includes
 
@@ -34,11 +33,9 @@ class DIGIKAM_EXPORT DPluginConfViewEditor : public DPluginConfView
 public:
 
     explicit DPluginConfViewEditor(QWidget* const parent = nullptr);
-    ~DPluginConfViewEditor() override;
+    ~DPluginConfViewEditor() override = default;
 
     void loadPlugins()       override;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_DPLUGIN_CONF_VIEW_EDITOR_H
