@@ -7,7 +7,7 @@
  * Description : Preprocessor for openface nn model
  *
  * SPDX-FileCopyrightText: 2019      by Thanh Trung Dinh <dinhthanhtrung1996 at gmail dot com>
- * SPDX-FileCopyrightText: 2019-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2019-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -17,7 +17,6 @@
 
 // Qt includes
 
-#include <QUrl>
 #include <QFile>
 #include <QTime>
 #include <QString>
@@ -27,7 +26,6 @@
 // Local includes
 
 #include "digikam_debug.h"
-#include "digikam_opencv.h"
 #include "fullobjectdetection.h"
 
 namespace Digikam
@@ -41,9 +39,9 @@ namespace Digikam
   * for matrix faceTemplate below.
   */
 static float FACE_TEMPLATE[3][2] = {
-                                       {18.639072F, 16.249624F},
-                                       {75.73048F,  15.18443F },
-                                       {47.515285F, 49.38637F }
+                                       { 18.639072F, 16.249624F },
+                                       { 75.73048F,  15.18443F  },
+                                       { 47.515285F, 49.38637F  }
                                    };
 
 // ---------------------------------------------------------------------------------------------------
@@ -51,22 +49,18 @@ static float FACE_TEMPLATE[3][2] = {
 OpenfacePreprocessor::OpenfacePreprocessor()
     : outImageSize          (cv::Size(96, 96)),
       faceTemplate          (cv::Mat(3, 2, CV_32F, &FACE_TEMPLATE)),
-      outerEyesNosePositions( {36, 45, 33} )
-{
-}
-
-OpenfacePreprocessor::~OpenfacePreprocessor()
+      outerEyesNosePositions( { 36, 45, 33 } )
 {
 }
 
 bool OpenfacePreprocessor::loadModels()
 {
-    QString appPath = QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation);
-    QUrl    appUrl  = QUrl::fromLocalFile(appPath).adjusted(QUrl::RemoveFilename);
-    appUrl.setPath(appUrl.path() + QLatin1String("digikam/facesengine/"));
+    QString appPath = QStandardPaths::locate(QStandardPaths::GenericDataLocation,
+                                             QLatin1String("digikam/facesengine"),
+                                             QStandardPaths::LocateDirectory);
 
-    QString name    = QLatin1String("shapepredictor.dat");
-    QString spdata  = appUrl.toLocalFile() + name;
+    QString data    = QLatin1String("shapepredictor.dat");
+    QString spdata  = appPath + QLatin1Char('/') + data;
 
     QFile model(spdata);
     RedEye::ShapePredictor* const temp = new RedEye::ShapePredictor();
@@ -85,7 +79,7 @@ bool OpenfacePreprocessor::loadModels()
     {
         delete temp;
 
-        qCCritical(DIGIKAM_FACEDB_LOG) << "Cannot found faces engine model" << name;
+        qCCritical(DIGIKAM_FACEDB_LOG) << "Cannot found faces engine model" << data;
         qCCritical(DIGIKAM_FACEDB_LOG) << "Faces recognition feature cannot be used!";
 
         return false;
@@ -139,7 +133,7 @@ cv::Mat OpenfacePreprocessor::process(const cv::Mat& image)
 /*
         qCDebug(DIGIKAM_FACESENGINE_LOG) << "index = " << index
                                          << ", landmarks: (" << landmarks.at<float>(i, 0)
-                                         << ", " << landmarks.at<float>(i, 1) << ")" << QT_ENDL;
+                                         << ", " << landmarks.at<float>(i, 1) << ")" << Qt::endl;
 */
     }
 
