@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_RECOGNITION_PREPROCESSOR_H
-#define DIGIKAM_RECOGNITION_PREPROCESSOR_H
+#pragma once
 
 #include "facepreprocessor.h"
 
@@ -53,9 +52,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_RECOGNITION_PREPROCESSOR_H
