@@ -6,25 +6,15 @@
  * Date        : 2006-02-23
  * Description : item metadata interface
  *
- * Copyright (C) 2006-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2013      by Veaceslav Munteanu <veaceslav dot munteanu90 at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * SPDX-FileCopyrightText: 2013      by Veaceslav Munteanu <veaceslav dot munteanu90 at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DMETA_DATA_H
-#define DIGIKAM_DMETA_DATA_H
+#pragma once
 
 // Qt includes
 
@@ -33,6 +23,8 @@
 
 // Local includes
 
+#include "digikam_config.h"
+#include "digikam_export.h"
 #include "metaengine.h"
 #include "metaengine_data.h"
 #include "metaenginesettingscontainer.h"
@@ -40,7 +32,6 @@
 #include "captionvalues.h"
 #include "photoinfocontainer.h"
 #include "videoinfocontainer.h"
-#include "digikam_export.h"
 #include "dmetadatasettings.h"
 
 namespace Digikam
@@ -78,7 +69,7 @@ public:
     DMetadata();
     explicit DMetadata(const QString& filePath);
     explicit DMetadata(const MetaEngineData& data);
-    ~DMetadata();
+    ~DMetadata() = default;
 
 public: // Settings helpers
 
@@ -93,7 +84,7 @@ public: // File I/O helpers
      * If backend is non null, return the backend used to populate metadata (Exiv2).
      * See MetaEngine::Backend enum for details.
      */
-    bool load(const QString& filePath, Backend* backend = nullptr);
+    bool load(const QString& filePath, bool videoAll = false, Backend* backend = nullptr);
     bool save(const QString& filePath, bool setVersion = false)                                                         const;
     bool applyChanges(bool setVersion = false)                                                                          const;
 
@@ -229,8 +220,16 @@ public: // IPTC helpers
 
     bool removeIptcTags(const QStringList& tagFilters);
 
+    /**
+     * Return a map of ISO-639-1 2 letters country codes with country names.
+     */
     static CountryCodeMap countryCodeMap();
 
+    /**
+     * Return a map of ISO-639-2 3 letters country codes with country names.
+     */
+    static CountryCodeMap countryCodeMap2();
+
 private:
 
     bool setIptcTag(const QString& text,
@@ -390,6 +389,9 @@ private:
     QVariant fromExifOrXmpList(const QStringList& tagList)                                                              const;
     bool hasValidField(const QVariantList& list)                                                                        const;
     QVariant toStringListVariant(const QStringList& list)                                                               const;
+    QVariant toStringVariant(const QString& str)                                                                        const;
+
+#ifdef HAVE_HEIF
 
 private:
 
@@ -398,14 +400,22 @@ private:
      */
     bool loadUsingLibheif(const QString& filePath);
 
+#endif
+
 private:
 
     /**
      * ImageMagick helper methods.
      */
     bool loadUsingImageMagick(const QString& filePath);
+
+private:
+
+    /**
+     * ExifTool helper methods.
+     */
+    bool loadUsingExifTool(const QString& filePath, bool videoAll = false, bool merge = false);
+    bool saveUsingExifTool(const QString& filePath) const;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_DMETA_DATA_H
