@@ -6,18 +6,9 @@
  * Date        : 2020-12-23
  * Description : item metadata interface - ImageMagick helpers.
  *
- * Copyright (C) 2020-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2020-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -40,11 +31,33 @@
 
 #ifdef HAVE_IMAGE_MAGICK
 
-#include <Magick++.h>
+// Pragma directives to reduce warnings from ImageMagick header files.
+#   if !defined(Q_OS_DARWIN) && defined(Q_CC_GNU)
+#       pragma GCC diagnostic push
+#       pragma GCC diagnostic ignored "-Wignored-qualifiers"
+#       pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
+#   endif
+
+#   if defined(Q_CC_CLANG)
+#       pragma clang diagnostic push
+#       pragma clang diagnostic ignored "-Wignored-qualifiers"
+#       pragma clang diagnostic ignored "-Wkeyword-macro"
+#   endif
+
+#   include <Magick++.h>
 
 using namespace Magick;
 using namespace MagickCore;
 
+// Restore warnings
+#   if !defined(Q_OS_DARWIN) && defined(Q_CC_GNU)
+#       pragma GCC diagnostic pop
+#   endif
+
+#   if defined(Q_CC_CLANG)
+#       pragma clang diagnostic pop
+#   endif
+
 #endif // HAVE_IMAGE_MAGICK
 
 namespace Digikam
@@ -70,7 +83,13 @@ bool DMetadata::loadUsingImageMagick(const QString& filePath)
 
     if (
         !fileInfo.exists() || ext.isEmpty() ||
-        (ext != QLatin1String("FITS"))            // only FITS files
+        rawFilesExt.toUpper().contains(ext) ||    // Ignore RAW files
+        (ext == QLatin1String("HEIF"))      ||    // Ignore HEIF files
+        (ext == QLatin1String("HEIC"))      ||    // Ignore HEIC files
+        (ext == QLatin1String("HIF"))       ||    // Ignore HIF files
+        (ext == QLatin1String("XCF"))       ||    // Ignore XCF files
+        (ext == QLatin1String("SVG"))       ||    // Ignore SVG files
+        (ext == QLatin1String("PDF"))             // Ignore PDF files
        )
     {
         return false;
@@ -191,7 +210,7 @@ bool DMetadata::loadUsingImageMagick(const QString& filePath)
         // This is a fast IM C API call, not the IM CLI tool process.
 /*
         // NOTE: to hack with CLI IM tool
-        qCDebug(DIGIKAM_METAENGINE_LOG) << "IM identify escape format string (" << filters.size() << "bytes):" << endl << filters << endl;
+        qCDebug(DIGIKAM_METAENGINE_LOG) << "IM identify escape format string (" << filters.size() << "bytes):" << Qt::endl << filters << Qt::endl;
 */
         if (IdentifyImageCommand(image_info, identargc, identargv, metadata, &ex) == MagickTrue)
         {
@@ -210,6 +229,7 @@ bool DMetadata::loadUsingImageMagick(const QString& filePath)
                     QString tmp = QString::fromUtf8(metadata[i]);
                     output.append(tmp);
                     lbytes     += tmp.size();
+                    Q_UNUSED(lbytes);
 /*
                     qCDebug(DIGIKAM_METAENGINE_LOG) << "Append new metadata line of" << tmp.size() << "bytes";
                     qCDebug(DIGIKAM_METAENGINE_LOG) << metadata[i];
@@ -224,7 +244,7 @@ bool DMetadata::loadUsingImageMagick(const QString& filePath)
             QString key;
             QString val;
 
-            foreach (const QString& tupple, lines)
+            Q_FOREACH (const QString& tupple, lines)
             {
                 key = tupple.section(QLatin1Char('='), 0, 0);
                 val = tupple.section(QLatin1Char('='), 1, 1);
@@ -240,10 +260,12 @@ bool DMetadata::loadUsingImageMagick(const QString& filePath)
                     val = val.section(QLatin1String(" / "), 0, 0);          // Drop tag description string on the right side (stage2).
                 }
 
-                if (key.isEmpty()                                 ||
+                if (
+                    key.isEmpty()                                 ||
                     key.startsWith(QLatin1String("comment"))      ||
                     key.startsWith(QLatin1String("date:create"))  ||
-                    key.startsWith(QLatin1String("date:modify")))
+                    key.startsWith(QLatin1String("date:modify"))
+                   )
                 {
                     // These tags are already handled with Exif or key or val are empty.
 
@@ -268,8 +290,10 @@ bool DMetadata::loadUsingImageMagick(const QString& filePath)
 
                 // Register XMP tags in container
 
-                if      (key == QLatin1String("Xmp.tiff.ImageDescription") ||
-                         key == QLatin1String("Xmp.exif.UserComment"))
+                if      (
+                         key == QLatin1String("Xmp.tiff.ImageDescription") ||
+                         key == QLatin1String("Xmp.exif.UserComment")
+                        )
                 {
                     setXmpTagStringLangAlt(key.toLatin1().constData(), val, QString());
                 }
@@ -327,6 +351,10 @@ bool DMetadata::loadUsingImageMagick(const QString& filePath)
         ret = false;
     }
 
+#else  // HAVE_IMAGE_MAGICK
+
+    Q_UNUSED(filePath);
+
 #endif // HAVE_IMAGE_MAGICK
 
     return ret;
