@@ -7,7 +7,7 @@
  * Description : Exiv2 library interface.
  *               Exif manipulation methods
  *
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -22,12 +22,6 @@
 
 // Qt includes
 
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
-#   include <QStringEncoder>
-#else
-#   include <QTextCodec>
-#endif
-
 #include <QBuffer>
 
 // KDE includes
@@ -59,7 +53,7 @@ bool MetaEngine::canWriteExif(const QString& filePath)
 
         Exiv2::Image::AutoPtr image = Exiv2::ImageFactory::open((const wchar_t*)filePath.utf16());
 
-#elif defined Q_OS_WIN
+#elif defined __MINGW32__ // krazy:exclude=cpp
 
         Exiv2::Image::AutoPtr image = Exiv2::ImageFactory::open(QFile::encodeName(filePath).constData());
 
@@ -272,13 +266,11 @@ QString MetaEngine::getExifTagComment(const char* exifTagName) const
     return QString();
 }
 
-static bool is7BitAscii(const QByteArray& s)
+static bool is7BitAscii(const QString& s)
 {
-    const int size = s.size();
-
-    for (int i = 0 ; i < size ; ++i)
+    for (int i = 0 ; i < s.size() ; ++i)
     {
-        if (!isascii(s[i]))
+        if (s.at(i).unicode() > 0x7f)
         {
             return false;
         }
@@ -308,35 +300,21 @@ bool MetaEngine::setExifComment(const QString& comment, bool writeDescription) c
             }
 
             // Write as Unicode only when necessary.
+            // Check if it's in the ASCII 7bit range
 
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
-            auto latin1Codec         = QStringEncoder(QStringEncoder::Latin1);
-            QByteArray encodedString = latin1Codec(comment);
-
-            if (!encodedString.isEmpty() && !latin1Codec.hasError())
-#else
-            QTextCodec* const latin1Codec = QTextCodec::codecForName("iso8859-1");
-
-            if (latin1Codec && latin1Codec->canEncode(comment))
-#endif
+            if (is7BitAscii(comment))
             {
-                // We know it's in the ISO-8859-1 8bit range.
-                // Check if it's in the ASCII 7bit range
+                // write as ASCII
 
-                if (is7BitAscii(comment.toLatin1()))
-                {
-                    // write as ASCII
+                QString exifComment(QString::fromLatin1("charset=Ascii %1").arg(comment));
+                d->exifMetadata()["Exif.Photo.UserComment"] = exifComment.toStdString();
 
-                    QString exifComment(QString::fromLatin1("charset=\"Ascii\" %1").arg(comment));
-                    d->exifMetadata()["Exif.Photo.UserComment"] = exifComment.toStdString();
-
-                    return true;
-                }
+                return true;
             }
 
             // write as Unicode (UCS-2)
 
-            QString exifComment(QString::fromUtf8("charset=\"Unicode\" %1").arg(comment));
+            QString exifComment(QString::fromUtf8("charset=Unicode %1").arg(comment));
             d->exifMetadata()["Exif.Photo.UserComment"] = exifComment.toStdString();
         }
 
@@ -484,6 +462,28 @@ bool MetaEngine::setExifTagLong(const char* exifTagName, long val) const
     return false;
 }
 
+bool MetaEngine::setExifTagUShort(const char* exifTagName, unsigned int val) const
+{
+    QMutexLocker lock(&s_metaEngineMutex);
+
+    try
+    {
+        d->exifMetadata()[exifTagName] = static_cast<uint16_t>(val);     // krazy:exclude=typedefs
+
+        return true;
+    }
+    catch (Exiv2::AnyError& e)
+    {
+        d->printExiv2ExceptionError(QLatin1String("Cannot set Exif tag unsigned short value into image with Exiv2:"), e);
+    }
+    catch (...)
+    {
+        qCCritical(DIGIKAM_METAENGINE_LOG) << "Default exception from Exiv2";
+    }
+
+    return false;
+}
+
 bool MetaEngine::setExifTagRational(const char* exifTagName, long int num, long int den) const
 {
     QMutexLocker lock(&s_metaEngineMutex);
@@ -506,6 +506,28 @@ bool MetaEngine::setExifTagRational(const char* exifTagName, long int num, long
     return false;
 }
 
+bool MetaEngine::setExifTagURational(const char* exifTagName, unsigned long int num, unsigned long int den) const
+{
+    QMutexLocker lock(&s_metaEngineMutex);
+
+    try
+    {
+        d->exifMetadata()[exifTagName] = Exiv2::URational(num, den);
+
+        return true;
+    }
+    catch (Exiv2::AnyError& e)
+    {
+        d->printExiv2ExceptionError(QLatin1String("Cannot set Exif tag unsigned rational value into image with Exiv2:"), e);
+    }
+    catch (...)
+    {
+        qCCritical(DIGIKAM_METAENGINE_LOG) << "Default exception from Exiv2";
+    }
+
+    return false;
+}
+
 bool MetaEngine::setExifTagData(const char* exifTagName, const QByteArray& data) const
 {
     if (data.isEmpty())
@@ -537,11 +559,17 @@ bool MetaEngine::setExifTagData(const char* exifTagName, const QByteArray& data)
 bool MetaEngine::setExifTagVariant(const char* exifTagName, const QVariant& val,
                                    bool rationalWantSmallDenominator) const
 {
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
     switch (val.typeId())
+
 #else
+
     switch (val.type())
+
 #endif
+
     {
         case QVariant::Int:
         case QVariant::UInt:
@@ -554,7 +582,8 @@ bool MetaEngine::setExifTagVariant(const char* exifTagName, const QVariant& val,
 
         case QVariant::Double:
         {
-            long num, den;
+            long num = 0;
+            long den = 1;
 
             if (rationalWantSmallDenominator)
             {
@@ -570,7 +599,8 @@ bool MetaEngine::setExifTagVariant(const char* exifTagName, const QVariant& val,
 
         case QVariant::List:
         {
-            long num = 0, den = 1;
+            long num = 0;
+            long den = 1;
             QList<QVariant> list = val.toList();
 
             if (list.size() >= 1)
@@ -589,7 +619,7 @@ bool MetaEngine::setExifTagVariant(const char* exifTagName, const QVariant& val,
         case QVariant::Date:
         case QVariant::DateTime:
         {
-            QDateTime dateTime = val.toDateTime();
+            QDateTime dateTime = asDateTimeUTC(val.toDateTime());
 
             if (!dateTime.isValid())
             {
@@ -641,11 +671,16 @@ QString MetaEngine::createExifUserStringFromValue(const char* exifTagName, const
         Exiv2::ExifKey key(exifTagName);
         Exiv2::Exifdatum datum(key);
 
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
         switch (val.typeId())
+
 #else
+
         switch (val.type())
+
 #endif
+
         {
             case QVariant::Int:
             case QVariant::Bool:
@@ -699,7 +734,7 @@ QString MetaEngine::createExifUserStringFromValue(const char* exifTagName, const
             case QVariant::Date:
             case QVariant::DateTime:
             {
-                QDateTime dateTime = val.toDateTime();
+                QDateTime dateTime = asDateTimeUTC(val.toDateTime());
 
                 if (!dateTime.isValid())
                 {
@@ -764,11 +799,17 @@ bool MetaEngine::getExifTagLong(const char* exifTagName, long& val, int componen
 
         if ((it != exifData.end()) && (it->count() > 0))
         {
+
 #if EXIV2_TEST_VERSION(0,27,99)
+
             val = it->toInt64(component);
+
 #else
+
             val = it->toLong(component);
+
 #endif
+
             return true;
         }
     }
@@ -838,19 +879,31 @@ QVariant MetaEngine::getExifTagVariant(const char* exifTagName, bool rationalAsL
                 {
                     if ((int)it->count() > component)
                     {
+
 #if EXIV2_TEST_VERSION(0,27,99)
+
                         return QVariant((int)it->toInt64(component));
+
 #else
+
                         return QVariant((int)it->toLong(component));
+
 #endif
+
                     }
                     else
                     {
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
                         return QVariant(QMetaType(QMetaType::Int));
+
 #else
+
                         return QVariant(QVariant::Int);
+
 #endif
+
                     }
                 }
 
@@ -861,32 +914,49 @@ QVariant MetaEngine::getExifTagVariant(const char* exifTagName, bool rationalAsL
                     {
                         if ((int)it->count() <= component)
                         {
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
                             return QVariant(QMetaType(QMetaType::QVariantList));
+
 #else
+
                             return QVariant(QVariant::List);
+
 #endif
+
                         }
 
                         QList<QVariant> list;
                         list << (*it).toRational(component).first;
                         list << (*it).toRational(component).second;
 
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
                         return QVariant(QMetaType(QMetaType::QVariantList));
+
 #else
+
                         return QVariant(list);
+
 #endif
+
                     }
                     else
                     {
                         if ((int)it->count() <= component)
                         {
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
                             return QVariant(QMetaType(QMetaType::Double));
+
 #else
+
                             return QVariant(QVariant::Double);
+
 #endif
+
                         }
 
                         // prefer double precision
@@ -896,11 +966,17 @@ QVariant MetaEngine::getExifTagVariant(const char* exifTagName, bool rationalAsL
 
                         if (den == 0.0)
                         {
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
                             return QVariant(QMetaType(QMetaType::Double));
+
 #else
+
                             return QVariant(QVariant::Double);
+
 #endif
+
                         }
 
                         return QVariant(num / den);
@@ -911,7 +987,8 @@ QVariant MetaEngine::getExifTagVariant(const char* exifTagName, bool rationalAsL
                 case Exiv2::time:
                 {
                     QDateTime dateTime = QDateTime::fromString(QString::fromStdString(it->toString()), Qt::ISODate);
-                    return QVariant(dateTime);
+
+                    return QVariant(asDateTimeUTC(dateTime));
                 }
 
                 case Exiv2::asciiString:
@@ -967,11 +1044,17 @@ QString MetaEngine::getExifTagString(const char* exifTagName, bool escapeCR) con
 
             if (
                 (key == QLatin1String("Exif.CanonCs.LensType")) &&
+
 #if EXIV2_TEST_VERSION(0,27,99)
+
                 (it->toInt64() == 65535)
+
 #else
+
                 (it->toLong()  == 65535)
+
 #endif
+
                )
             {
                 // FIXME: workaround for a possible crash in Exiv2 pretty-print function for the Exif.CanonCs.LensType.
@@ -1045,19 +1128,23 @@ QImage MetaEngine::getExifThumbnail(bool fixOrientation) const
         Exiv2::DataBuf const c1 = thumb.copy();
 
 #if EXIV2_TEST_VERSION(0,27,99)
+
         if (c1.size() == 0)
         {
             return thumbnail;
         }
 
         thumbnail.loadFromData(c1.c_data(), c1.size());
+
 #else
+
         if (c1.size_ == 0)
         {
             return thumbnail;
         }
 
         thumbnail.loadFromData(c1.pData_, c1.size_);
+
 #endif
 
         if (!thumbnail.isNull())
@@ -1076,10 +1163,15 @@ QImage MetaEngine::getExifThumbnail(bool fixOrientation) const
 
                 if (it != exifData.end() && it->count())
                 {
+
 #if EXIV2_TEST_VERSION(0,27,99)
+
                     long orientation = it->toInt64();
+
 #else
+
                     long orientation = it->toLong();
+
 #endif
 
                     //qCDebug(DIGIKAM_METAENGINE_LOG) << "Exif Thumbnail Orientation: " << (int)orientation;
@@ -1165,11 +1257,17 @@ bool MetaEngine::setTiffThumbnail(const QImage& thumbImage) const
         if (
             (pos            == d->exifMetadata().end()) ||
             (pos->count()   != 1)                       ||
+
 #if EXIV2_TEST_VERSION(0,27,99)
+
             (pos->toInt64() != 0)
+
 #else
+
             (pos->toLong()  != 0)
+
 #endif
+
            )
         {
 
@@ -1214,17 +1312,29 @@ bool MetaEngine::setTiffThumbnail(const QImage& thumbImage) const
             Exiv2::DataBuf buf((Exiv2::byte*)data.data(), data.size());
             Exiv2::ULongValue val;
             val.read("0");
+
 #if EXIV2_TEST_VERSION(0,27,99)
+
             val.setDataArea(buf.data(), buf.size());
+
 #else
+
             val.setDataArea(buf.pData_, buf.size_);
+
 #endif
+
             d->exifMetadata()["Exif.SubImage1.JPEGInterchangeFormat"]       = val;
+
 #if EXIV2_TEST_VERSION(0,27,99)
+
             d->exifMetadata()["Exif.SubImage1.JPEGInterchangeFormatLength"] = uint32_t(buf.size());
+
 #else
+
             d->exifMetadata()["Exif.SubImage1.JPEGInterchangeFormatLength"] = uint32_t(buf.size_);
+
 #endif
+
             d->exifMetadata()["Exif.SubImage1.Compression"]                 = uint16_t(6);          // JPEG (old-style)
             d->exifMetadata()["Exif.SubImage1.NewSubfileType"]              = uint32_t(1);          // Thumbnail image
 
@@ -1290,7 +1400,7 @@ MetaEngine::MetaDataMap MetaEngine::getExifTagsDataList(const QStringList& exifK
         QString            key;
         QString            tagValue;
         double             num   = 0.0;
-        double             den   = 0.0;
+        double             den   = 1.0;
 
         for (Exiv2::ExifData::const_iterator md = exifData.begin() ; md != exifData.end() ; ++md)
         {
@@ -1314,8 +1424,10 @@ MetaEngine::MetaDataMap MetaEngine::getExifTagsDataList(const QStringList& exifK
 
                 tagValue = d->convertCommentValue(*md);
             }
-            else if ((key == QLatin1String("Exif.GPSInfo.GPSTrack"))      ||
-                     (key == QLatin1String("Exif.GPSInfo.GPSImgDirection")))
+            else if (
+                     (key == QLatin1String("Exif.GPSInfo.GPSTrack"))      ||
+                     (key == QLatin1String("Exif.GPSInfo.GPSImgDirection"))
+                    )
             {
                 // NOTE: special cases to render contents of these GPS info tags. See bug #435317.
                 // Check value byte size, otherwise Exiv2 crashes in the toRational() function.
@@ -1349,11 +1461,17 @@ MetaEngine::MetaDataMap MetaEngine::getExifTagsDataList(const QStringList& exifK
             }
             else if (
                      (key           == QLatin1String("Exif.CanonCs.LensType")) && 
+
 #if EXIV2_TEST_VERSION(0,27,99)
+
                      (md->toInt64() == 65535)
+
 #else
+
                      (md->toLong()  == 65535)
+
 #endif
+
                     )
             {
                 // FIXME: workaround for a possible crash in Exiv2 pretty-print function for the Exif.CanonCs.LensType.
@@ -1462,6 +1580,10 @@ MetaEngine::TagsMap MetaEngine::getStdExifTagsList() const
                     values << QLatin1String(ti->name_) << QLatin1String(ti->title_) << QLatin1String(ti->desc_);
                     tagsMap.insert(key, values);
                 }
+                else
+                {
+                    break;
+                }
 
                 ++(*it);
             }
@@ -1523,6 +1645,10 @@ MetaEngine::TagsMap MetaEngine::getMakernoteTagsList() const
                     values << QLatin1String(ti->name_) << QLatin1String(ti->title_) << QLatin1String(ti->desc_);
                     tagsMap.insert(key, values);
                 }
+                else
+                {
+                    break;
+                }
 
                 ++(*it);
             }
