@@ -7,7 +7,7 @@
  * Description : Exiv2 library interface.
  *               Common metadata image information manipulation methods
  *
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -47,7 +47,7 @@ bool MetaEngine::setItemProgramId(const QString& program, const QString& version
 
         d->exifMetadata()["Exif.Image.ProcessingSoftware"] = std::string(software.toLatin1().constData());
 
-        // See B.K.O #142564: Check if Exif.Image.Software already exist. If yes, do not touch this tag.
+        // See bug #142564: Check if Exif.Image.Software already exist. If yes, do not touch this tag.
 
         if (!d->exifMetadata().empty())
         {
@@ -68,6 +68,7 @@ bool MetaEngine::setItemProgramId(const QString& program, const QString& version
         if (!d->xmpMetadata().empty())
         {
             // Only create Xmp.xmp.CreatorTool if it do not exist.
+
             Exiv2::XmpData xmpData(d->xmpMetadata());
             Exiv2::XmpKey key("Xmp.xmp.CreatorTool");
             Exiv2::XmpData::const_iterator it = xmpData.findKey(key);
@@ -118,11 +119,17 @@ QSize MetaEngine::getItemDimensions() const
 
         if ((it != exifData.end()) && it->count())
         {
+
 #if EXIV2_TEST_VERSION(0,27,99)
+
             width = it->toInt64();
+
 #else
+
             width = it->toLong();
+
 #endif
+
         }
 
         Exiv2::ExifKey key2("Exif.Photo.PixelYDimension");
@@ -130,11 +137,17 @@ QSize MetaEngine::getItemDimensions() const
 
         if ((it2 != exifData.end()) && it2->count())
         {
+
 #if EXIV2_TEST_VERSION(0,27,99)
+
             height = it2->toInt64();
+
 #else
+
             height = it2->toLong();
+
 #endif
+
         }
 
         if ((width != -1) && (height != -1))
@@ -152,11 +165,17 @@ QSize MetaEngine::getItemDimensions() const
 
         if ((it3 != exifData.end()) && it3->count())
         {
+
 #if EXIV2_TEST_VERSION(0,27,99)
+
             width = it3->toInt64();
+
 #else
+
             width = it3->toLong();
+
 #endif
+
         }
 
         Exiv2::ExifKey key4("Exif.Image.ImageLength");
@@ -164,11 +183,17 @@ QSize MetaEngine::getItemDimensions() const
 
         if ((it4 != exifData.end()) && it4->count())
         {
+
 #if EXIV2_TEST_VERSION(0,27,99)
+
             height = it4->toInt64();
+
 #else
+
             height = it4->toLong();
+
 #endif
+
         }
 
         if ((width != -1) && (height != -1))
@@ -253,7 +278,7 @@ bool MetaEngine::setItemDimensions(const QSize& size) const
     {
         // Set Exif values.
 
-        // NOTE: see B.K.O #144604: need to cast to record an unsigned integer value.
+        // NOTE: see bug #144604: need to cast to record an unsigned integer value.
 
         d->exifMetadata()["Exif.Image.ImageWidth"]      = static_cast<uint32_t>(size.width());
         d->exifMetadata()["Exif.Image.ImageLength"]     = static_cast<uint32_t>(size.height());
@@ -327,10 +352,15 @@ MetaEngine::ImageOrientation MetaEngine::getItemOrientation() const
 
         if ((it != exifData.end()) && it->count())
         {
+
 #if EXIV2_TEST_VERSION(0,27,99)
+
             orientation = it->toInt64();
+
 #else
+
             orientation = it->toLong();
+
 #endif
 
             //qCDebug(DIGIKAM_METAENGINE_LOG) << "Orientation => Exif.MinoltaCs7D.Rotation =>" << (int)orientation;
@@ -358,10 +388,15 @@ MetaEngine::ImageOrientation MetaEngine::getItemOrientation() const
 
         if ((it != exifData.end()) && it->count())
         {
+
 #if EXIV2_TEST_VERSION(0,27,99)
+
             orientation = it->toInt64();
+
 #else
+
             orientation = it->toLong();
+
 #endif
 
             //qCDebug(DIGIKAM_METAENGINE_LOG) << "Orientation => Exif.MinoltaCs5D.Rotation =>" << (int)orientation;
@@ -391,10 +426,15 @@ MetaEngine::ImageOrientation MetaEngine::getItemOrientation() const
 
         if ((it != exifData.end()) && it->count())
         {
+
 #if EXIV2_TEST_VERSION(0,27,99)
+
             orientation = it->toInt64();
+
 #else
+
             orientation = it->toLong();
+
 #endif
 
             //qCDebug(DIGIKAM_METAENGINE_LOG) << "Orientation => Exif.Image.Orientation =>" << (int)orientation;
@@ -497,6 +537,7 @@ MetaEngine::ImageColorWorkSpace MetaEngine::getItemColorWorkSpace() const
 
     if (!getExifTagLong("Exif.Photo.ColorSpace", exifColorSpace))
     {
+
 #ifdef _XMP_SUPPORT_
 
         QVariant var = getXmpTagVariant("Xmp.exif.ColorSpace");
@@ -507,6 +548,7 @@ MetaEngine::ImageColorWorkSpace MetaEngine::getItemColorWorkSpace() const
         }
 
 #endif // _XMP_SUPPORT_
+
     }
 
     if      (exifColorSpace == 1)
@@ -646,8 +688,9 @@ QDateTime MetaEngine::getItemDateTime() const
 
                 if (it != exifData.end())
                 {
-                    QDateTime dateTime = QDateTime::fromString(QString::fromStdString(it->toString()), Qt::ISODate);
-                    dateMap.insert(dateTime, dateMap.value(dateTime, 0) + 2);
+                    QDateTime dateTime = asDateTimeUTC(QDateTime::fromString(QString::fromStdString(it->toString()),
+                                                                             Qt::ISODate));
+                    dateMap.insert(dateTime, dateMap.value(dateTime, 0) + 4);
 
                     if (dateTime.isValid())
                     {
@@ -661,10 +704,11 @@ QDateTime MetaEngine::getItemDateTime() const
 
                 if (it != exifData.end())
                 {
-                    QDateTime dateTime = QDateTime::fromString(QString::fromStdString(it->toString()), Qt::ISODate);
+                    QDateTime dateTime = asDateTimeUTC(QDateTime::fromString(QString::fromStdString(it->toString()),
+                                                                             Qt::ISODate));
                     dateMap.insert(dateTime, dateMap.value(dateTime, 0) + 1);
 
-                    if (dateTime.isValid() && dateMap.value(dateTime) > 2)
+                    if (dateTime.isValid() && dateMap.value(dateTime) > 4)
                     {
                         //qCDebug(DIGIKAM_METAENGINE_LOG) << "DateTime => Exif.Photo.DateTimeDigitized =>" << dateTime;
 
@@ -678,10 +722,11 @@ QDateTime MetaEngine::getItemDateTime() const
 
                 if (it != exifData.end())
                 {
-                    QDateTime dateTime = QDateTime::fromString(QString::fromStdString(it->toString()), Qt::ISODate);
+                    QDateTime dateTime = asDateTimeUTC(QDateTime::fromString(QString::fromStdString(it->toString()),
+                                                                             Qt::ISODate));
                     dateMap.insert(dateTime, dateMap.value(dateTime, 0) + 1);
 
-                    if (dateTime.isValid() && dateMap.value(dateTime) > 2)
+                    if (dateTime.isValid() && dateMap.value(dateTime) > 4)
                     {
                         //qCDebug(DIGIKAM_METAENGINE_LOG) << "DateTime => Exif.Image.DateTime =>" << dateTime;
 
@@ -704,10 +749,11 @@ QDateTime MetaEngine::getItemDateTime() const
 
                 if (it != xmpData.end())
                 {
-                    QDateTime dateTime = QDateTime::fromString(QString::fromStdString(it->toString()), Qt::ISODate);
+                    QDateTime dateTime = asDateTimeUTC(QDateTime::fromString(QString::fromStdString(it->toString()),
+                                                                             Qt::ISODate));
                     dateMap.insert(dateTime, dateMap.value(dateTime, 0) + 2);
 
-                    if (dateTime.isValid() && (dateMap.value(dateTime) > 2))
+                    if (dateTime.isValid() && (dateMap.value(dateTime) > 4))
                     {
                         //qCDebug(DIGIKAM_METAENGINE_LOG) << "DateTime => Xmp.exif.DateTimeOriginal =>" << dateTime;
 
@@ -721,10 +767,11 @@ QDateTime MetaEngine::getItemDateTime() const
 
                 if (it != xmpData.end())
                 {
-                    QDateTime dateTime = QDateTime::fromString(QString::fromStdString(it->toString()), Qt::ISODate);
+                    QDateTime dateTime = asDateTimeUTC(QDateTime::fromString(QString::fromStdString(it->toString()),
+                                                                             Qt::ISODate));
                     dateMap.insert(dateTime, dateMap.value(dateTime, 0) + 1);
 
-                    if (dateTime.isValid() && (dateMap.value(dateTime) > 2))
+                    if (dateTime.isValid() && (dateMap.value(dateTime) > 4))
                     {
                         //qCDebug(DIGIKAM_METAENGINE_LOG) << "DateTime => Xmp.exif.DateTimeDigitized =>" << dateTime;
 
@@ -738,10 +785,11 @@ QDateTime MetaEngine::getItemDateTime() const
 
                 if (it != xmpData.end())
                 {
-                    QDateTime dateTime = QDateTime::fromString(QString::fromStdString(it->toString()), Qt::ISODate);
+                    QDateTime dateTime = asDateTimeUTC(QDateTime::fromString(QString::fromStdString(it->toString()),
+                                                                             Qt::ISODate));
                     dateMap.insert(dateTime, dateMap.value(dateTime, 0) + 1);
 
-                    if (dateTime.isValid() && (dateMap.value(dateTime) > 2))
+                    if (dateTime.isValid() && (dateMap.value(dateTime) > 4))
                     {
                         //qCDebug(DIGIKAM_METAENGINE_LOG) << "DateTime => Xmp.photoshop.DateCreated =>" << dateTime;
 
@@ -755,10 +803,11 @@ QDateTime MetaEngine::getItemDateTime() const
 
                 if (it != xmpData.end())
                 {
-                    QDateTime dateTime = QDateTime::fromString(QString::fromStdString(it->toString()), Qt::ISODate);
+                    QDateTime dateTime = asDateTimeUTC(QDateTime::fromString(QString::fromStdString(it->toString()),
+                                                                             Qt::ISODate));
                     dateMap.insert(dateTime, dateMap.value(dateTime, 0) + 1);
 
-                    if (dateTime.isValid() && (dateMap.value(dateTime) > 2))
+                    if (dateTime.isValid() && (dateMap.value(dateTime) > 4))
                     {
                         //qCDebug(DIGIKAM_METAENGINE_LOG) << "DateTime => Xmp.xmp.CreateDate =>" << dateTime;
 
@@ -772,10 +821,11 @@ QDateTime MetaEngine::getItemDateTime() const
 
                 if (it != xmpData.end())
                 {
-                    QDateTime dateTime = QDateTime::fromString(QString::fromStdString(it->toString()), Qt::ISODate);
+                    QDateTime dateTime = asDateTimeUTC(QDateTime::fromString(QString::fromStdString(it->toString()),
+                                                                             Qt::ISODate));
                     dateMap.insert(dateTime, dateMap.value(dateTime, 0) + 1);
 
-                    if (dateTime.isValid() && (dateMap.value(dateTime) > 2))
+                    if (dateTime.isValid() && (dateMap.value(dateTime) > 4))
                     {
                         //qCDebug(DIGIKAM_METAENGINE_LOG) << "DateTime => Xmp.tiff.DateTime =>" << dateTime;
 
@@ -789,10 +839,11 @@ QDateTime MetaEngine::getItemDateTime() const
 
                 if (it != xmpData.end())
                 {
-                    QDateTime dateTime = QDateTime::fromString(QString::fromStdString(it->toString()), Qt::ISODate);
+                    QDateTime dateTime = asDateTimeUTC(QDateTime::fromString(QString::fromStdString(it->toString()),
+                                                                             Qt::ISODate));
                     dateMap.insert(dateTime, dateMap.value(dateTime, 0) + 1);
 
-                    if (dateTime.isValid() && (dateMap.value(dateTime) > 2))
+                    if (dateTime.isValid() && (dateMap.value(dateTime) > 4))
                     {
                         //qCDebug(DIGIKAM_METAENGINE_LOG) << "DateTime => Xmp.xmp.ModifyDate =>" << dateTime;
 
@@ -806,10 +857,11 @@ QDateTime MetaEngine::getItemDateTime() const
 
                 if (it != xmpData.end())
                 {
-                    QDateTime dateTime = QDateTime::fromString(QString::fromStdString(it->toString()), Qt::ISODate);
+                    QDateTime dateTime = asDateTimeUTC(QDateTime::fromString(QString::fromStdString(it->toString()),
+                                                                             Qt::ISODate));
                     dateMap.insert(dateTime, dateMap.value(dateTime, 0) + 1);
 
-                    if (dateTime.isValid() && (dateMap.value(dateTime) > 2))
+                    if (dateTime.isValid() && (dateMap.value(dateTime) > 4))
                     {
                         //qCDebug(DIGIKAM_METAENGINE_LOG) << "DateTime => Xmp.xmp.MetadataDate =>" << dateTime;
 
@@ -826,10 +878,11 @@ QDateTime MetaEngine::getItemDateTime() const
 
                 if (it != xmpData.end())
                 {
-                    QDateTime dateTime = QDateTime::fromString(QString::fromStdString(it->toString()), Qt::ISODate);
+                    QDateTime dateTime = asDateTimeUTC(QDateTime::fromString(QString::fromStdString(it->toString()),
+                                                                             Qt::ISODate));
                     dateMap.insert(dateTime, dateMap.value(dateTime, 0) + 2);
 
-                    if (dateTime.isValid() && (dateMap.value(dateTime) > 2))
+                    if (dateTime.isValid() && (dateMap.value(dateTime) > 4))
                     {
                         //qCDebug(DIGIKAM_METAENGINE_LOG) << "DateTime => Xmp.video.DateTimeOriginal =>" << dateTime;
 
@@ -843,10 +896,11 @@ QDateTime MetaEngine::getItemDateTime() const
 
                 if (it != xmpData.end())
                 {
-                    QDateTime dateTime = QDateTime::fromString(QString::fromStdString(it->toString()), Qt::ISODate);
+                    QDateTime dateTime = asDateTimeUTC(QDateTime::fromString(QString::fromStdString(it->toString()),
+                                                                             Qt::ISODate));
                     dateMap.insert(dateTime, dateMap.value(dateTime, 0) + 1);
 
-                    if (dateTime.isValid() && (dateMap.value(dateTime) > 2))
+                    if (dateTime.isValid() && (dateMap.value(dateTime) > 4))
                     {
                         //qCDebug(DIGIKAM_METAENGINE_LOG) << "DateTime => Xmp.video.DateUTC =>" << dateTime;
 
@@ -860,10 +914,11 @@ QDateTime MetaEngine::getItemDateTime() const
 
                 if (it != xmpData.end())
                 {
-                    QDateTime dateTime = QDateTime::fromString(QString::fromStdString(it->toString()), Qt::ISODate);
+                    QDateTime dateTime = asDateTimeUTC(QDateTime::fromString(QString::fromStdString(it->toString()),
+                                                                             Qt::ISODate));
                     dateMap.insert(dateTime, dateMap.value(dateTime, 0) + 1);
 
-                    if (dateTime.isValid() && (dateMap.value(dateTime) > 2))
+                    if (dateTime.isValid() && (dateMap.value(dateTime) > 4))
                     {
                         //qCDebug(DIGIKAM_METAENGINE_LOG) << "DateTime => Xmp.video.ModificationDate =>" << dateTime;
 
@@ -877,10 +932,11 @@ QDateTime MetaEngine::getItemDateTime() const
 
                 if (it != xmpData.end())
                 {
-                    QDateTime dateTime = QDateTime::fromString(QString::fromStdString(it->toString()), Qt::ISODate);
+                    QDateTime dateTime = asDateTimeUTC(QDateTime::fromString(QString::fromStdString(it->toString()),
+                                                                             Qt::ISODate));
                     dateMap.insert(dateTime, dateMap.value(dateTime, 0) + 1);
 
-                    if (dateTime.isValid() && (dateMap.value(dateTime) > 2))
+                    if (dateTime.isValid() && (dateMap.value(dateTime) > 4))
                     {
                         //qCDebug(DIGIKAM_METAENGINE_LOG) << "DateTime => Xmp.video.DateTimeDigitized =>" << dateTime;
 
@@ -914,10 +970,10 @@ QDateTime MetaEngine::getItemDateTime() const
                     QString IptcTimeCreated(QString::fromStdString(it2->toString()));
                     QDate date         = QDate::fromString(IptcDateCreated, Qt::ISODate);
                     QTime time         = QTime::fromString(IptcTimeCreated, Qt::ISODate);
-                    QDateTime dateTime = QDateTime(date, time);
+                    QDateTime dateTime = asDateTimeUTC(QDateTime(date, time));
                     dateMap.insert(dateTime, dateMap.value(dateTime, 0) + 1);
 
-                    if (dateTime.isValid() && (dateMap.value(dateTime) > 2))
+                    if (dateTime.isValid() && (dateMap.value(dateTime) > 4))
                     {
                         //qCDebug(DIGIKAM_METAENGINE_LOG) << "DateTime => Iptc.Application2.DateCreated =>" << dateTime;
 
@@ -942,10 +998,10 @@ QDateTime MetaEngine::getItemDateTime() const
                     QString IptcTimeDigitization(QString::fromStdString(it4->toString()));
                     QDate date         = QDate::fromString(IptcDateDigitization, Qt::ISODate);
                     QTime time         = QTime::fromString(IptcTimeDigitization, Qt::ISODate);
-                    QDateTime dateTime = QDateTime(date, time);
+                    QDateTime dateTime = asDateTimeUTC(QDateTime(date, time));
                     dateMap.insert(dateTime, dateMap.value(dateTime, 0) + 1);
 
-                    if (dateTime.isValid() && (dateMap.value(dateTime) > 2))
+                    if (dateTime.isValid() && (dateMap.value(dateTime) > 4))
                     {
                         //qCDebug(DIGIKAM_METAENGINE_LOG) << "DateTime => Iptc.Application2.DigitizationDate =>" << dateTime;
 
@@ -1012,7 +1068,8 @@ bool MetaEngine::setImageDateTime(const QDateTime& dateTime, bool setDateTimeDig
         // For digital cameras, these dates should be both set, and identical.
         // Reference: https://www.exif.org/Exif2-2.PDF, chapter 4.6.5, table 4, section F.
 
-        const std::string& exifdatetime(dateTime.toString(QString::fromLatin1("yyyy:MM:dd hh:mm:ss")).toLatin1().constData());
+        const std::string& exifdatetime(asDateTimeLocal(dateTime)
+                                        .toString(QLatin1String("yyyy:MM:dd hh:mm:ss")).toLatin1().constData());
         d->exifMetadata()["Exif.Image.DateTime"]         = exifdatetime;
         d->exifMetadata()["Exif.Photo.DateTimeOriginal"] = exifdatetime;
 
@@ -1025,7 +1082,7 @@ bool MetaEngine::setImageDateTime(const QDateTime& dateTime, bool setDateTimeDig
 
         // In second we write date & time into Xmp.
 
-        const std::string& xmpdatetime(dateTime.toString(Qt::ISODate).toLatin1().constData());
+        const std::string& xmpdatetime(asDateTimeLocal(dateTime).toString(Qt::ISODate).toLatin1().constData());
 
         Exiv2::Value::AutoPtr xmpTxtVal = Exiv2::Value::create(Exiv2::xmpText);
         xmpTxtVal->read(xmpdatetime);
@@ -1044,8 +1101,10 @@ bool MetaEngine::setImageDateTime(const QDateTime& dateTime, bool setDateTimeDig
         // We call this function from the FFmpeg parser and we don't have a filename yet.
         // Check getFilePath() for empty.
 
-        if (getFilePath().isEmpty() ||
-            QMimeDatabase().mimeTypeForFile(getFilePath()).name().startsWith(QLatin1String("video/")))
+        if (
+            getFilePath().isEmpty() ||
+            QMimeDatabase().mimeTypeForFile(getFilePath()).name().startsWith(QLatin1String("video/"))
+           )
         {
             d->xmpMetadata().add(Exiv2::XmpKey("Xmp.video.DateTimeOriginal"), xmpTxtVal.get());
             d->xmpMetadata().add(Exiv2::XmpKey("Xmp.video.DateUTC"),          xmpTxtVal.get());
@@ -1065,8 +1124,8 @@ bool MetaEngine::setImageDateTime(const QDateTime& dateTime, bool setDateTimeDig
 
         // In third we write date & time into Iptc.
 
-        const std::string& iptcdate(dateTime.date().toString(Qt::ISODate).toLatin1().constData());
-        const std::string& iptctime(dateTime.time().toString(Qt::ISODate).toLatin1().constData());
+        const std::string& iptcdate(asDateTimeLocal(dateTime).date().toString(Qt::ISODate).toLatin1().constData());
+        const std::string& iptctime(asDateTimeLocal(dateTime).time().toString(Qt::ISODate).toLatin1().constData());
         d->iptcMetadata()["Iptc.Application2.DateCreated"] = iptcdate;
         d->iptcMetadata()["Iptc.Application2.TimeCreated"] = iptctime;
 
@@ -1110,7 +1169,8 @@ QDateTime MetaEngine::getDigitizationDateTime(bool fallbackToCreationTime) const
 
             if (it != exifData.end())
             {
-                QDateTime dateTime = QDateTime::fromString(QString::fromStdString(it->toString()), Qt::ISODate);
+                QDateTime dateTime = asDateTimeUTC(QDateTime::fromString(QString::fromStdString(it->toString()),
+                                                                         Qt::ISODate));
                 dateMap.insert(dateTime, dateMap.value(dateTime, 0) + 1);
 
                 if (dateTime.isValid())
@@ -1133,7 +1193,8 @@ QDateTime MetaEngine::getDigitizationDateTime(bool fallbackToCreationTime) const
 
                 if (it != xmpData.end())
                 {
-                    QDateTime dateTime = QDateTime::fromString(QString::fromStdString(it->toString()), Qt::ISODate);
+                    QDateTime dateTime = asDateTimeUTC(QDateTime::fromString(QString::fromStdString(it->toString()),
+                                                                             Qt::ISODate));
                     dateMap.insert(dateTime, dateMap.value(dateTime, 0) + 1);
 
                     if (dateTime.isValid() && (dateMap.value(dateTime) > 1))
@@ -1150,7 +1211,8 @@ QDateTime MetaEngine::getDigitizationDateTime(bool fallbackToCreationTime) const
 
                 if (it != xmpData.end())
                 {
-                    QDateTime dateTime = QDateTime::fromString(QString::fromStdString(it->toString()), Qt::ISODate);
+                    QDateTime dateTime = asDateTimeUTC(QDateTime::fromString(QString::fromStdString(it->toString()),
+                                                                             Qt::ISODate));
                     dateMap.insert(dateTime, dateMap.value(dateTime, 0) + 1);
 
                     if (dateTime.isValid() && (dateMap.value(dateTime) > 1))
@@ -1188,7 +1250,7 @@ QDateTime MetaEngine::getDigitizationDateTime(bool fallbackToCreationTime) const
 
                     QDate date         = QDate::fromString(IptcDateDigitization, Qt::ISODate);
                     QTime time         = QTime::fromString(IptcTimeDigitization, Qt::ISODate);
-                    QDateTime dateTime = QDateTime(date, time);
+                    QDateTime dateTime = asDateTimeUTC(QDateTime(date, time));
                     dateMap.insert(dateTime, dateMap.value(dateTime, 0) + 1);
 
                     if (dateTime.isValid() && (dateMap.value(dateTime) > 1))
@@ -1324,7 +1386,15 @@ bool MetaEngine::setItemPreview(const QImage& preview) const
         d->iptcMetadata()["Iptc.Application2.PreviewFormat"]  = 11;  // JPEG
         d->iptcMetadata()["Iptc.Application2.PreviewVersion"] = 1;
 
-        setXmpTagString("Xmp.digiKam.Preview", QString::fromUtf8(data.toBase64()));
+        QByteArray xmpPreview(data.toBase64());
+
+        if (xmpPreview.size() < 62000)
+        {
+            qCDebug(DIGIKAM_METAENGINE_LOG) << "Set XMP image preview with:"
+                                            << xmpPreview.size() << "bytes";
+
+            setXmpTagString("Xmp.digiKam.Preview", QString::fromUtf8(xmpPreview));
+        }
 
         return true;
     }
