@@ -7,7 +7,7 @@
  * Description : Exiv2 library interface.
  *               Internal private container.
  *
- * SPDX-FileCopyrightText: 2006-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2006-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2006-2013 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
@@ -16,26 +16,12 @@
 
 #include "metaengine_p.h"
 
-// C ANSI includes
-
-extern "C"
-{
-#include <sys/stat.h>
-
-#ifndef Q_CC_MSVC
-#   include <utime.h>
-#else
-#   include <sys/utime.h>
-#endif
-}
-
 // Qt includes
 
 #if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
 #   include <QTextCodec>
 #endif
 
-#include <QFile>
 #include <qplatformdefs.h>
 
 // Local includes
@@ -80,25 +66,13 @@ bool s_metaEngineSupportBmff = false;
 bool s_metaEngineWarnOrError = false;
 
 MetaEngine::Private::Private(MetaEngine* const q)
-    : writeWithExifTool     (false),
-      writeRawFiles         (false),
-      writeDngFiles         (false),
-      updateFileTimeStamp   (false),
-      useXMPSidecar4Reading (false),
-      useCompatibleFileName (false),
-      metadataWritingMode   (WRITE_TO_FILE_ONLY),
-      loadedFromSidecar     (false),
-      parent                (q),
+    : parent                (q),
       data                  (new MetaEngineData::Private)
 {
     QMutexLocker lock(&s_metaEngineMutex);
     Exiv2::LogMsg::setHandler(MetaEngine::Private::printExiv2MessageHandler);
 }
 
-MetaEngine::Private::~Private()
-{
-}
-
 const Exiv2::ExifData& MetaEngine::Private::exifMetadata() const
 {
     return data.constData()->exifMetadata;
@@ -114,6 +88,11 @@ const std::string& MetaEngine::Private::itemComments() const
     return data.constData()->imageComments;
 }
 
+const Exiv2::ByteOrder& MetaEngine::Private::exifByteOrder() const
+{
+    return data.constData()->exifByteOrder;
+}
+
 Exiv2::ExifData& MetaEngine::Private::exifMetadata()
 {
     return data.data()->exifMetadata;
@@ -129,6 +108,11 @@ std::string& MetaEngine::Private::itemComments()
     return data.data()->imageComments;
 }
 
+Exiv2::ByteOrder& MetaEngine::Private::exifByteOrder()
+{
+    return data.data()->exifByteOrder;
+}
+
 #ifdef _XMP_SUPPORT_
 
 const Exiv2::XmpData& MetaEngine::Private::xmpMetadata() const
@@ -141,7 +125,7 @@ Exiv2::XmpData& MetaEngine::Private::xmpMetadata()
     return data.data()->xmpMetadata;
 }
 
-#endif
+#endif // _XMP_SUPPORT_
 
 void MetaEngine::Private::copyPrivateData(const Private* const other)
 {
@@ -149,12 +133,16 @@ void MetaEngine::Private::copyPrivateData(const Private* const other)
 
     data                  = other->data;
     filePath              = other->filePath;
+    mimeType              = other->mimeType;
+    pixelSize             = other->pixelSize;
     writeRawFiles         = other->writeRawFiles;
     writeDngFiles         = other->writeDngFiles;
+    writeWithExifTool     = other->writeWithExifTool;
+    loadedFromSidecar     = other->loadedFromSidecar;
     updateFileTimeStamp   = other->updateFileTimeStamp;
+    metadataWritingMode   = other->metadataWritingMode;
     useXMPSidecar4Reading = other->useXMPSidecar4Reading;
     useCompatibleFileName = other->useCompatibleFileName;
-    metadataWritingMode   = other->metadataWritingMode;
 }
 
 bool MetaEngine::Private::saveToXMPSidecar(const QFileInfo& finfo) const
@@ -166,6 +154,10 @@ bool MetaEngine::Private::saveToXMPSidecar(const QFileInfo& finfo) const
         return false;
     }
 
+    QFileInfo xmpInfo(xmpFile);
+    QDateTime modTime = xmpInfo.exists() ? xmpInfo.fileTime(QFileDevice::FileModificationTime)
+                                         : finfo.fileTime(QFileDevice::FileModificationTime);
+
     QMutexLocker lock(&s_metaEngineMutex);
 
     try
@@ -177,7 +169,7 @@ bool MetaEngine::Private::saveToXMPSidecar(const QFileInfo& finfo) const
         image = Exiv2::ImageFactory::create(Exiv2::ImageType::xmp,
                                             (const wchar_t*)xmpFile.utf16());
 
-#elif defined Q_OS_WIN
+#elif defined __MINGW32__ // krazy:exclude=cpp
 
         image = Exiv2::ImageFactory::create(Exiv2::ImageType::xmp,
                                             QFile::encodeName(xmpFile).constData());
@@ -191,11 +183,11 @@ bool MetaEngine::Private::saveToXMPSidecar(const QFileInfo& finfo) const
 
 #if EXIV2_TEST_VERSION(0,27,99)
 
-        return saveUsingExiv2(finfo, std::move(image));
+        return saveUsingExiv2(xmpInfo, modTime, std::move(image));
 
 #else
 
-        return saveUsingExiv2(finfo, image);
+        return saveUsingExiv2(xmpInfo, modTime, image);
 
 #endif
 
@@ -223,11 +215,13 @@ bool MetaEngine::Private::saveToFile(const QFileInfo& finfo) const
         return false;
     }
 
+    QDateTime modTime = finfo.fileTime(QFileDevice::FileModificationTime);
+
     QMutexLocker lock(&s_metaEngineMutex);
 
     if (writeWithExifTool)
     {
-        return saveUsingExifTool(finfo);
+        return saveUsingExifTool(finfo, modTime);
     }
     else
     {
@@ -239,7 +233,7 @@ bool MetaEngine::Private::saveToFile(const QFileInfo& finfo) const
 
             image = Exiv2::ImageFactory::open((const wchar_t*)finfo.filePath().utf16());
 
-#elif defined Q_OS_WIN
+#elif defined __MINGW32__ // krazy:exclude=cpp
 
             image = Exiv2::ImageFactory::open(QFile::encodeName(finfo.filePath()).constData());
 
@@ -251,11 +245,11 @@ bool MetaEngine::Private::saveToFile(const QFileInfo& finfo) const
 
 #if EXIV2_TEST_VERSION(0,27,99)
 
-            return saveUsingExiv2(finfo, std::move(image));
+            return saveUsingExiv2(finfo, modTime, std::move(image));
 
 #else
 
-            return saveUsingExiv2(finfo, image);
+            return saveUsingExiv2(finfo, modTime, image);
 
 #endif
 
@@ -275,7 +269,9 @@ bool MetaEngine::Private::saveToFile(const QFileInfo& finfo) const
     }
 }
 
-bool MetaEngine::Private::saveUsingExiv2(const QFileInfo& finfo, Exiv2::Image::AutoPtr image) const
+bool MetaEngine::Private::saveUsingExiv2(const QFileInfo& finfo,
+                                         const QDateTime& modTime,
+                                         Exiv2::Image::AutoPtr image) const
 {
     QMutexLocker lock(&s_metaEngineMutex);
 
@@ -283,12 +279,19 @@ bool MetaEngine::Private::saveUsingExiv2(const QFileInfo& finfo, Exiv2::Image::A
 
     if (!ext.isEmpty())
     {
-        if (s_rawFileExtensions().contains(ext) && (image->imageType() != Exiv2::ImageType::xmp))
+        if (s_rawFileExtensions().contains(ext))
         {
             // NOTE: never touch RAW files with Exiv2 as it's not safe. Use ExifTool backend instead.
 
             return false;
         }
+
+        // Check for a PGF image, this would be destroyed by Exiv2.
+
+        if (ext == QLatin1String("pgf"))
+        {
+            return false;
+        }
     }
 
     try
@@ -433,7 +436,7 @@ bool MetaEngine::Private::saveUsingExiv2(const QFileInfo& finfo, Exiv2::Image::A
 
             wroteXMP = true;
 
-#endif
+#endif // _XMP_SUPPORT_
 
         }
 
@@ -451,70 +454,22 @@ bool MetaEngine::Private::saveUsingExiv2(const QFileInfo& finfo, Exiv2::Image::A
             qCDebug(DIGIKAM_METAENGINE_LOG) << "Support for writing metadata is limited for file" << finfo.fileName();
         }
 
-#ifdef _XMP_SUPPORT_
-
-        if (!updateFileTimeStamp && (image->imageType() != Exiv2::ImageType::xmp))
-#else
-
-        if (!updateFileTimeStamp)
-
-#endif
+        image->writeMetadata();
 
+        if (!updateFileTimeStamp && modTime.isValid())
         {
-            // Don't touch access and modification timestamp of file.
+            // Don't touch modification timestamp of file.
 
-#ifdef Q_OS_WIN64
+            QFile modFile(finfo.filePath());
 
-            struct __utimbuf64 ut;
-            struct __stat64    st;
-            int ret = _wstat64((const wchar_t*)finfo.filePath().utf16(), &st);
-
-#elif defined Q_OS_WIN
-
-            struct _utimbuf    ut;
-            struct _stat       st;
-            int ret = _wstat((const wchar_t*)finfo.filePath().utf16(), &st);
-
-#else
-
-            struct utimbuf     ut;
-            QT_STATBUF         st;
-            int ret = QT_STAT(finfo.filePath().toUtf8().constData(), &st);
-
-#endif
-
-            if (ret == 0)
+            if (modFile.open(QIODevice::WriteOnly | QIODevice::Append | QIODevice::ExistingOnly))
             {
-                ut.modtime = st.st_mtime;
-                ut.actime  = st.st_atime;
+                modFile.setFileTime(modTime, QFileDevice::FileModificationTime);
+
+                qCDebug(DIGIKAM_METAENGINE_LOG) << "File time stamp restored";
+
+                modFile.close();
             }
-
-            image->writeMetadata();
-
-            if (ret == 0)
-            {
-
-#ifdef Q_OS_WIN64
-
-                _wutime64((const wchar_t*)finfo.filePath().utf16(), &ut);
-
-#elif defined Q_OS_WIN
-
-                _wutime((const wchar_t*)finfo.filePath().utf16(), &ut);
-
-#else
-
-                ::utime(finfo.filePath().toUtf8().constData(), &ut);
-
-#endif
-
-            }
-
-            qCDebug(DIGIKAM_METAENGINE_LOG) << "File time stamp restored";
-        }
-        else
-        {
-            image->writeMetadata();
         }
 
         return true;
@@ -531,7 +486,8 @@ bool MetaEngine::Private::saveUsingExiv2(const QFileInfo& finfo, Exiv2::Image::A
     return false;
 }
 
-bool MetaEngine::Private::saveUsingExifTool(const QFileInfo& finfo) const
+bool MetaEngine::Private::saveUsingExifTool(const QFileInfo& finfo,
+                                            const QDateTime& modTime) const
 {
     QString ext = finfo.suffix().toLower();
 
@@ -572,79 +528,39 @@ bool MetaEngine::Private::saveUsingExifTool(const QFileInfo& finfo) const
 
     // ---
 
-    parent->exportChanges(exvPath);
-
-    if (!updateFileTimeStamp)
+    if (!parent->exportChanges(exvPath))
     {
-        // Don't touch access and modification timestamp of file.
+        qCWarning(DIGIKAM_METAENGINE_LOG) << "Exiv2 error exception for" << finfo.fileName()
+                                          << "Writing of metadata aborted!";
+        QFile::remove(exvPath);
 
-#ifdef Q_OS_WIN64
-
-        struct __utimbuf64 ut;
-        struct __stat64    st;
-        int ret = _wstat64((const wchar_t*)finfo.filePath().utf16(), &st);
-
-#elif defined Q_OS_WIN
-
-        struct _utimbuf    ut;
-        struct _stat       st;
-        int ret = _wstat((const wchar_t*)finfo.filePath().utf16(), &st);
-
-#else
-
-        struct utimbuf     ut;
-        QT_STATBUF         st;
-        int ret = QT_STAT(finfo.filePath().toUtf8().constData(), &st);
-
-#endif
-
-        if (ret == 0)
-        {
-            ut.modtime = st.st_mtime;
-            ut.actime  = st.st_atime;
-        }
-
-        bool hasIptcCSet = (parent->getIptcTagData("Iptc.Envelope.CharacterSet") == "\33%G");
-
-        if (!parser->applyChanges(finfo.filePath(), exvPath, parent->hasExif(), hasIptcCSet))
-        {
-            qCWarning(DIGIKAM_METAENGINE_LOG) << "Cannot apply changes with ExifTool on" << finfo.filePath();
-            QFile::remove(exvPath);
-
-            return false;
-        }
-
-        if (ret == 0)
-        {
-
-#ifdef Q_OS_WIN64
-
-            _wutime64((const wchar_t*)finfo.filePath().utf16(), &ut);
-
-#elif defined Q_OS_WIN
-
-            _wutime((const wchar_t*)finfo.filePath().utf16(), &ut);
-
-#else
-
-            ::utime(finfo.filePath().toUtf8().constData(), &ut);
-
-#endif
-
-        }
-
-        qCDebug(DIGIKAM_METAENGINE_LOG) << "File time stamp restored";
+        return false;
     }
-    else
+
+    bool hasCSet = (parent->getIptcTagData("Iptc.Envelope.CharacterSet") == "\33%G");
+
+    if (!parser->applyChanges(finfo.filePath(), exvPath,
+                              parent->hasExif(), parent->hasXmp(), hasCSet))
     {
-        bool hasIptcCSet = (parent->getIptcTagData("Iptc.Envelope.CharacterSet") == "\33%G");
+        qCWarning(DIGIKAM_METAENGINE_LOG) << "Cannot apply changes with ExifTool on" << finfo.filePath();
+        QFile::remove(exvPath);
 
-        if (!parser->applyChanges(finfo.filePath(), exvPath, parent->hasExif(), hasIptcCSet))
+        return false;
+    }
+
+    if (!updateFileTimeStamp && modTime.isValid())
+    {
+        // Don't touch modification timestamp of file.
+
+        QFile modFile(finfo.filePath());
+
+        if (modFile.open(QIODevice::WriteOnly | QIODevice::Append | QIODevice::ExistingOnly))
         {
-            qCWarning(DIGIKAM_METAENGINE_LOG) << "Cannot apply changes with ExifTool on" << finfo.filePath();
-            QFile::remove(exvPath);
+            modFile.setFileTime(modTime, QFileDevice::FileModificationTime);
 
-            return false;
+            qCDebug(DIGIKAM_METAENGINE_LOG) << "File time stamp restored";
+
+            modFile.close();
         }
     }
 
@@ -672,12 +588,46 @@ QString MetaEngine::Private::convertCommentValue(const Exiv2::Exifdatum& exifDat
 
     try
     {
+        QByteArray rawComment(exifDatum.size(), '\0');
+        exifDatum.copy((Exiv2::byte*)rawComment.data(), Exiv2::littleEndian);
+
+        if (
+            (rawComment.size() > 8) &&
+            rawComment.startsWith(QByteArray("UNICODE\0"))
+           )
+        {
+            rawComment = rawComment.mid(8);
+
+            if ((rawComment.size() % 2) != 0)
+            {
+                qCDebug(DIGIKAM_METAENGINE_LOG) << "Comment not properly 16 bit encoded";
+
+                return QString();
+            }
+
+            // change the byte order if we have a big-endian
+            // image or encounter a possible incorrect byte order
+
+            if ((exifByteOrder() == Exiv2::bigEndian) || (rawComment.at(0) == '\0'))
+            {
+                const QByteArray tmpComment(rawComment);
+
+                for (int i = 0 ; i < rawComment.size() ; i += 2)
+                {
+                    rawComment[i]     = tmpComment.at(i + 1);
+                    rawComment[i + 1] = tmpComment.at(i);
+                }
+            }
+
+            return QString::fromUtf16((char16_t*)rawComment.data(), rawComment.size() / 2);
+        }
+
         std::string comment;
         std::string charset;
 
         comment = exifDatum.toString();
 
-        // libexiv2 will prepend "charset=\"SomeCharset\" " if charset is specified
+        // libexiv2 will prepend "charset=SomeCharset " if charset is specified
         // Before conversion to QString, we must know the charset, so we stay with std::string for a while
 
         if ((comment.length() > 8) && (comment.substr(0, 8) == "charset="))
@@ -690,22 +640,18 @@ QString MetaEngine::Private::convertCommentValue(const Exiv2::Exifdatum& exifDat
             {
                 // extract string between the = and the blank
 
-                charset = comment.substr(8, pos-8);
+                charset = comment.substr(8, pos - 8);
 
                 // get the rest of the string after the charset specification
 
-                comment = comment.substr(pos+1);
+                comment = comment.substr(pos + 1);
             }
         }
 
-        if      (charset == "\"Unicode\"")
-        {
-            return QString::fromUtf8(comment.data());
-        }
-        else if (charset == "\"Jis\"")
+        if      (charset == "Jis")
         {
 
-#if (QT_VERSION > QT_VERSION_CHECK(5, 99, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
 
             if (Exiv2::convertStringCharset(comment, charset.c_str(), "UTF-8"))
             {
@@ -724,6 +670,7 @@ QString MetaEngine::Private::convertCommentValue(const Exiv2::Exifdatum& exifDat
             {
                 const char* tmp = comment.c_str();
 
+                // cppcheck-suppress knownConditionTrueFalse
                 if (tmp)
                 {
                     return codec->toUnicode(tmp);
@@ -735,7 +682,7 @@ QString MetaEngine::Private::convertCommentValue(const Exiv2::Exifdatum& exifDat
 #endif
 
         }
-        else if (charset == "\"Ascii\"")
+        else if (charset == "Ascii")
         {
             return QString::fromStdString(comment);
         }
