@@ -153,8 +153,10 @@ FocusPointsExtractor::ListAFPoints FocusPointsExtractor::getAFPoints_canon() con
     QStringList afPointWidths  = findValue(TagNameRoot, QLatin1String("AFAreaWidths"),  true).toStringList();
     QStringList afPointHeights = findValue(TagNameRoot, QLatin1String("AFAreaHeights"), true).toStringList();
 
-    if (((afPointWidth.isNull())   || (afPointHeight.isNull())) &&
-        ((afPointWidths.isEmpty()) || (afPointHeights.isEmpty())))
+    if (
+        (afPointWidth.isNull()   || afPointHeight.isNull()) &&
+        (afPointWidths.isEmpty() || afPointHeights.isEmpty())
+       )
     {
         qCDebug(DIGIKAM_METAENGINE_LOG) << "FocusPointsExtractor: invalid sizes from Canon makernotes.";
 
@@ -216,8 +218,10 @@ FocusPointsExtractor::ListAFPoints FocusPointsExtractor::getAFPoints_canon() con
 
     int yDirection          = 1;
 
-    if ((cameraType == QLatin1String("COMPACT"))    ||
-        (cameraType == QLatin1String("EOS HIGH-END")))
+    if (
+        (cameraType == QLatin1String("COMPACT"))    ||
+        (cameraType == QLatin1String("EOS HIGH-END"))
+       )
     {
         yDirection = -1;
     }
@@ -229,8 +233,8 @@ FocusPointsExtractor::ListAFPoints FocusPointsExtractor::getAFPoints_canon() con
         float afPointWidthUsed  = (afPointWidths.isEmpty()) ? afPointWidth.toFloat()
                                                             : afPointWidths[i].toFloat();
 
-        float afPointHeightUsed = (afPointWidths.isEmpty()) ? afPointHeight.toFloat()
-                                                            : afPointWidths[i].toFloat();
+        float afPointHeightUsed = (afPointHeights.isEmpty()) ? afPointHeight.toFloat()
+                                                             : afPointHeights[i].toFloat();
 
         FocusPoint point        = CanonInternal::create_af_point(
                                                                  imageWidth.toFloat(),
