@@ -30,6 +30,7 @@
 // Local includes
 
 #include "digikam_version.h"
+#include "digikam_globals.h"
 #include "digikam_debug.h"
 
 namespace Digikam
@@ -154,10 +155,13 @@ void OnlineVersionChecker::slotDownloadFinished(QNetworkReply* reply)
     reply->deleteLater();
     d->reply = nullptr;
 
-    if ((reply->error() != QNetworkReply::NoError)             &&
-        (reply->error() != QNetworkReply::InsecureRedirectError))
+    if (
+        (reply->error() != QNetworkReply::NoError)             &&
+        (reply->error() != QNetworkReply::InsecureRedirectError)
+       )
     {
         qCDebug(DIGIKAM_GENERAL_LOG) << "Error: " << reply->errorString();
+
         Q_EMIT signalNewVersionCheckError(reply->errorString());
 
         return;
@@ -165,9 +169,11 @@ void OnlineVersionChecker::slotDownloadFinished(QNetworkReply* reply)
 
     QUrl redirectUrl = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl();
 
-    if (redirectUrl.isValid()         &&
+    if (
+        redirectUrl.isValid()         &&
         (reply->url() != redirectUrl) &&
-        (d->redirects < 10))
+        (d->redirects < 10)
+       )
     {
         download(redirectUrl);
 
@@ -179,6 +185,7 @@ void OnlineVersionChecker::slotDownloadFinished(QNetworkReply* reply)
     if (data.isEmpty())
     {
         qCWarning(DIGIKAM_GENERAL_LOG) << "No data returned from the remote connection.";
+
         Q_EMIT signalNewVersionCheckError(i18n("No data returned from the remote connection."));
 
         return;
@@ -191,8 +198,10 @@ void OnlineVersionChecker::slotDownloadFinished(QNetworkReply* reply)
 
         QString arch;
         QString ext;
+        QString qtVersion;
+        QString dir;
 
-        if (!OnlineVersionChecker::bundleProperties(arch, ext))
+        if (!OnlineVersionChecker::bundleProperties(arch, ext, qtVersion, dir))
         {
             Q_EMIT signalNewVersionCheckError(i18n("Unsupported Architecture: %1", QSysInfo::buildAbi()));
 
@@ -218,34 +227,34 @@ void OnlineVersionChecker::slotDownloadFinished(QNetworkReply* reply)
 
         QStringList sections = d->preReleaseFileName.split(QLatin1Char('-'));
 
-        if (sections.size() < 4)
+        if (sections.size() < 5)
         {
             qCWarning(DIGIKAM_GENERAL_LOG) << "Invalid file name format returned from the remote connection.";
+
             Q_EMIT signalNewVersionCheckError(i18n("Invalid file name format returned from the remote connection."));
 
             return;
         }
 
-        // Tow possibles places exists where to find the date in file name.
+        // Two possibles places exists where to find the date in file name.
 
-        // Check 1 - the fila name include a pre release suffix as -beta or -rc
+        // Check 1 - the file-name include a pre release suffix as -beta or -rc
 
         QString dtStr      = sections[3];
-        QDateTime onlineDt = QDateTime::fromString(dtStr, QLatin1String("yyyyMMddTHHmmss"));
-        onlineDt.setTimeSpec(Qt::UTC);
+        QDateTime onlineDt = asDateTimeUTC(QDateTime::fromString(dtStr, QLatin1String("yyyyMMddTHHmmss")));
 
         if (!onlineDt.isValid())
         {
             // Check 2 - the file name do not include a pre release suffix
 
             dtStr    = sections[2];
-            onlineDt = QDateTime::fromString(dtStr, QLatin1String("yyyyMMddTHHmmss"));
-            onlineDt.setTimeSpec(Qt::UTC);
+            onlineDt = asDateTimeUTC(QDateTime::fromString(dtStr, QLatin1String("yyyyMMddTHHmmss")));
         }
 
         if (!onlineDt.isValid())
         {
             qCWarning(DIGIKAM_GENERAL_LOG) << "Invalid pre-release date from the remote list.";
+
             Q_EMIT signalNewVersionCheckError(i18n("Invalid pre-release date from the remote list."));
 
             return;
@@ -278,6 +287,7 @@ void OnlineVersionChecker::slotDownloadFinished(QNetworkReply* reply)
         if (onlineVals.size() != 3)
         {
             qCWarning(DIGIKAM_GENERAL_LOG) << "Invalid format returned from the remote connection.";
+
             Q_EMIT signalNewVersionCheckError(i18n("Invalid format returned from the remote connection."));
 
             return;
@@ -287,12 +297,10 @@ void OnlineVersionChecker::slotDownloadFinished(QNetworkReply* reply)
 
         qCDebug(DIGIKAM_GENERAL_LOG) << "Online Version:" << onlineVer;
 
-        if (digiKamMakeIntegerVersion(onlineVals[0].toInt(),
-                                      onlineVals[1].toInt(),
-                                      onlineVals[2].toInt()) >
-            digiKamMakeIntegerVersion(currVals[0].toInt(),
-                                      currVals[1].toInt(),
-                                      currVals[2].toInt()))
+        if (
+            digiKamMakeIntegerVersion(onlineVals[0].toInt(), onlineVals[1].toInt(), onlineVals[2].toInt()) >
+            digiKamMakeIntegerVersion(currVals[0].toInt(),   currVals[1].toInt(),   currVals[2].toInt())
+           )
         {
             Q_EMIT signalNewVersionAvailable(onlineVer);
         }
@@ -303,25 +311,30 @@ void OnlineVersionChecker::slotDownloadFinished(QNetworkReply* reply)
     }
 }
 
-bool OnlineVersionChecker::bundleProperties(QString& arch, QString& ext)
+bool OnlineVersionChecker::bundleProperties(QString& arch, QString& ext,
+                                            QString& qtVersion, QString& dir)
 {
 
 #if defined Q_OS_MACOS
 
-    ext  = QLatin1String("pkg");
+    ext       = QLatin1String("pkg");
 
 #   if defined Q_PROCESSOR_X86_64
 
-    arch = QLatin1String("x86-64");
+    arch      = QLatin1String("x86-64");
 
 #   elif defined Q_PROCESSOR_ARM
 
 /*  Native Apple silicon is not yet supported
-    arch = QLatin1String("arm-64");
+    arch      = QLatin1String("arm-64");
 */
 
     // NOTE: Intel 64 version work fine with Apple Rosetta 2 emulator.
-    arch = QLatin1String("x86-64");
+    arch      = QLatin1String("x86-64");
+
+    // Still Qt5 version for Mac, Qt6 is not yet done.
+    qtVersion = QLatin1String("qt5");
+    dir       = QLatin1String("/");
 
 #   endif
 
@@ -347,6 +360,18 @@ bool OnlineVersionChecker::bundleProperties(QString& arch, QString& ext)
 
 #   endif
 
+#   if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+    qtVersion = QLatin1String("qt6");
+    dir       = QLatin1String("/");
+
+#   else
+
+    qtVersion = QLatin1String("qt5");
+    dir       = QLatin1String("/legacy");
+
+#   endif
+
 #endif
 
 #if defined Q_OS_LINUX
@@ -369,9 +394,26 @@ bool OnlineVersionChecker::bundleProperties(QString& arch, QString& ext)
 
 #   endif
 
+#   if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+    qtVersion = QLatin1String("qt6");
+    dir       = QLatin1String("/");
+
+#   else
+
+    qtVersion = QLatin1String("qt5");
+    dir       = QLatin1String("/legacy");
+
+#   endif
+
 #endif
 
-    return (!ext.isEmpty() && !arch.isEmpty());
+    return (
+            !ext.isEmpty()       &&
+            !arch.isEmpty()      &&
+            !qtVersion.isEmpty() &&
+            !dir.isEmpty()
+           );
 }
 
 } // namespace Digikam
