@@ -134,9 +134,11 @@ void OnlineVersionDwnl::startDownload(const QString& version)
     {
         QString arch;
         QString bundle;
+        QString qtVersion;
+        QString dir;
         QString debug = d->updateWithDebug ? QLatin1String("-debug") : QString();
 
-        if (!OnlineVersionChecker::bundleProperties(arch, bundle))
+        if (!OnlineVersionChecker::bundleProperties(arch, bundle, qtVersion, dir))
         {
             Q_EMIT signalDownloadError(i18n("Unsupported Architecture: %1", QSysInfo::buildAbi()));
 
@@ -157,8 +159,9 @@ void OnlineVersionDwnl::startDownload(const QString& version)
 
 #endif
 
-        d->file       = QString::fromLatin1("digiKam-%1-%2%3%4.%5")
+        d->file       = QString::fromLatin1("digiKam-%1-%2-%3%4%5.%6")
                             .arg(version)
+                            .arg(qtVersion)
                             .arg(os)
                             .arg(arch)
                             .arg(debug)
@@ -198,8 +201,10 @@ void OnlineVersionDwnl::slotDownloaded(QNetworkReply* reply)
     reply->deleteLater();
     d->reply = nullptr;
 
-    if ((reply->error() != QNetworkReply::NoError)             &&
-        (reply->error() != QNetworkReply::InsecureRedirectError))
+    if (
+        (reply->error() != QNetworkReply::NoError)             &&
+        (reply->error() != QNetworkReply::InsecureRedirectError)
+       )
     {
         qCDebug(DIGIKAM_GENERAL_LOG) << "Error: " << reply->errorString();
         Q_EMIT signalDownloadError(reply->errorString());
@@ -209,9 +214,11 @@ void OnlineVersionDwnl::slotDownloaded(QNetworkReply* reply)
 
     QUrl redirectUrl = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toUrl();
 
-    if (redirectUrl.isValid()         &&
+    if (
+        redirectUrl.isValid()         &&
         (reply->url() != redirectUrl) &&
-        (d->redirects < 10))
+        (d->redirects < 10)
+       )
     {
         download(redirectUrl);
 
@@ -260,6 +267,7 @@ void OnlineVersionDwnl::slotDownloaded(QNetworkReply* reply)
     if (data.isEmpty())
     {
         qCDebug(DIGIKAM_GENERAL_LOG) << "Downloaded file is empty";
+
         Q_EMIT signalDownloadError(i18n("Downloaded file is empty."));
 
         return;
@@ -292,6 +300,7 @@ void OnlineVersionDwnl::slotDownloaded(QNetworkReply* reply)
     if (d->checksums != hash)
     {
         qCDebug(DIGIKAM_GENERAL_LOG) << "Checksums error";
+
         Q_EMIT signalDownloadError(i18n("Checksums error."));
 
         return;
@@ -319,6 +328,7 @@ void OnlineVersionDwnl::slotDownloaded(QNetworkReply* reply)
     else
     {
         qCDebug(DIGIKAM_GENERAL_LOG) << "Cannot open " << path;
+
         Q_EMIT signalDownloadError(i18n("Cannot open target file."));
     }
 }
