@@ -321,14 +321,21 @@ void DFileOperations::openInFileManager(const QList<QUrl>& urls)
     QStringList args;
     QFileInfo info(path);
 
-    if (!info.isDir())
+    if (info.isFile())
     {
         args << QLatin1String("/select,");
     }
 
-    args << QDir::toNativeSeparators(path);
+    qDebug() << "Explorer 1:" << info.absoluteFilePath();
+    qDebug() << "Explorer 2:" << info.canonicalFilePath();
 
-    if (QProcess::startDetached(QLatin1String("explorer"), args))
+    args << QDir::toNativeSeparators(info.absoluteFilePath());
+
+    QProcess process;
+    process.setArguments(args);
+    process.setProgram(QLatin1String("explorer.exe"));
+
+    if (process.startDetached())
     {
         return;
     }
@@ -488,19 +495,7 @@ bool DFileOperations::renameFile(const QString& srcFile,
     QDateTime accDateTime = srcInfo.fileTime(QFileDevice::FileAccessTime);
     QDateTime modDateTime = srcInfo.fileTime(QFileDevice::FileModificationTime);
 
-    bool ret              = (!QFileInfo::exists(dstFile));
-
-    if (ret)
-    {
-        ret = QFile::rename(srcFile, dstFile);
-
-        if (!ret && QFileInfo::exists(dstFile))
-        {
-            QFile::remove(dstFile);
-        }
-    }
-
-    if (ret)
+    if (QFile::rename(srcFile, dstFile))
     {
         QFile modFile(dstFile);
 
@@ -523,14 +518,16 @@ bool DFileOperations::renameFile(const QString& srcFile,
 
             modFile.close();
 
-            return ret;
+            return true;
         }
 
         qCWarning(DIGIKAM_GENERAL_LOG) << "Failed to restore modification time for file"
                                        << dstFile;
+
+        return true;
     }
 
-    return ret;
+    return false;
 }
 
 bool DFileOperations::copyFile(const QString& srcFile,
