@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_CLOCK_PHOTO_DIALOG_H
-#define DIGIKAM_CLOCK_PHOTO_DIALOG_H
+#pragma once
 
 // Qt includes
 
@@ -62,9 +61,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_CLOCK_PHOTO_DIALOG_H
