@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_FFMPEG_CONFIG_HELPER_H
-#define DIGIKAM_FFMPEG_CONFIG_HELPER_H
+#pragma once
 
 // Qt includes
 
@@ -35,7 +34,7 @@ class DIGIKAM_EXPORT FFMpegConfigHelper
 public:
 
     /**
-     * Return a map of video Codec Name with a list of properties:
+     * Return a map of Video Codec Name with a list of properties:
      *    - Codecs description.
      *    - Read support.
      *    - Write support.
@@ -43,7 +42,7 @@ public:
     static FFMpegProperties getVideoCodecsProperties();
 
     /**
-     * Return a map of audio Codec Name with a list of properties:
+     * Return a map of Audio Codec Name with a list of properties:
      *    - Codecs description.
      *    - Read support.
      *    - Write support.
@@ -51,7 +50,7 @@ public:
     static FFMpegProperties getAudioCodecsProperties();
 
     /**
-     * Return a file extensions supported a list of properties:
+     * Return a map,of File extensions supported with a list of properties:
      *    - Format description.
      */
     static FFMpegProperties getExtensionsProperties();
@@ -65,5 +64,3 @@ private:
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_FFMPEG_CONFIG_HELPER_H
