@@ -6,7 +6,7 @@
  * Date        : 2017-05-25
  * Description : a tool to generate video slideshow from images.
  *
- * SPDX-FileCopyrightText: 2017-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -14,10 +14,6 @@
 
 #include "vidslidesettings.h"
 
-// Qt includes
-
-#include <QStandardPaths>
-
 // KDE includes
 
 #include <klocalizedstring.h>
@@ -30,30 +26,6 @@
 namespace Digikam
 {
 
-VidSlideSettings::VidSlideSettings()
-    : selMode       (IMAGES),
-      transition    (TransitionMngr::None),
-      imgFrames     (125),
-      abitRate      (64000),
-      vbitRate      (VBR12),
-      vStandard     (PAL),
-      vType         (BLUERAY),
-      vCodec        (X264),
-      vFormat       (MP4),
-      vEffect       (EffectMngr::None),
-      conflictRule  (FileSaveConflictBox::OVERWRITE),
-      outputDir     (QStandardPaths::writableLocation(QStandardPaths::MoviesLocation)),
-      outputPlayer  (INTERNAL),
-      equalize      (false),
-      strength      (5),
-      iface         (nullptr)
-{
-}
-
-VidSlideSettings::~VidSlideSettings()
-{
-}
-
 void VidSlideSettings::readSettings(KConfigGroup& group)
 {
     selMode      = (Selection)group.readEntry("SelMode",
@@ -85,7 +57,7 @@ void VidSlideSettings::readSettings(KConfigGroup& group)
     outputPlayer = (VidPlayer)group.readEntry("OutputPlayer",
                    (int)INTERNAL);
     ffmpegPath   = group.readEntry("FFmpegPath",
-                   defaultFFmpegSearchPaths().first());
+                   defaultFFmpegSearchPaths().constFirst());
     equalize     = group.readEntry("Equalize",
                    false);
     strength     = group.readEntry("Strength",
@@ -852,9 +824,11 @@ QStringList VidSlideSettings::defaultFFmpegSearchPaths() const
     defPaths << QLatin1String("/usr/local/bin");
 
     // digiKam Bundle PKG install path
+
     defPaths << macOSBundlePrefix() + QLatin1String("bin");
 
     // Std Macports install path
+
     defPaths << QLatin1String("/opt/local/bin");
 
 #endif
