@@ -15,8 +15,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_SQUEEZED_COMBOBOX_H
-#define DIGIKAM_SQUEEZED_COMBOBOX_H
+#pragma once
 
 // Qt includes
 
@@ -164,9 +163,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_SQUEEZED_COMBOBOX_H
