@@ -29,6 +29,10 @@
 #include <klocalizedstring.h>
 #include <kconfiggroup.h>
 
+// Local includes
+
+#include "digikam_globals.h"
+
 namespace Digikam
 {
 
@@ -36,22 +40,15 @@ class Q_DECL_HIDDEN FileSaveConflictBox::Private
 {
 public:
 
-    explicit Private()
-      : conflictLabel       (nullptr),
-        conflictButtonGroup (nullptr),
-        storeDiffButton     (nullptr),
-        overwriteButton     (nullptr),
-        skipFileButton      (nullptr)
-    {
-    }
+    Private() = default;
 
-    QLabel*       conflictLabel;
+    QLabel*       conflictLabel         = nullptr;
 
-    QButtonGroup* conflictButtonGroup;
+    QButtonGroup* conflictButtonGroup   = nullptr;
 
-    QRadioButton* storeDiffButton;
-    QRadioButton* overwriteButton;
-    QRadioButton* skipFileButton;
+    QRadioButton* storeDiffButton       = nullptr;
+    QRadioButton* overwriteButton       = nullptr;
+    QRadioButton* skipFileButton        = nullptr;
 };
 
 FileSaveConflictBox::FileSaveConflictBox(QWidget* const parent, bool addSkip)
@@ -60,8 +57,8 @@ FileSaveConflictBox::FileSaveConflictBox(QWidget* const parent, bool addSkip)
 {
     setAttribute(Qt::WA_DeleteOnClose);
 
-    const int spacing          = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
-                                      QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
+    const int spacing          = layoutSpacing();
+
     QGridLayout* const grid    = new QGridLayout(this);
     d->conflictLabel           = new QLabel(i18n("If Target File Exists:"), this);
     QWidget* const conflictBox = new QWidget(this);
@@ -136,7 +133,7 @@ void FileSaveConflictBox::setConflictRule(ConflictRule r)
 void FileSaveConflictBox::readSettings(KConfigGroup& group)
 {
     setConflictRule((FileSaveConflictBox::ConflictRule)group.readEntry("Conflict",
-        (int)(FileSaveConflictBox::DIFFNAME)));
+                    (int)(FileSaveConflictBox::DIFFNAME)));
 }
 
 void FileSaveConflictBox::writeSettings(KConfigGroup& group)
