@@ -56,8 +56,9 @@ public:
     int                        scrollStepFactor             = 10;
 
     QMouseEvent*               currentMouseEvent            = nullptr;
+    bool                       initialSelectedItem          = true;
     bool                       ensureOneSelectedItem        = false;
-    bool                       ensureInitialSelectedItem    = false;
+    bool                       ensureInitialSelectedItem    = true;
     bool                       scrollCurrentToCenter        = false;
     Qt::MouseButton            mouseButtonPressed           = Qt::NoButton;
     QPersistentModelIndex      hintAtSelectionIndex;
@@ -249,7 +250,7 @@ void ItemViewCategorized::awayFromSelection()
     const QModelIndex first = model()->index(0, 0);
     const QModelIndex last  = model()->index(model()->rowCount() - 1, 0);
 
-    if (selection.contains(first) && selection.contains(last))
+    if      (selection.contains(first) && selection.contains(last))
     {
         QItemSelection remaining(first, last);
         remaining.merge(selection, QItemSelectionModel::Toggle);
@@ -400,7 +401,7 @@ void ItemViewCategorized::slotActivated(const QModelIndex& index)
 
     const bool shiftKeyPressed   = modifiers & Qt::ShiftModifier;
     const bool controlKeyPressed = modifiers & Qt::ControlModifier;
-    const bool rightClickPressed = buttons & Qt::RightButton;
+    const bool rightClickPressed = buttons   & Qt::RightButton;
 
     if (shiftKeyPressed || controlKeyPressed || rightClickPressed)
     {
@@ -455,7 +456,7 @@ void ItemViewCategorized::reset()
     Q_EMIT selectionChanged();
     Q_EMIT selectionCleared();
 
-    d->ensureInitialSelectedItem = true;
+    d->ensureInitialSelectedItem = d->initialSelectedItem;
     d->hintAtScrollPosition      = QModelIndex();
     d->hintAtSelectionIndex      = QModelIndex();
     d->hintAtSelectionRow        = -1;
@@ -495,6 +496,10 @@ void ItemViewCategorized::rowsRemoved(const QModelIndex& parent, int start, int
     {
         scrollTo(currentIndex(), QAbstractItemView::PositionAtCenter);
     }
+    else
+    {
+        scrollTo(currentIndex(), QAbstractItemView::PositionAtTop);
+    }
 }
 
 void ItemViewCategorized::rowsAboutToBeRemoved(const QModelIndex& parent, int start, int end)
@@ -636,11 +641,10 @@ void ItemViewCategorized::ensureSelectionAfterChanges()
 {
     if      (d->ensureInitialSelectedItem && model()->rowCount())
     {
-        // Ensure the item (0,0) is selected, if the model was reset previously
+        // Ensure the item (0, 0) is selected, if the model was reset previously
         // and the user did not change the selection since reset.
-        // Caveat: Item at (0,0) may have changed.
+        // Caveat: Item at (0, 0) may have changed.
 
-        bool hadInitial              = d->ensureInitialSelectedItem;
         d->ensureInitialSelectedItem = false;
         d->ensureOneSelectedItem     = false;
         QModelIndex index            = model()->index(0, 0);
@@ -652,15 +656,11 @@ void ItemViewCategorized::ensureSelectionAfterChanges()
 
             // we want ensureInitial set to false if and only if the selection
             // is done from any other place than the previous line (i.e., by user action)
-            // Effect: we select whatever is the current index(0,0)
+            // Effect: we select whatever is the current index(0, 0)
             // TODO: cppcheck report here that hadInitial condition is always true.
             //       This code must be refactored later.
 
-            // cppcheck-suppress knownConditionTrueFalse
-            if (hadInitial)
-            {
-                d->ensureInitialSelectedItem = true;
-            }
+            d->ensureInitialSelectedItem = true;
         }
     }
     else if (d->ensureOneSelectedItem)
@@ -846,7 +846,7 @@ void ItemViewCategorized::mousePressEvent(QMouseEvent* event)
 
     Qt::KeyboardModifiers modifiers = event->modifiers();
     const Qt::MouseButton button    = event->button();
-    const bool rightButtonPressed   = button & Qt::RightButton;
+    const bool rightButtonPressed   = button    & Qt::RightButton;
     const bool shiftKeyPressed      = modifiers & Qt::ShiftModifier;
     const bool controlKeyPressed    = modifiers & Qt::ControlModifier;
     d->mouseButtonPressed           = button;
@@ -914,8 +914,10 @@ void ItemViewCategorized::mouseMoveEvent(QMouseEvent* event)
     {
         indexVisualRect = visualRect(index);
 
-        if (d->usePointingHand &&
-            d->delegate->acceptsActivation(event->pos(), indexVisualRect, index))
+        if (
+            d->usePointingHand &&
+            d->delegate->acceptsActivation(event->pos(), indexVisualRect, index)
+           )
         {
             setCursor(Qt::PointingHandCursor);
         }
@@ -1109,7 +1111,7 @@ void ItemViewCategorized::showIndexNotification(const QModelIndex& index, const
 
 #else
 
-    option = viewOptions();
+    option                      = viewOptions();
 
 #endif
 
@@ -1145,7 +1147,7 @@ QPixmap ItemViewCategorized::pixmapForDrag(const QList<QModelIndex>& indexes) co
 
 #else
 
-    option = viewOptions();
+    option                      = viewOptions();
 
 #endif
 
@@ -1154,6 +1156,11 @@ QPixmap ItemViewCategorized::pixmapForDrag(const QList<QModelIndex>& indexes) co
     return d->delegate->pixmapForDrag(option, indexes);
 }
 
+void ItemViewCategorized::setInitialSelectedItem(bool enabled)
+{
+    d->initialSelectedItem = enabled;
+}
+
 void ItemViewCategorized::setScrollCurrentToCenter(bool enabled)
 {
     d->scrollCurrentToCenter = enabled;
