@@ -37,7 +37,9 @@
 
 // Local includes
 
+#include "digikam_globals.h"
 #include "dlayoutbox.h"
+#include "thememanager.h"
 
 namespace Digikam
 {
@@ -73,13 +75,10 @@ class Q_DECL_HIDDEN DAdjustableLabel::Private
 {
 public:
 
-    explicit Private()
-      : emode(Qt::ElideMiddle)
-    {
-    }
+    Private() = default;
 
     QString           ajdText;
-    Qt::TextElideMode emode;
+    Qt::TextElideMode emode = Qt::ElideMiddle;
 };
 
 DAdjustableLabel::DAdjustableLabel(QWidget* const parent)
@@ -103,6 +102,7 @@ QSize DAdjustableLabel::minimumSizeHint() const
 {
     QSize sh = QLabel::minimumSizeHint();
     sh.setWidth(-1);
+
     return sh;
 }
 
@@ -122,7 +122,7 @@ QSize DAdjustableLabel::sizeHint() const
     int maxW     = screen->geometry().width() * 3 / 4;
     int currentW = fm.horizontalAdvance(d->ajdText);
 
-    return (QSize(currentW > maxW ? maxW : currentW, QLabel::sizeHint().height()));
+    return (QSize((currentW > maxW) ? maxW : currentW, QLabel::sizeHint().height()));
 }
 
 void DAdjustableLabel::setAdjustedText(const QString& text)
@@ -229,6 +229,7 @@ void DClickLabel::mouseReleaseEvent(QMouseEvent* event)
     {
         Q_EMIT leftClicked();
         Q_EMIT activated();
+
         event->accept();
     }
 }
@@ -240,11 +241,16 @@ void DClickLabel::keyPressEvent(QKeyEvent* e)
         case Qt::Key_Down:
         case Qt::Key_Right:
         case Qt::Key_Space:
+        {
             Q_EMIT activated();
+
             return;
+        }
 
         default:
+        {
             break;
+        }
     }
 
     QLabel::keyPressEvent(e);
@@ -277,6 +283,7 @@ void DSqueezedClickLabel::mouseReleaseEvent(QMouseEvent* event)
     {
         Q_EMIT leftClicked();
         Q_EMIT activated();
+
         event->accept();
     }
 }
@@ -302,11 +309,16 @@ void DSqueezedClickLabel::keyPressEvent(QKeyEvent* e)
         case Qt::Key_Down:
         case Qt::Key_Right:
         case Qt::Key_Space:
+        {
             Q_EMIT activated();
+
             return;
+        }
 
         default:
+        {
             break;
+        }
     }
 
     QLabel::keyPressEvent(e);
@@ -315,13 +327,10 @@ void DSqueezedClickLabel::keyPressEvent(QKeyEvent* e)
 // ------------------------------------------------------------------------
 
 DArrowClickLabel::DArrowClickLabel(QWidget* const parent)
-    : QWidget(parent),
-      m_arrowType(Qt::DownArrow)
+    : QWidget(parent)
 {
     setCursor(Qt::PointingHandCursor);
     setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
-    m_size   = 8;
-    m_margin = 2;
 }
 
 void DArrowClickLabel::setArrowType(Qt::ArrowType type)
@@ -330,10 +339,6 @@ void DArrowClickLabel::setArrowType(Qt::ArrowType type)
     update();
 }
 
-DArrowClickLabel::~DArrowClickLabel()
-{
-}
-
 Qt::ArrowType DArrowClickLabel::arrowType() const
 {
     return m_arrowType;
@@ -378,7 +383,10 @@ void DArrowClickLabel::paintEvent(QPaintEvent*)
         return;
     }
 
-    if ((width() < (m_size + m_margin)) || (height() < (m_size + m_margin)))
+    if (
+        (width()  < (m_size + m_margin)) ||
+        (height() < (m_size + m_margin))
+       )
     {
         return; // don't draw arrows if we are too small
     }
@@ -420,23 +428,33 @@ void DArrowClickLabel::paintEvent(QPaintEvent*)
     switch (m_arrowType)
     {
         case Qt::LeftArrow:
+        {
             e = QStyle::PE_IndicatorArrowLeft;
             break;
+        }
 
         case Qt::RightArrow:
+        {
             e = QStyle::PE_IndicatorArrowRight;
             break;
+        }
 
         case Qt::UpArrow:
+        {
             e = QStyle::PE_IndicatorArrowUp;
             break;
+        }
 
         case Qt::DownArrow:
+        {
             e = QStyle::PE_IndicatorArrowDown;
             break;
+        }
 
         case Qt::NoArrow:
+        {
             break;
+        }
     }
 
     opt.state |= QStyle::State_Enabled;
@@ -457,50 +475,40 @@ class Q_DECL_HIDDEN DLabelExpander::Private
 
 public:
 
-    explicit Private()
-      : expandByDefault (true),
-        checkBox        (nullptr),
-        pixmapLabel     (nullptr),
-        btn             (nullptr),
-        containerWidget (nullptr),
-        grid            (nullptr),
-        line            (nullptr),
-        hbox            (nullptr),
-        arrow           (nullptr),
-        clickLabel      (nullptr)
-    {
-    }
+    Private() = default;
 
-    bool              expandByDefault;
+    bool              expandByDefault   = true;
 
-    QCheckBox*        checkBox;
-    QLabel*           pixmapLabel;
-    QToolButton*      btn;
-    QWidget*          containerWidget;
-    QGridLayout*      grid;
+    QCheckBox*        checkBox          = nullptr;
+    QLabel*           pixmapLabel       = nullptr;
+    QToolButton*      btn               = nullptr;
+    QWidget*          containerWidget   = nullptr;
+    QGridLayout*      grid              = nullptr;
 
-    DLineWidget*      line;
-    QWidget*          hbox;
+    DLineWidget*      line              = nullptr;
+    QWidget*          hbox              = nullptr;
 
-    DArrowClickLabel* arrow;
-    DClickLabel*      clickLabel;
+    QIcon             icon;
+
+    DArrowClickLabel* arrow             = nullptr;
+    DClickLabel*      clickLabel        = nullptr;
 };
 
 DLabelExpander::DLabelExpander(QWidget* const parent)
     : QWidget(parent),
       d      (new Private)
 {
-    const int spacing = qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
-                             QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing));
+    const int spacing       = layoutSpacing();
 
-    d->grid        = new QGridLayout(this);
-    d->line        = new DLineWidget(Qt::Horizontal, this);
-    d->hbox        = new QWidget(this);
-    d->arrow       = new DArrowClickLabel(d->hbox);
-    d->checkBox    = new QCheckBox(d->hbox);
-    d->pixmapLabel = new QLabel(d->hbox);
-    d->clickLabel  = new DClickLabel(d->hbox);
-    d->btn         = new QToolButton(d->hbox);
+
+    d->grid                 = new QGridLayout(this);
+    d->line                 = new DLineWidget(Qt::Horizontal, this);
+    d->hbox                 = new QWidget(this);
+    d->arrow                = new DArrowClickLabel(d->hbox);
+    d->checkBox             = new QCheckBox(d->hbox);
+    d->pixmapLabel          = new QLabel(d->hbox);
+    d->clickLabel           = new DClickLabel(d->hbox);
+    d->btn                  = new QToolButton(d->hbox);
 
     QHBoxLayout* const hlay = new QHBoxLayout(d->hbox);
     hlay->addWidget(d->arrow);
@@ -535,6 +543,9 @@ DLabelExpander::DLabelExpander(QWidget* const parent)
 
     connect(d->btn, &QToolButton::pressed,
             this, &DLabelExpander::signalButtonPressed);
+
+    connect(ThemeManager::instance(), &ThemeManager::signalThemeChanged,
+            this, &DLabelExpander::slotUpdateIcon);
 }
 
 DLabelExpander::~DLabelExpander()
@@ -584,22 +595,13 @@ QString DLabelExpander::text() const
 
 void DLabelExpander::setIcon(const QIcon& icon)
 {
-    d->pixmapLabel->setPixmap(icon.pixmap(style()->pixelMetric(QStyle::PM_SmallIconSize)));
+    d->icon = icon;
+    slotUpdateIcon();
 }
 
 QIcon DLabelExpander::icon() const
 {
-
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
-
-    return QIcon(d->pixmapLabel->pixmap(Qt::ReturnByValue));
-
-#else
-
-    return QIcon(*d->pixmapLabel->pixmap());
-
-#endif
-
+    return d->icon;
 }
 
 void DLabelExpander::setButtonVisible(bool b)
@@ -615,7 +617,8 @@ bool DLabelExpander::buttonIsVisible() const
 void DLabelExpander::setButtonIcon(const QIcon& icon)
 {
     d->btn->setIcon(icon);
-    d->btn->setIconSize(QSize(style()->pixelMetric(QStyle::PM_SmallIconSize), style()->pixelMetric(QStyle::PM_SmallIconSize)));
+    d->btn->setIconSize(QSize(style()->pixelMetric(QStyle::PM_SmallIconSize),
+                              style()->pixelMetric(QStyle::PM_SmallIconSize)));
 }
 
 void DLabelExpander::setWidget(QWidget* const widget)
@@ -697,6 +700,11 @@ bool DLabelExpander::eventFilter(QObject* obj, QEvent* ev)
     }
 }
 
+void DLabelExpander::slotUpdateIcon()
+{
+    d->pixmapLabel->setPixmap(d->icon.pixmap(style()->pixelMetric(QStyle::PM_SmallIconSize)));
+}
+
 // ------------------------------------------------------------------------
 
 class Q_DECL_HIDDEN DExpanderBox::Private
@@ -704,8 +712,7 @@ class Q_DECL_HIDDEN DExpanderBox::Private
 public:
 
     explicit Private(DExpanderBox* const box)
-      : vbox  (nullptr),
-        parent(box)
+      : parent(box)
     {
     }
 
@@ -714,7 +721,7 @@ public:
     {
         DLabelExpander* const exp = new DLabelExpander(parent->viewport());
         exp->setText(txt);
-        exp->setIcon(icon.pixmap(QApplication::style()->pixelMetric(QStyle::PM_SmallIconSize)));
+        exp->setIcon(icon);
         exp->setWidget(w);
         exp->setLineVisible(!wList.isEmpty());
         exp->setObjectName(objName);
@@ -745,9 +752,9 @@ public:
 
     QList<DLabelExpander*> wList;
 
-    QVBoxLayout*           vbox;
+    QVBoxLayout*           vbox     = nullptr;
 
-    DExpanderBox*          parent;
+    DExpanderBox*          parent   = nullptr;
 };
 
 DExpanderBox::DExpanderBox(QWidget* const parent)
@@ -758,8 +765,8 @@ DExpanderBox::DExpanderBox(QWidget* const parent)
     setWidgetResizable(true);
     QWidget* const main = new QWidget(viewport());
     d->vbox             = new QVBoxLayout(main);
-    d->vbox->setSpacing(qMin(QApplication::style()->pixelMetric(QStyle::PM_LayoutHorizontalSpacing),
-                             QApplication::style()->pixelMetric(QStyle::PM_LayoutVerticalSpacing)));
+    d->vbox->setSpacing(layoutSpacing());
+
     d->vbox->setContentsMargins(QMargins());
     setWidget(main);
 
@@ -844,6 +851,7 @@ void DExpanderBox::slotItemExpanded(bool b)
     if (exp)
     {
         int index = indexOf(exp);
+
         Q_EMIT signalItemExpanded(index, b);
     }
 }
@@ -855,6 +863,7 @@ void DExpanderBox::slotItemButtonPressed()
     if (exp)
     {
         int index = indexOf(exp);
+
         Q_EMIT signalItemButtonPressed(index);
     }
 }
@@ -866,6 +875,7 @@ void DExpanderBox::slotItemToggled(bool b)
     if (exp)
     {
         int index = indexOf(exp);
+
         Q_EMIT signalItemToggled(index, b);
     }
 }
@@ -1095,11 +1105,6 @@ void DExpanderBox::writeSettings(KConfigGroup& group)
 
 DExpanderBoxExclusive::DExpanderBoxExclusive(QWidget* const parent)
     : DExpanderBox(parent)
-{
-    setIsToolBox(true);
-}
-
-DExpanderBoxExclusive::~DExpanderBoxExclusive()
 {
 }
 
