@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_DXML_GUI_WINDOW_H
-#define DIGIKAM_DXML_GUI_WINDOW_H
+#pragma once
 
 // Qt includes
 
@@ -77,10 +76,6 @@ enum StdActionType
     StdForwardAction
 };
 
-static const QString s_configFullScreenHideToolBarsEntry(QLatin1String("FullScreen Hide ToolBars"));
-static const QString s_configFullScreenHideThumbBarEntry(QLatin1String("FullScreen Hide ThumbBar"));
-static const QString s_configFullScreenHideSideBarsEntry(QLatin1String("FullScreen Hide SideBars"));
-static const QString s_configFullScreenHideStatusBarEntry(QLatin1String("FullScreen Hide StatusBar"));
 
 /**
  * Generi class to use with all main window.
@@ -184,6 +179,14 @@ public:
      */
     static void setupIconTheme();
 
+    /**
+     * Shared with FullScreenSettings.
+     */
+    static QString configFullScreenHideToolBarsEntry()  { return QLatin1String("FullScreen Hide ToolBars");  };
+    static QString configFullScreenHideThumbBarEntry()  { return QLatin1String("FullScreen Hide ThumbBar");  };
+    static QString configFullScreenHideSideBarsEntry()  { return QLatin1String("FullScreen Hide SideBars");  };
+    static QString configFullScreenHideStatusBarEntry() { return QLatin1String("FullScreen Hide StatusBar"); };
+
 protected:
 
     DLogoAction* m_animLogo;
@@ -290,15 +293,13 @@ private:
 
 private:
 
-    bool m_winLoaded;
-    bool m_maximized;
+    bool m_winLoaded = false;
+    bool m_maximized = false;
 
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_DXML_GUI_WINDOW_H
