@@ -6,20 +6,11 @@
  * Date        : 2014-11-30
  * Description : Save space slider widget
  *
- * Copyright (C) 2014-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C)      2010 by Justin Noel <justin at ics dot com>
- * Copyright (C)      2010 by Cyrille Berger <cberger at cberger dot net>
+ * SPDX-FileCopyrightText: 2014-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText:      2010 by Justin Noel <justin at ics dot com>
+ * SPDX-FileCopyrightText:      2010 by Cyrille Berger <cberger at cberger dot net>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -47,71 +38,57 @@ class Q_DECL_HIDDEN DAbstractSliderSpinBoxPrivate
 {
 public:
 
-    DAbstractSliderSpinBoxPrivate()
-      : edit(nullptr),
-        validator(nullptr),
-        dummySpinBox(nullptr),
-        upButtonDown(false),
-        downButtonDown(false),
-        factor(1.0),
-        fastSliderStep(5),
-        slowFactor(0.1),
-        shiftPercent(0.0),
-        shiftMode(false),
-        exponentRatio(0.0),
-        value(0),
-        maximum(100),
-        minimum(0),
-        singleStep(1),
-        style(STYLE_NOQUIRK),
-        blockUpdateSignalOnDrag(false),
-        isDragging             (false)
-    {
-    }
-
     enum Style
     {
         STYLE_NOQUIRK,
+        STYLE_MACINTOSH,
         STYLE_PLASTIQUE,
+        STYLE_WINDOWS,
         STYLE_BREEZE,
         STYLE_FUSION,
         STYLE_OXYGEN,
         STYLE_GTK2
     };
 
-    QLineEdit*        edit;
-    QDoubleValidator* validator;
-    QSpinBox*         dummySpinBox;
-    bool              upButtonDown;
-    bool              downButtonDown;
-    int               factor;
-    int               fastSliderStep;
-    double            slowFactor;
-    double            shiftPercent;
-    bool              shiftMode;
+public:
+
+    DAbstractSliderSpinBoxPrivate() = default;
+
+public:
+
+    QLineEdit*        edit                      = nullptr;
+    QDoubleValidator* validator                 = nullptr;
+    QSpinBox*         dummySpinBox              = nullptr;
+    bool              upButtonDown              = false;
+    bool              downButtonDown            = false;
+    int               factor                    = 1;
+    int               fastSliderStep            = 5;
+    double            slowFactor                = 0.1;
+    double            shiftPercent              = 0.0;
+    bool              shiftMode                 = false;
     QString           prefix;
     QString           suffix;
-    double            exponentRatio;
-    int               value;
-    int               maximum;
-    int               minimum;
-    int               singleStep;
-    Style             style;
-    bool              blockUpdateSignalOnDrag;
-    bool              isDragging;
+    double            exponentRatio             = 0.0;
+    int               value                     = 0;
+    int               maximum                   = 100;
+    int               minimum                   = 0;
+    int               singleStep                = 1;
+    Style             style                     = STYLE_NOQUIRK;
+    bool              blockUpdateSignalOnDrag   = false;
+    bool              isDragging                = false;
 };
 
 DAbstractSliderSpinBox::DAbstractSliderSpinBox(QWidget* const parent, DAbstractSliderSpinBoxPrivate* const q)
     : QWidget(parent),
-      d_ptr(q)
+      d_ptr  (q)
 {
     Q_D(DAbstractSliderSpinBox);
 
     QEvent e(QEvent::StyleChange);
-    changeEvent(&e);
+    this->changeEvent(&e);
 
-    d->edit = new QLineEdit(this);
-    d->edit->setContentsMargins(0, 0, 0, 0);
+    d->edit     = new QLineEdit(this);
+    d->edit->setContentsMargins(QMargins());
     d->edit->setAlignment(Qt::AlignCenter);
     d->edit->installEventFilter(this);
     d->edit->setFrame(false);
@@ -146,6 +123,7 @@ DAbstractSliderSpinBox::DAbstractSliderSpinBox(QWidget* const parent, DAbstractS
 DAbstractSliderSpinBox::~DAbstractSliderSpinBox()
 {
     Q_D(DAbstractSliderSpinBox);
+
     delete d;
 }
 
@@ -191,21 +169,29 @@ void DAbstractSliderSpinBox::paintEvent(QPaintEvent* e)
 
     switch (d->style)
     {
-        case DAbstractSliderSpinBoxPrivate::STYLE_FUSION:
-            paintFusion(painter);
-            break;
-
         case DAbstractSliderSpinBoxPrivate::STYLE_PLASTIQUE:
+        {
             paintPlastique(painter);
             break;
+        }
 
         case DAbstractSliderSpinBoxPrivate::STYLE_BREEZE:
+        {
             paintBreeze(painter);
             break;
+        }
+
+        case DAbstractSliderSpinBoxPrivate::STYLE_FUSION:
+        {
+            paintFusion(painter);
+            break;
+        }
 
         default:
+        {
             paint(painter);
             break;
+        }
     }
 
     painter.end();
@@ -236,8 +222,12 @@ void DAbstractSliderSpinBox::paint(QPainter& painter)
 
     QStyleOptionProgressBar progressOpts = progressBarOptions();
 
-    if ((d->style == DAbstractSliderSpinBoxPrivate::STYLE_GTK2) ||
-        (d->style == DAbstractSliderSpinBoxPrivate::STYLE_OXYGEN))
+    if (
+        (d->style == DAbstractSliderSpinBoxPrivate::STYLE_GTK2)    ||
+        (d->style == DAbstractSliderSpinBoxPrivate::STYLE_OXYGEN)  ||
+        (d->style == DAbstractSliderSpinBoxPrivate::STYLE_WINDOWS) ||
+        (d->style == DAbstractSliderSpinBoxPrivate::STYLE_MACINTOSH)
+       )
     {
         progressOpts.state |= QStyle::State_Horizontal;
     }
@@ -292,7 +282,7 @@ void DAbstractSliderSpinBox::paintFusion(QPainter& painter)
     }
 
     QRegion rightRect = rect;
-    rightRect = rightRect.subtracted(leftRect);
+    rightRect         = rightRect.subtracted(leftRect);
 
     QTextOption textOption(Qt::AlignAbsolute | Qt::AlignHCenter | Qt::AlignVCenter);
     textOption.setWrapMode(QTextOption::NoWrap);
@@ -338,7 +328,7 @@ void DAbstractSliderSpinBox::paintPlastique(QPainter& painter)
 
     painter.save();
 
-    QRect rect = progressOpts.rect.adjusted(2, 0, -2, 0);
+    QRect rect               = progressOpts.rect.adjusted(2, 0, -2, 0);
     QRect leftRect;
 
     int progressIndicatorPos = (progressOpts.progress - double(progressOpts.minimum)) / qMax(double(1.0),
@@ -358,7 +348,7 @@ void DAbstractSliderSpinBox::paintPlastique(QPainter& painter)
     }
 
     QRegion rightRect = rect;
-    rightRect = rightRect.subtracted(leftRect);
+    rightRect         = rightRect.subtracted(leftRect);
 
     QTextOption textOption(Qt::AlignAbsolute | Qt::AlignHCenter | Qt::AlignVCenter);
     textOption.setWrapMode(QTextOption::NoWrap);
@@ -497,16 +487,20 @@ void DAbstractSliderSpinBox::mouseReleaseEvent(QMouseEvent* e)
     {
         setInternalValue(d->value - d->singleStep);
     }
-    else if (progressRect(spinOpts).contains(e->pos()) &&
-             !(d->edit->isVisible())                      &&
-             !(d->upButtonDown || d->downButtonDown))
+    else if (
+             progressRect(spinOpts).contains(e->pos()) &&
+             !(d->edit->isVisible())                   &&
+             !(d->upButtonDown || d->downButtonDown)
+            )
     {
         // Snap to percentage for progress area
+
         setInternalValue(valueForX(e->pos().x(),e->modifiers()));
     }
     else
     {
         // Confirm the last known value, since we might be ignoring move events
+
         setInternalValue(d->value);
     }
 
@@ -524,7 +518,7 @@ void DAbstractSliderSpinBox::mouseMoveEvent(QMouseEvent* e)
         if (!d->shiftMode)
         {
             d->shiftPercent = pow(double(d->value - d->minimum) / double(d->maximum - d->minimum), 1 / double(d->exponentRatio));
-            d->shiftMode = true;
+            d->shiftMode    = true;
         }
     }
     else
@@ -534,7 +528,10 @@ void DAbstractSliderSpinBox::mouseMoveEvent(QMouseEvent* e)
 
     // Respect emulated mouse grab.
 
-    if (e->buttons() & Qt::LeftButton && !(d->downButtonDown || d->upButtonDown))
+    if (
+        (e->buttons() & Qt::LeftButton) &&
+        !(d->downButtonDown || d->upButtonDown)
+       )
     {
         d->isDragging = true;
         setInternalValue(valueForX(e->pos().x(),e->modifiers()), d->blockUpdateSignalOnDrag);
@@ -550,6 +547,7 @@ void DAbstractSliderSpinBox::keyPressEvent(QKeyEvent* e)
     {
         case Qt::Key_Up:
         case Qt::Key_Right:
+        {
             setInternalValue(d->value + d->singleStep);
 
             if (d->edit->isVisible())
@@ -559,9 +557,11 @@ void DAbstractSliderSpinBox::keyPressEvent(QKeyEvent* e)
 
             update();
             break;
+        }
 
         case Qt::Key_Down:
         case Qt::Key_Left:
+        {
             setInternalValue(d->value - d->singleStep);
 
             if (d->edit->isVisible())
@@ -571,11 +571,14 @@ void DAbstractSliderSpinBox::keyPressEvent(QKeyEvent* e)
 
             update();
             break;
+        }
 
         case Qt::Key_Shift:
+        {
             d->shiftPercent = pow(double(d->value - d->minimum) / double(d->maximum - d->minimum), 1 / double(d->exponentRatio));
-            d->shiftMode = true;
+            d->shiftMode    = true;
             break;
+        }
 
         case Qt::Key_Enter: // Line edit isn't "accepting" key strokes...
         case Qt::Key_Return:
@@ -585,16 +588,20 @@ void DAbstractSliderSpinBox::keyPressEvent(QKeyEvent* e)
         case Qt::Key_AltGr:
         case Qt::Key_Super_L:
         case Qt::Key_Super_R:
+        {
             break;
+        }
 
         default:
+        {
             showEdit();
             d->edit->event(e);
             break;
+        }
     }
 }
 
-void DAbstractSliderSpinBox::wheelEvent(QWheelEvent *e)
+void DAbstractSliderSpinBox::wheelEvent(QWheelEvent* e)
 {
     Q_D(DAbstractSliderSpinBox);
 
@@ -625,7 +632,10 @@ bool DAbstractSliderSpinBox::eventFilter(QObject* recv, QEvent* e)
 {
     Q_D(DAbstractSliderSpinBox);
 
-    if (recv == static_cast<QObject*>(d->edit) && e->type() == QEvent::KeyRelease)
+    if (
+        (recv == static_cast<QObject*>(d->edit)) &&
+        (e->type() == QEvent::KeyRelease)
+       )
     {
         QKeyEvent* keyEvent = static_cast<QKeyEvent*>(e);
 
@@ -633,17 +643,23 @@ bool DAbstractSliderSpinBox::eventFilter(QObject* recv, QEvent* e)
         {
             case Qt::Key_Enter:
             case Qt::Key_Return:
+            {
                 setInternalValue(QLocale::system().toDouble(d->edit->text()) * d->factor);
                 hideEdit();
                 return true;
+            }
 
             case Qt::Key_Escape:
+            {
                 d->edit->setText(valueString());
                 hideEdit();
                 return true;
+            }
 
             default:
+            {
                 break;
+            }
         }
     }
     else if (d->edit->isVisible() && e->type() == QEvent::ShortcutOverride)
@@ -656,11 +672,15 @@ bool DAbstractSliderSpinBox::eventFilter(QObject* recv, QEvent* e)
             case Qt::Key_Enter:
             case Qt::Key_Return:
             case Qt::Key_Escape:
+            {
                 e->accept();
                 return true;
+            }
 
             default:
+            {
                 break;
+            }
         }
     }
 
@@ -678,6 +698,7 @@ QSize DAbstractSliderSpinBox::sizeHint() const
     {
         // Some styles use bold font in progressbars
         // unfortunately there is no reliable way to check for that
+
         ft.setBold(true);
     }
 
@@ -687,38 +708,45 @@ QSize DAbstractSliderSpinBox::sizeHint() const
 
     switch (d->style)
     {
-        case DAbstractSliderSpinBoxPrivate::STYLE_FUSION:
-            hint += QSize(8, 8);
-            break;
-
         case DAbstractSliderSpinBoxPrivate::STYLE_PLASTIQUE:
+        {
             hint += QSize(8, 0);
             break;
+        }
 
         case DAbstractSliderSpinBoxPrivate::STYLE_BREEZE:
+        {
             hint += QSize(2, 0);
             break;
+        }
 
+        case DAbstractSliderSpinBoxPrivate::STYLE_MACINTOSH:
+        case DAbstractSliderSpinBoxPrivate::STYLE_WINDOWS:
+        case DAbstractSliderSpinBoxPrivate::STYLE_FUSION:
         case DAbstractSliderSpinBoxPrivate::STYLE_OXYGEN:
-            hint += QSize(8, 8);
-            break;
-
         case DAbstractSliderSpinBoxPrivate::STYLE_GTK2:
+        {
             hint += QSize(8, 8);
             break;
+        }
 
         case DAbstractSliderSpinBoxPrivate::STYLE_NOQUIRK:
+        {
             // almost all "modern" styles have a margin around controls
             hint += QSize(6, 6);
             break;
+        }
 
         default:
+        {
             break;
+        }
     }
 
     // Getting the size of the buttons is a pain as the calcs require a rect
     // that is "big enough". We run the calc twice to get the "smallest" buttons
     // This code was inspired by QAbstractSpinBox
+
     QSize extra(1000, 0);
     spinOpts.rect.setSize(hint + extra);
     extra += hint - style()->subControlRect(QStyle::CC_SpinBox, &spinOpts,
@@ -730,8 +758,7 @@ QSize DAbstractSliderSpinBox::sizeHint() const
 
     spinOpts.rect.setSize(hint);
 
-    return style()->sizeFromContents(QStyle::CT_SpinBox, &spinOpts, hint)
-                                     .expandedTo(QApplication::globalStrut());
+    return style()->sizeFromContents(QStyle::CT_SpinBox, &spinOpts, hint);
 }
 
 QSize DAbstractSliderSpinBox::minimumSizeHint() const
@@ -825,15 +852,21 @@ QRect DAbstractSliderSpinBox::progressRect(const QStyleOptionSpinBox& spinBoxOpt
     switch (d->style)
     {
         case DAbstractSliderSpinBoxPrivate::STYLE_PLASTIQUE:
+        {
             ret.adjust(-2, 0, 1, 0);
             break;
+        }
 
         case DAbstractSliderSpinBoxPrivate::STYLE_BREEZE:
+        {
             ret.adjust(1, 0, 0, 0);
             break;
+        }
 
         default:
+        {
             break;
+        }
     }
 
     return ret;
@@ -870,14 +903,17 @@ int DAbstractSliderSpinBox::valueForX(int x, Qt::KeyboardModifiers modifiers) co
     else
     {
         // Adjust for magic number in style code (margins)
+
         correctedProgRect = progressRect(spinOpts).adjusted(2, 2, -2, -2);
     }
 
     // Compute the distance of the progress bar, in pixel
+
     double leftDbl  = correctedProgRect.left();
     double xDbl     = x - leftDbl;
 
     // Compute the ration of the progress bar used, linearly (ignoring the exponent)
+
     double rightDbl = correctedProgRect.right();
     double minDbl   = d->minimum;
     double maxDbl   = d->maximum;
@@ -886,14 +922,18 @@ int DAbstractSliderSpinBox::valueForX(int x, Qt::KeyboardModifiers modifiers) co
     double percent  = (xDbl / (rightDbl - leftDbl));
 
     // If SHIFT is pressed, movement should be slowed.
+
     if (modifiers & Qt::ShiftModifier)
     {
         percent = d->shiftPercent + (percent - d->shiftPercent) * d->slowFactor;
     }
 
     // Final value
+
     double realvalue = ((dValues * pow(percent, d->exponentRatio)) + minDbl);
+
     // If key CTRL is pressed, round to the closest step.
+
     if (modifiers & Qt::ControlModifier)
     {
         double fstep = d->fastSliderStep;
@@ -903,7 +943,7 @@ int DAbstractSliderSpinBox::valueForX(int x, Qt::KeyboardModifiers modifiers) co
             fstep *= d->slowFactor;
         }
 
-        realvalue = floor((realvalue+fstep / 2) / fstep) * fstep;
+        realvalue = floor((realvalue + fstep / 2) / fstep) * fstep;
     }
 
     return int(realvalue);
@@ -912,25 +952,30 @@ int DAbstractSliderSpinBox::valueForX(int x, Qt::KeyboardModifiers modifiers) co
 void DAbstractSliderSpinBox::setPrefix(const QString& prefix)
 {
     Q_D(DAbstractSliderSpinBox);
+
     d->prefix = prefix;
 }
 
 void DAbstractSliderSpinBox::setSuffix(const QString& suffix)
 {
     Q_D(DAbstractSliderSpinBox);
+
     d->suffix = suffix;
 }
 
 void DAbstractSliderSpinBox::setExponentRatio(double dbl)
 {
     Q_D(DAbstractSliderSpinBox);
+
     Q_ASSERT(dbl > 0);
+
     d->exponentRatio = dbl;
 }
 
 void DAbstractSliderSpinBox::setBlockUpdateSignalOnDrag(bool blockUpdateSignal)
 {
     Q_D(DAbstractSliderSpinBox);
+
     d->blockUpdateSignalOnDrag = blockUpdateSignal;
 }
 
@@ -962,6 +1007,7 @@ void DAbstractSliderSpinBox::setInternalValue(int value)
 bool DAbstractSliderSpinBox::isDragging() const
 {
     Q_D(const DAbstractSliderSpinBox);
+
     return d->isDragging;
 }
 
@@ -973,18 +1019,26 @@ void DAbstractSliderSpinBox::changeEvent(QEvent* e)
 
     if (e->type() == QEvent::StyleChange)
     {
-        if      (style()->objectName() == QLatin1String("fusion"))
+        if      (style()->objectName() == QLatin1String("macintosh"))
         {
-            d->style = DAbstractSliderSpinBoxPrivate::STYLE_FUSION;
+            d->style = DAbstractSliderSpinBoxPrivate::STYLE_MACINTOSH;
         }
         else if (style()->objectName() == QLatin1String("plastique"))
         {
             d->style = DAbstractSliderSpinBoxPrivate::STYLE_PLASTIQUE;
         }
+        else if (style()->objectName() == QLatin1String("windows"))
+        {
+            d->style = DAbstractSliderSpinBoxPrivate::STYLE_WINDOWS;
+        }
         else if (style()->objectName() == QLatin1String("breeze"))
         {
             d->style = DAbstractSliderSpinBoxPrivate::STYLE_BREEZE;
         }
+        else if (style()->objectName() == QLatin1String("fusion"))
+        {
+            d->style = DAbstractSliderSpinBoxPrivate::STYLE_FUSION;
+        }
         else if (style()->objectName() == QLatin1String("oxygen"))
         {
             d->style = DAbstractSliderSpinBoxPrivate::STYLE_OXYGEN;
@@ -1012,10 +1066,6 @@ DSliderSpinBox::DSliderSpinBox(QWidget* const parent)
     setRange(0, 99);
 }
 
-DSliderSpinBox::~DSliderSpinBox()
-{
-}
-
 void DSliderSpinBox::setRange(int minimum, int maximum)
 {
     Q_D(DSliderSpinBox);
@@ -1037,6 +1087,7 @@ int DSliderSpinBox::minimum() const
 void DSliderSpinBox::setMinimum(int minimum)
 {
     Q_D(DSliderSpinBox);
+
     setRange(minimum, d->maximum);
 }
 
@@ -1050,6 +1101,7 @@ int DSliderSpinBox::maximum() const
 void DSliderSpinBox::setMaximum(int maximum)
 {
     Q_D(DSliderSpinBox);
+
     setRange(d->minimum, maximum);
 }
 
@@ -1063,6 +1115,7 @@ int DSliderSpinBox::fastSliderStep() const
 void DSliderSpinBox::setFastSliderStep(int step)
 {
     Q_D(DSliderSpinBox);
+
     d->fastSliderStep = step;
 }
 
@@ -1091,6 +1144,7 @@ QString DSliderSpinBox::valueString() const
 void DSliderSpinBox::setSingleStep(int value)
 {
     Q_D(DSliderSpinBox);
+
     d->singleStep = value;
 }
 
@@ -1107,7 +1161,7 @@ void DSliderSpinBox::setInternalValue(int _value, bool blockUpdateSignal)
 
     if (!blockUpdateSignal)
     {
-        emit valueChanged(value());
+        Q_EMIT valueChanged(value());
     }
 }
 
@@ -1122,10 +1176,6 @@ DDoubleSliderSpinBox::DDoubleSliderSpinBox(QWidget* const parent)
 {
 }
 
-DDoubleSliderSpinBox::~DDoubleSliderSpinBox()
-{
-}
-
 void DDoubleSliderSpinBox::setRange(double minimum, double maximum, int decimals)
 {
     Q_D(DDoubleSliderSpinBox);
@@ -1141,6 +1191,7 @@ void DDoubleSliderSpinBox::setRange(double minimum, double maximum, int decimals
     if      (((maximum - minimum) >= 2.0) || (decimals <= 0))
     {
         // Quick step on integers
+
         d->fastSliderStep = int(pow(10.0, decimals));
     }
     else if (decimals == 1)
@@ -1167,6 +1218,7 @@ double DDoubleSliderSpinBox::minimum() const
 void DDoubleSliderSpinBox::setMinimum(double minimum)
 {
     Q_D(DAbstractSliderSpinBox);
+
     setRange(minimum, d->maximum);
 }
 
@@ -1180,6 +1232,7 @@ double DDoubleSliderSpinBox::maximum() const
 void DDoubleSliderSpinBox::setMaximum(double maximum)
 {
     Q_D(DAbstractSliderSpinBox);
+
     setRange(d->minimum, maximum);
 }
 
@@ -1193,6 +1246,7 @@ double DDoubleSliderSpinBox::fastSliderStep() const
 void DDoubleSliderSpinBox::setFastSliderStep(double step)
 {
     Q_D(DAbstractSliderSpinBox);
+
     d->fastSliderStep = step;
 }
 
@@ -1214,6 +1268,7 @@ void DDoubleSliderSpinBox::setValue(double value)
 void DDoubleSliderSpinBox::setSingleStep(double value)
 {
     Q_D(DAbstractSliderSpinBox);
+
     d->singleStep = value * d->factor;
 }
 
@@ -1234,8 +1289,10 @@ void DDoubleSliderSpinBox::setInternalValue(int _value, bool blockUpdateSignal)
 
     if (!blockUpdateSignal)
     {
-        emit valueChanged(value());
+        Q_EMIT valueChanged(value());
     }
 }
 
 } // namespace Digikam
+
+#include "moc_dsliderspinbox.cpp"
