@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef SHOWFOTO_STACK_VIEW_FAVORITE_ITEM_DLG_H
-#define SHOWFOTO_STACK_VIEW_FAVORITE_ITEM_DLG_H
+#pragma once
 
 // Qt includes
 
@@ -114,9 +113,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace ShowFoto
-
-#endif // SHOWFOTO_STACK_VIEW_FAVORITE_ITEM_DLG_H
