@@ -14,8 +14,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_FACE_ENGINE_DEMO_MAIN_WINDOW_H
-#define DIGIKAM_FACE_ENGINE_DEMO_MAIN_WINDOW_H
+#pragma once
 
 // Qt includes
 
@@ -53,9 +52,7 @@ private:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace FaceEngineDemo
-
-#endif // DIGIKAM_FACE_ENGINE_DEMO_MAIN_WINDOW_H
