@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_FACE_SCAN_SETTINGS_H
-#define DIGIKAM_FACE_SCAN_SETTINGS_H
+#pragma once
 
 // Local includes
 
@@ -38,7 +37,7 @@ public:
         BenchmarkRecognition
     };
 
-    /// For detect and recognize
+    /// To detect and recognize
     enum AlreadyScannedHandling
     {
         Skip,
@@ -49,22 +48,22 @@ public:
 
 public:
 
-    explicit FaceScanSettings();
-    ~FaceScanSettings();
+    FaceScanSettings()  = default;
+    ~FaceScanSettings() = default;
 
 public:
 
     /// whole albums checked
-    bool                                    wholeAlbums;
+    bool                                    wholeAlbums                 = false;
 
     /// Processing power
-    bool                                    useFullCpu;
+    bool                                    useFullCpu                  = false;
 
     /// Use Yolo V3 model
-    bool                                    useYoloV3;
+    bool                                    useYoloV3                   = false;
 
     /// Detection accuracy
-    double                                  accuracy;
+    double                                  accuracy                    = 0.7;
 
     /// Albums to scan
     AlbumList                               albums;
@@ -72,11 +71,9 @@ public:
     /// Image infos to scan
     ItemInfoList                            infos;
 
-    ScanTask                                task;
+    ScanTask                                task                        = Detect;
 
-    AlreadyScannedHandling                  alreadyScannedHandling;
+    AlreadyScannedHandling                  alreadyScannedHandling      = Skip;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_FACE_SCAN_SETTINGS_H
