@@ -56,6 +56,7 @@ void FaceGroup::itemStateChanged(int itemState)
         case DImgPreviewItem::ImageLoadingFailed:
         {
             d->visibilityController->hide();
+
             break;
         }
 
@@ -357,7 +358,7 @@ void FaceGroup::clear()
     cancelAddItem();
     d->visibilityController->clear();
 
-    Q_FOREACH (RegionFrameItem* const item, d->items)
+    Q_FOREACH (FaceItem* const item, d->items)
     {
         delete item;
     }
@@ -453,7 +454,7 @@ void FaceGroup::slotAssigned(const TaggingAction& action, const ItemInfo&, const
         else if (action.shallCreateNewTag())
         {
             QStringList faceNames = action.newTagName().split(QLatin1Char('/'),
-                                                              QT_SKIP_EMPTY_PARTS);
+                                                              Qt::SkipEmptyParts);
             if (!faceNames.isEmpty())
             {
                 tagId             = action.parentTagId();
