@@ -6,18 +6,9 @@
  * Date        : 2017-05-15
  * Description : low level manager for bookmarks
  *
- * Copyright (C) 2017-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2017-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -56,8 +47,7 @@ RemoveBookmarksCommand::RemoveBookmarksCommand(BookmarksManager* const mngr,
       m_row            (row),
       m_bookmarkManager(mngr),
       m_node           (parent->children().value(row)),
-      m_parent         (parent),
-      m_done           (false)
+      m_parent         (parent)
 {
 }
 
@@ -72,14 +62,18 @@ RemoveBookmarksCommand::~RemoveBookmarksCommand()
 void RemoveBookmarksCommand::undo()
 {
     m_parent->add(m_node, m_row);
-    emit m_bookmarkManager->entryAdded(m_node);
+
+    Q_EMIT m_bookmarkManager->entryAdded(m_node);
+
     m_done = false;
 }
 
 void RemoveBookmarksCommand::redo()
 {
     m_parent->remove(m_node);
-    emit m_bookmarkManager->entryRemoved(m_parent, m_row, m_node);
+
+    Q_EMIT m_bookmarkManager->entryRemoved(m_parent, m_row, m_node);
+
     m_done = true;
 }
 
@@ -111,18 +105,13 @@ class Q_DECL_HIDDEN ChangeBookmarkCommand::Private
 {
 public:
 
-    explicit Private()
-      : manager (nullptr),
-        type    (Url),
-        node    (nullptr)
-    {
-    }
+    Private() = default;
 
-    BookmarksManager* manager;
-    BookmarkData      type;
+    BookmarksManager* manager   = nullptr;
+    BookmarkData      type      = Url;
     QString           oldValue;
     QString           newValue;
-    BookmarkNode*     node;
+    BookmarkNode*     node      = nullptr;
 };
 
 ChangeBookmarkCommand::ChangeBookmarkCommand(BookmarksManager* const mngr,
@@ -190,7 +179,7 @@ void ChangeBookmarkCommand::undo()
         }
     }
 
-    emit d->manager->entryChanged(d->node);
+    Q_EMIT d->manager->entryChanged(d->node);
 }
 
 void ChangeBookmarkCommand::redo()
@@ -216,7 +205,7 @@ void ChangeBookmarkCommand::redo()
         }
     }
 
-    emit d->manager->entryChanged(d->node);
+    Q_EMIT d->manager->entryChanged(d->node);
 }
 
 // --------------------------------------------------------------
@@ -225,14 +214,10 @@ class Q_DECL_HIDDEN BookmarksModel::Private
 {
 public:
 
-    explicit Private()
-      : manager (nullptr),
-        endMacro(false)
-    {
-    }
+    Private() = default;
 
-    BookmarksManager* manager;
-    bool              endMacro;
+    BookmarksManager* manager   = nullptr;
+    bool              endMacro  = false;
 };
 
 BookmarksModel::BookmarksModel(BookmarksManager* const mngr, QObject* const parent)
@@ -301,7 +286,8 @@ void BookmarksModel::entryRemoved(BookmarkNode* parent, int row, BookmarkNode* i
 void BookmarksModel::entryChanged(BookmarkNode* item)
 {
     QModelIndex idx = index(item);
-    emit dataChanged(idx, idx);
+
+    Q_EMIT dataChanged(idx, idx);
 }
 
 bool BookmarksModel::removeRows(int row, int count, const QModelIndex& parent)
@@ -330,7 +316,7 @@ bool BookmarksModel::removeRows(int row, int count, const QModelIndex& parent)
 
 QVariant BookmarksModel::headerData(int section, Qt::Orientation orientation, int role) const
 {
-    if (orientation == Qt::Horizontal && role == Qt::DisplayRole)
+    if ((orientation == Qt::Horizontal) && (role == Qt::DisplayRole))
     {
         switch (section)
         {
@@ -369,7 +355,7 @@ QVariant BookmarksModel::data(const QModelIndex& index, int role) const
                 {
                     case 0:
                     {
-                        return QString(50, 0xB7);
+                        return QString(50, QChar(0xB7));
                     }
 
                     case 1:
@@ -509,8 +495,10 @@ bool BookmarksModel::hasChildren(const QModelIndex& parent) const
 
     const BookmarkNode* const parentNode = node(parent);
 
-    return ((parentNode->type() == BookmarkNode::Folder) ||
-            (parentNode->type() == BookmarkNode::RootFolder));
+    return (
+            (parentNode->type() == BookmarkNode::Folder) ||
+            (parentNode->type() == BookmarkNode::RootFolder)
+           );
 }
 
 Qt::ItemFlags BookmarksModel::flags(const QModelIndex& index) const
@@ -528,8 +516,10 @@ Qt::ItemFlags BookmarksModel::flags(const QModelIndex& index) const
         flags |= Qt::ItemIsDragEnabled;
     }
 
-    if ((bookmarkNode->type() != BookmarkNode::Separator) &&
-        (bookmarkNode->type() != BookmarkNode::RootFolder))
+    if (
+        (bookmarkNode->type() != BookmarkNode::Separator) &&
+        (bookmarkNode->type() != BookmarkNode::RootFolder)
+       )
     {
         flags |= Qt::ItemIsEditable;
     }
@@ -561,7 +551,7 @@ QMimeData* BookmarksModel::mimeData(const QModelIndexList& indexes) const
     QByteArray data;
     QDataStream stream(&data, QIODevice::WriteOnly);
 
-    foreach (QModelIndex index, indexes)
+    Q_FOREACH (QModelIndex index, indexes)
     {
         if ((index.column() != 0) || !index.isValid())
         {
@@ -741,7 +731,16 @@ bool TreeProxyModel::filterAcceptsRow(int srow, const QModelIndex& sparent) cons
         return false;
     }
 
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+
+    if (index.data().toString().contains(filterRegularExpression()))
+
+#else
+
     if (index.data().toString().contains(filterRegExp()))
+
+#endif
+
     {
         return true;
     }
@@ -759,7 +758,7 @@ bool TreeProxyModel::filterAcceptsRow(int srow, const QModelIndex& sparent) cons
 
 void TreeProxyModel::emitResult(bool v)
 {
-    emit signalFilterAccepts(v);
+    Q_EMIT signalFilterAccepts(v);
 }
 
 // --------------------------------------------------------------
@@ -768,16 +767,11 @@ class Q_DECL_HIDDEN BookmarksManager::Private
 {
 public:
 
-    explicit Private()
-      : loaded          (false),
-        bookmarkRootNode(nullptr),
-        bookmarkModel   (nullptr)
-    {
-    }
+    Private() = default;
 
-    bool            loaded;
-    BookmarkNode*   bookmarkRootNode;
-    BookmarksModel* bookmarkModel;
+    bool            loaded              = false;
+    BookmarkNode*   bookmarkRootNode    = nullptr;
+    BookmarksModel* bookmarkModel       = nullptr;
     QUndoStack      commands;
     QString         bookmarksFile;
 };
@@ -815,7 +809,7 @@ void BookmarksManager::load()
 
     if (reader.error() != QXmlStreamReader::NoError)
     {
-        QMessageBox::warning(nullptr, i18n("Loading Bookmark"),
+        QMessageBox::warning(nullptr, i18nc("@title:window", "Loading Bookmark"),
                              i18n("Error when loading bookmarks on line %1, column %2:\n%3",
                                   reader.lineNumber(),
                                   reader.columnNumber(),
@@ -937,7 +931,7 @@ QUndoStack* BookmarksManager::undoRedoStack() const
 
 void BookmarksManager::importBookmarks()
 {
-    QString fileName = DFileDialog::getOpenFileName(nullptr, i18n("Open File"),
+    QString fileName = DFileDialog::getOpenFileName(nullptr, i18nc("@title:window", "Open File"),
                                                     QString(),
                                                     i18n("XBEL (*.xbel *.xml)"));
     if (fileName.isEmpty())
@@ -950,7 +944,7 @@ void BookmarksManager::importBookmarks()
 
     if (reader.error() != QXmlStreamReader::NoError)
     {
-        QMessageBox::warning(nullptr, i18n("Loading Bookmark"),
+        QMessageBox::warning(nullptr, i18nc("@title:window", "Loading Bookmark"),
                              i18n("Error when loading bookmarks on line %1, column %2:\n%3",
                                   reader.lineNumber(),
                                   reader.columnNumber(),
@@ -958,13 +952,13 @@ void BookmarksManager::importBookmarks()
     }
 
     importRootNode->setType(BookmarkNode::Folder);
-    importRootNode->title = i18n("Imported %1", QDate::currentDate().toString(Qt::SystemLocaleShortDate));
+    importRootNode->title = i18n("Imported %1", QLocale().toString(QDate::currentDate(), QLocale::ShortFormat));
     addBookmark(bookmarks(), importRootNode);
 }
 
 void BookmarksManager::exportBookmarks()
 {
-    QString fileName = DFileDialog::getSaveFileName(nullptr, i18n("Save File"),
+    QString fileName = DFileDialog::getSaveFileName(nullptr, i18nc("@title:window", "Save File"),
                                                     i18n("%1 Bookmarks.xbel", QCoreApplication::applicationName()),
                                                     i18n("XBEL (*.xbel *.xml)"));
     if (fileName.isEmpty())
@@ -976,8 +970,10 @@ void BookmarksManager::exportBookmarks()
 
     if (!writer.write(fileName, d->bookmarkRootNode))
     {
-        QMessageBox::critical(nullptr, i18n("Export error"), i18n("error saving bookmarks"));
+        QMessageBox::critical(nullptr, i18nc("@title:window", "Export Bookmark"), i18n("Error saving bookmarks"));
     }
 }
 
 } // namespace Digikam
+
+#include "moc_bookmarksmngr.cpp"
