@@ -6,20 +6,11 @@
  * Date        : 2010-03-26
  * Description : A widget to configure the GPS correlation
  *
- * Copyright (C) 2010-2021 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2010-2014 by Michael G. Hansen <mike at mghansen dot de>
- * Copyright (C) 2014      by Justus Schwartz <justus at gmx dot li>
+ * SPDX-FileCopyrightText: 2010-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2010-2014 by Michael G. Hansen <mike at mghansen dot de>
+ * SPDX-FileCopyrightText: 2014      by Justus Schwartz <justus at gmx dot li>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -73,72 +64,51 @@ class Q_DECL_HIDDEN GPSCorrelatorWidget::Private
 {
 public:
 
-    explicit Private()
-      : gpxLoadFilesButton          (nullptr),
-        gpxFileList                 (nullptr),
-        timeZoneCB                  (nullptr),
-        offsetSign                  (nullptr),
-        offsetTime                  (nullptr),
-        interpolateButton           (nullptr),
-        interpolateLimitLabel       (nullptr),
-        interpolateLimitInput       (nullptr),
-        directMatchButton           (nullptr),
-        directMatchLimitLabel       (nullptr),
-        directMatchLimitInput       (nullptr),
-        showTracksOnMap             (nullptr),
-        correlateButton             (nullptr),
-        trackManager                (nullptr),
-        trackCorrelator             (nullptr),
-        trackListModel              (nullptr),
-        uiEnabledInternal           (true),
-        uiEnabledExternal           (true),
-        imageModel                  (nullptr),
-        correlationTotalCount       (0),
-        correlationCorrelatedCount  (0),
-        correlationTriedCount       (0),
-        correlationUndoCommand      (nullptr)
-    {
-    }
+    Private() = default;
 
     QString                 gpxFileOpenLastDirectory;
-    QPushButton*            gpxLoadFilesButton;
-    QTreeView*              gpxFileList;
+    QPushButton*            gpxLoadFilesButton          = nullptr;
+    QTreeView*              gpxFileList                 = nullptr;
 
-    TimeZoneComboBox*       timeZoneCB;
+    TimeZoneComboBox*       timeZoneCB                  = nullptr;
 
-    QComboBox*              offsetSign;
-    QTimeEdit*              offsetTime;
+    QComboBox*              offsetSign                  = nullptr;
+    QTimeEdit*              offsetTime                  = nullptr;
 
-    QRadioButton*           interpolateButton;
-    QLabel*                 interpolateLimitLabel;
-    QTimeEdit*              interpolateLimitInput;
-    QRadioButton*           directMatchButton;
-    QLabel*                 directMatchLimitLabel;
-    QTimeEdit*              directMatchLimitInput;
-    QCheckBox*              showTracksOnMap;
+    QRadioButton*           interpolateButton           = nullptr;
+    QLabel*                 interpolateLimitLabel       = nullptr;
+    QTimeEdit*              interpolateLimitInput       = nullptr;
+    QRadioButton*           directMatchButton           = nullptr;
+    QLabel*                 directMatchLimitLabel       = nullptr;
+    QTimeEdit*              directMatchLimitInput       = nullptr;
+    QCheckBox*              showTracksOnMap             = nullptr;
+    QCheckBox*              selectedImages              = nullptr;
 
-    QPushButton*            correlateButton;
+    QPushButton*            correlateButton             = nullptr;
 
-    TrackManager*           trackManager;
-    TrackCorrelator*        trackCorrelator;
-    TrackListModel*         trackListModel;
-    bool                    uiEnabledInternal;
-    bool                    uiEnabledExternal;
-    GPSItemModel*           imageModel;
+    TrackManager*           trackManager                = nullptr;
+    TrackCorrelator*        trackCorrelator             = nullptr;
+    TrackListModel*         trackListModel              = nullptr;
+    bool                    uiEnabledInternal           = true;
+    bool                    uiEnabledExternal           = true;
+    GPSItemModel*           imageModel                  = nullptr;
+    QItemSelectionModel*    selectionModel              = nullptr;
 
-    int                     correlationTotalCount;
-    int                     correlationCorrelatedCount;
-    int                     correlationTriedCount;
-    GPSUndoCommand*         correlationUndoCommand;
+    int                     correlationTotalCount       = 0;
+    int                     correlationCorrelatedCount  = 0;
+    int                     correlationTriedCount       = 0;
+    GPSUndoCommand*         correlationUndoCommand      = nullptr;
 };
 
 GPSCorrelatorWidget::GPSCorrelatorWidget(QWidget* const parent,
                                          GPSItemModel* const imageModel,
+                                         QItemSelectionModel* const selectionModel,
                                          TrackManager* const trackManager)
     : QWidget(parent),
-      d      (new Private())
+      d      (new Private)
 {
     d->imageModel      = imageModel;
+    d->selectionModel  = selectionModel;
     d->trackManager    = trackManager;
     d->trackCorrelator = new TrackCorrelator(d->trackManager, this);
     d->trackListModel  = new TrackListModel(d->trackManager, this);
@@ -166,6 +136,10 @@ GPSCorrelatorWidget::GPSCorrelatorWidget(QWidget* const parent,
 
     d->showTracksOnMap                = new QCheckBox(i18n("Show tracks on Map"), this);
     d->showTracksOnMap->setWhatsThis(i18n("Set this option to show tracks on the Map"));
+
+    d->selectedImages                 = new QCheckBox(i18n("Only use selected images"), this);
+    d->selectedImages->setWhatsThis(i18n("Set this option to correlate selected images only"));
+
     DLineWidget* const line           = new DLineWidget(Qt::Horizontal, this);
 
     connect(d->showTracksOnMap, SIGNAL(stateChanged(int)),
@@ -254,9 +228,10 @@ GPSCorrelatorWidget::GPSCorrelatorWidget(QWidget* const parent,
     settingsLayout->addWidget(d->gpxLoadFilesButton, 0, 0, 1, 1);
     settingsLayout->addWidget(d->gpxFileList,        1, 0, 1, 1);
     settingsLayout->addWidget(d->showTracksOnMap,    2, 0, 1, 1);
-    settingsLayout->addWidget(line,                  3, 0, 1, 1);
-    settingsLayout->addWidget(offsetWidget,          4, 0, 1, 1);
-    settingsLayout->addWidget(matchWidget,           5, 0, 4, 1);
+    settingsLayout->addWidget(d->selectedImages,     3, 0, 1, 1);
+    settingsLayout->addWidget(line,                  4, 0, 1, 1);
+    settingsLayout->addWidget(offsetWidget,          5, 0, 1, 1);
+    settingsLayout->addWidget(matchWidget,           6, 0, 4, 1);
     settingsLayout->addWidget(d->correlateButton,    9, 0, 1, 1);
     settingsLayout->setRowStretch(9, 100);
 
@@ -294,7 +269,7 @@ void GPSCorrelatorWidget::slotLoadTrackFiles()
 
     QList<QUrl> list;
 
-    foreach (const QString& str, gpxFiles)
+    Q_FOREACH (const QString& str, gpxFiles)
     {
         list << QUrl::fromLocalFile(str);
     }
@@ -325,8 +300,8 @@ void GPSCorrelatorWidget::slotAllTrackFilesReady()
                                                "The following %1 GPX files could not be loaded:",
                                                invalidFiles.count());
 
-        const QString errorTitleString = i18np("Error loading GPX file",
-                                               "Error loading GPX files",
+        const QString errorTitleString = i18ncp("@title:window", "Error Loading GPX File",
+                                               "Error Loading GPX Files",
                                                invalidFiles.count());
 
         DMessageBox::showInformationList(QMessageBox::Critical,
@@ -336,7 +311,7 @@ void GPSCorrelatorWidget::slotAllTrackFilesReady()
                                          invalidFiles);
     }
 
-    emit signalAllTrackFilesReady();
+    Q_EMIT signalAllTrackFilesReady();
 
     setUIEnabledInternal(true);
 }
@@ -370,7 +345,7 @@ void GPSCorrelatorWidget::slotCorrelate()
 {
     // disable the UI of the entire dialog:
 
-    emit signalSetUIEnabled(false, this, QString::fromUtf8(SLOT(slotCancelCorrelation())));
+    Q_EMIT signalSetUIEnabled(false, this, QString::fromUtf8(SLOT(slotCancelCorrelation())));
 
     // store the options:
 
@@ -392,12 +367,25 @@ void GPSCorrelatorWidget::slotCorrelate()
     // create a list of items to be correlated
 
     TrackCorrelator::Correlation::List itemList;
+    QList<QModelIndex> selectedIndices;
 
-    const int imageCount         = d->imageModel->rowCount();
+    if (d->selectedImages->isChecked())
+    {
+        selectedIndices = d->selectionModel->selectedRows();
+    }
+    else
+    {
+        for (int i = 0 ; i < d->imageModel->rowCount() ; ++i)
+        {
+            selectedIndices << d->imageModel->index(i, 0);
+        }
+    }
+
+    const int imageCount = selectedIndices.size();
 
     for (int i = 0 ; i < imageCount ; ++i)
     {
-        QPersistentModelIndex imageIndex  = d->imageModel->index(i, 0);
+        QPersistentModelIndex imageIndex  = selectedIndices.at(i);
         GPSItemContainer* const imageItem = d->imageModel->itemFromIndex(imageIndex);
 
         if (!imageItem)
@@ -417,7 +405,7 @@ void GPSCorrelatorWidget::slotCorrelate()
     d->correlationTriedCount      = 0;
     d->correlationUndoCommand     = new GPSUndoCommand;
 
-    emit signalProgressSetup(imageCount, i18n("Correlating images -"));
+    Q_EMIT signalProgressSetup(imageCount, i18n("Correlating images -"));
 
     d->trackCorrelator->correlate(itemList, options);
 
@@ -492,32 +480,39 @@ void GPSCorrelatorWidget::slotItemsCorrelated(const Digikam::TrackCorrelator::Co
         }
     }
 
-    emit signalProgressChanged(d->correlationTriedCount);
+    Q_EMIT signalProgressChanged(d->correlationTriedCount);
 }
 
 void GPSCorrelatorWidget::slotAllItemsCorrelated()
 {
     if (d->correlationCorrelatedCount == 0)
     {
-        QMessageBox::warning(this, i18n("Correlation failed"),
+        QMessageBox::warning(this, i18nc("@title:window", "Correlation Failed"),
                              i18n("Could not correlate any image - please make "
                                   "sure the offset and gap settings are correct."));
     }
     else if (d->correlationCorrelatedCount == d->correlationTotalCount)
     {
-        QMessageBox::information(this, i18n("Correlation succeeded"),
+        QMessageBox::information(this, i18nc("@title:window", "Correlation Succeeded"),
                                  i18n("All images have been correlated. You "
                                       "can now check their position on the map."));
     }
     else
     {
-        // note: no need for i18np here, because the case of correlationTotalCount == 1 is covered in the other two cases.
+        // NOTE: Even if the case of correlationTotalCount == 1 is covered in the other two cases, we need i18np.
+        //       See bug #376438 for details.
 
-        QMessageBox::warning(this, i18n("Correlation finished"),
-                             i18n("%1 out of %2 images have been correlated. Please "
-                                  "check the offset and gap settings if you think "
-                                  "that more images should have been correlated.",
-                                  d->correlationCorrelatedCount, d->correlationTotalCount));
+        QMessageBox::warning(this, i18nc("@title:window", "Correlation Finished"),
+                             i18np(
+                                   "One image out of %2 images have been correlated. Please "
+                                   "check the offset and gap settings if you think "
+                                   "that more images should have been correlated.",
+                                   "%1 out of %2 images have been correlated. Please "
+                                   "check the offset and gap settings if you think "
+                                   "that more images should have been correlated.",
+                                   d->correlationCorrelatedCount,
+                                   d->correlationTotalCount)
+                             );
     }
 
     if (d->correlationCorrelatedCount == 0)
@@ -529,17 +524,18 @@ void GPSCorrelatorWidget::slotAllItemsCorrelated()
         d->correlationUndoCommand->setText(i18np("1 image correlated",
                                                  "%1 images correlated",
                                                  d->correlationCorrelatedCount));
-        emit signalUndoCommand(d->correlationUndoCommand);
+        Q_EMIT signalUndoCommand(d->correlationUndoCommand);
     }
 
     // enable the UI
 
-    emit signalSetUIEnabled(true);
+    Q_EMIT signalSetUIEnabled(true);
 }
 
 void GPSCorrelatorWidget::saveSettingsToGroup(KConfigGroup* const group)
 {
     group->writeEntry("ShowTracksOnMap",              d->showTracksOnMap->isChecked());
+    group->writeEntry("SelectedImages",               d->selectedImages->isChecked());
     group->writeEntry("Interpolate",                  d->interpolateButton->isChecked());
     group->writeEntry("Max Inter Dist Time",          d->interpolateLimitInput->time().toString());
     group->writeEntry("Max Gap Time",                 d->directMatchLimitInput->time().toString());
@@ -551,13 +547,14 @@ void GPSCorrelatorWidget::saveSettingsToGroup(KConfigGroup* const group)
 
 void GPSCorrelatorWidget::readSettingsFromGroup(const KConfigGroup* const group)
 {
-    d->showTracksOnMap->setChecked(group->readEntry("ShowTracksOnMap", true));
-    d->interpolateButton->setChecked(group->readEntry("Interpolate", true));
+    d->showTracksOnMap->setChecked(group->readEntry("ShowTracksOnMap",                          true));
+    d->selectedImages->setChecked(group->readEntry("SelectedImages",                            false));
+    d->interpolateButton->setChecked(group->readEntry("Interpolate",                            true));
     d->interpolateLimitInput->setTime(QTime::fromString(group->readEntry("Max Inter Dist Time", "00:15:00")));
-    d->directMatchLimitInput->setTime(QTime::fromString(group->readEntry("Max Gap Time", "00:00:30")));
-    d->timeZoneCB->setCurrentIndex(group->readEntry("Time Zone", 13));  // +00:00
-    d->offsetSign->setCurrentIndex(group->readEntry("Offset Sign", 0));
-    d->offsetTime->setTime(QTime::fromString(group->readEntry("Offset Time", "00:00:00")));
+    d->directMatchLimitInput->setTime(QTime::fromString(group->readEntry("Max Gap Time",        "00:00:30")));
+    d->timeZoneCB->setCurrentIndex(group->readEntry("Time Zone",                                13));  // +00:00
+    d->offsetSign->setCurrentIndex(group->readEntry("Offset Sign",                              0));
+    d->offsetTime->setTime(QTime::fromString(group->readEntry("Offset Time",                    "00:00:00")));
     d->gpxFileOpenLastDirectory = group->readEntry("GPX File Open Last Directory",
                                                    QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation));
 
@@ -575,7 +572,7 @@ void GPSCorrelatorWidget::slotCorrelationCanceled()
 
     delete d->correlationUndoCommand;
 
-    emit signalSetUIEnabled(true);
+    Q_EMIT signalSetUIEnabled(true);
 }
 
 QList<GeoCoordinates::List> GPSCorrelatorWidget::getTrackCoordinates() const
@@ -619,9 +616,11 @@ void GPSCorrelatorWidget::slotCurrentChanged(const QModelIndex& current, const Q
         if ((track.id != 0) && (track.points.size() > 0))
         {
             const GeoCoordinates& coordinates = track.points.at(0).coordinates;
-            emit signalTrackListChanged(coordinates);
+            Q_EMIT signalTrackListChanged(coordinates);
         }
     }
 }
 
 } // namespace Digikam
+
+#include "moc_gpscorrelatorwidget.cpp"
