@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_GPS_ITEM_LIST_DRAG_DROP_HANDLER_H
-#define DIGIKAM_GPS_ITEM_LIST_DRAG_DROP_HANDLER_H
+#pragma once
 
 // Qt includes
 
@@ -35,7 +34,7 @@ class DIGIKAM_EXPORT ItemListDragDropHandler : public QObject
 public:
 
     explicit ItemListDragDropHandler(QObject* const parent = nullptr);
-    ~ItemListDragDropHandler() override;
+    ~ItemListDragDropHandler() override = default;
 
     virtual QMimeData* createMimeData(const QList<QPersistentModelIndex>& modelIndices) = 0;
 };
@@ -49,11 +48,9 @@ class DIGIKAM_EXPORT GPSItemListDragDropHandler : public ItemListDragDropHandler
 public:
 
     explicit GPSItemListDragDropHandler(QObject* const parent = nullptr);
-    ~GPSItemListDragDropHandler() override;
+    ~GPSItemListDragDropHandler() override = default;
 
     QMimeData* createMimeData(const QList<QPersistentModelIndex>& modelIndices) override;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_GPS_ITEM_LIST_DRAG_DROP_HANDLER_H
