@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_ABSTRACT_MARKER_TILER_H
-#define DIGIKAM_ABSTRACT_MARKER_TILER_H
+#pragma once
 
 // Qt includes
 
@@ -52,6 +51,8 @@ public:
     {
     public:
 
+        ClickInfo() = default;
+
         TileIndex::List tileIndicesList;
         QVariant        representativeIndex;
         GeoGroupState   groupSelectionState;
@@ -64,7 +65,7 @@ public:
     {
     public:
 
-        explicit Tile();
+        Tile() = default;
         ~Tile();
 
     public:
@@ -132,7 +133,7 @@ public:
     private:
 
         class Private;
-        Private* const d;
+        Private* const d = nullptr;
     };
 
 public:
@@ -177,11 +178,9 @@ Q_SIGNALS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(Digikam::AbstractMarkerTiler::TilerFlags)
-
-#endif // DIGIKAM_ABSTRACT_MARKER_TILER_H
