@@ -13,8 +13,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_SAVING_CONTEXT_H
-#define DIGIKAM_SAVING_CONTEXT_H
+#pragma once
 
 // Qt includes
 
@@ -50,25 +49,16 @@ public:
 
 public:
 
-    explicit SavingContext()
-      : savingState            (SavingStateNone),
-        synchronizingState     (NormalSaving),
-        synchronousSavingResult(false),
-        destinationExisted     (false),
-        abortingSaving         (false),
-        executedOperation      (SavingStateNone),
-        saveTempFile           (nullptr)
-    {
-    }
+    SavingContext() = default;
 
 public:
 
-    SavingState          savingState;
-    SynchronizingState   synchronizingState;
-    bool                 synchronousSavingResult;
-    bool                 destinationExisted;
-    bool                 abortingSaving;
-    SavingState          executedOperation;
+    SavingState          savingState                = SavingStateNone;
+    SynchronizingState   synchronizingState         = NormalSaving;
+    bool                 synchronousSavingResult    = false;
+    bool                 destinationExisted         = false;
+    bool                 abortingSaving             = false;
+    SavingState          executedOperation          = SavingStateNone;
 
     QString              originalFormat;
     QString              format;
@@ -77,12 +67,10 @@ public:
     QUrl                 destinationURL;
     QUrl                 moveSrcURL;
 
-    SafeTemporaryFile*   saveTempFile;
+    SafeTemporaryFile*   saveTempFile               = nullptr;
     QString              saveTempFileName;
 
     VersionFileOperation versionFileOperation;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_SAVING_CONTEXT_H
