@@ -7,7 +7,7 @@
  * Description : digiKam image editor GUI
  *
  * SPDX-FileCopyrightText: 2004-2005 by Renchi Raju <renchi dot raju at gmail dot com>
- * SPDX-FileCopyrightText: 2004-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2004-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -41,6 +41,12 @@ ImageWindow::ImageWindow()
 {
     setXMLFile(QLatin1String("imageeditorui5.rc"));
 
+#if (KXMLGUI_VERSION >= QT_VERSION_CHECK(5, 88, 0))
+
+    setStateConfigGroup(configGroupName());
+
+#endif
+
     m_instance = this;
 
     // We don't want to be deleted on close
@@ -50,8 +56,8 @@ ImageWindow::ImageWindow()
 
     // -- Build the GUI -------------------------------
 
-    setupUserArea();
-    setupActions();
+    this->setupUserArea();
+    this->setupActions();
     setupStatusBar();
     createGUI(xmlFile());
     registerPluginsActions();
@@ -70,17 +76,24 @@ ImageWindow::ImageWindow()
 
     // Make signals/slots connections
 
-    setupConnections();
+    this->setupConnections();
 
     // -- Read settings --------------------------------
 
     readSettings();
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
     KConfigGroup group        = config->group(configGroupName());
+
     applyMainWindowSettings(group);
+
+    d->thumbBarDock->reInitialize();
     d->thumbBarDock->setShouldBeVisible(group.readEntry(d->configShowThumbbarEntry, false));
+
+    QByteArray thumbbarState;
+    thumbbarState = group.readEntry(QLatin1String("ThumbbarState"), thumbbarState);
+    d->viewContainer->restoreState(QByteArray::fromBase64(thumbbarState));
+
     setAutoSaveSettings(configGroupName(), true);
-    d->viewContainer->setAutoSaveSettings(QLatin1String("ImageViewer Thumbbar"), true);
 
     //-------------------------------------------------------------
 
@@ -129,7 +142,9 @@ void ImageWindow::closeEvent(QCloseEvent* e)
 
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
     KConfigGroup group        = config->group(configGroupName());
-    d->rightSideBar->setConfigGroup(KConfigGroup(&group, "Right Sidebar"));
+
+    group.writeEntry(QLatin1String("ThumbbarState"), d->viewContainer->saveState().toBase64());
+    d->rightSideBar->setConfigGroup(KConfigGroup(&group, QLatin1String("Right Sidebar")));
     d->rightSideBar->saveState();
     saveSettings();
 
@@ -726,7 +741,7 @@ void ImageWindow::saveFaceTagsToImage(const ItemInfo& info)
 
             // Start transform each face rect
 
-            qCDebug(DIGIKAM_GENERAL_LOG) << ">>>>>>>>>face rect before:"
+            qCDebug(DIGIKAM_GENERAL_LOG) << ">>>>>>>>> Face rect before:"
                                          << faceRect.x()     << faceRect.y()
                                          << faceRect.width() << faceRect.height();
 
@@ -737,26 +752,36 @@ void ImageWindow::saveFaceTagsToImage(const ItemInfo& info)
                 switch (type)
                 {
                     case EditorWindow::TransformType::RotateLeft:
+                    {
                         tempSize = TagRegion::adjustToOrientation(faceRect, MetaEngine::ORIENTATION_ROT_270, tempSize);
                         break;
+                    }
 
                     case EditorWindow::TransformType::RotateRight:
+                    {
                         tempSize = TagRegion::adjustToOrientation(faceRect, MetaEngine::ORIENTATION_ROT_90,  tempSize);
                         break;
+                    }
 
                     case EditorWindow::TransformType::FlipHorizontal:
+                    {
                         tempSize = TagRegion::adjustToOrientation(faceRect, MetaEngine::ORIENTATION_HFLIP,   tempSize);
                         break;
+                    }
 
                     case EditorWindow::TransformType::FlipVertical:
+                    {
                         tempSize = TagRegion::adjustToOrientation(faceRect, MetaEngine::ORIENTATION_VFLIP,   tempSize);
                         break;
+                    }
 
                     default:
+                    {
                         break;
+                    }
                 }
 
-                qCDebug(DIGIKAM_GENERAL_LOG) << ">>>>>>>>>face rect transform:"
+                qCDebug(DIGIKAM_GENERAL_LOG) << ">>>>>>>>> Face rect transform:"
                                              << faceRect.x()     << faceRect.y()
                                              << faceRect.width() << faceRect.height();
             }
@@ -1058,9 +1083,11 @@ void ImageWindow::dragMoveEvent(QDragMoveEvent* e)
     QList<qlonglong> imageIDs;
     QList<QUrl>      urls;
 
-    if (DItemDrag::decode(e->mimeData(), urls, albumIDs, imageIDs) ||
+    if (
+        DItemDrag::decode(e->mimeData(), urls, albumIDs, imageIDs) ||
         DAlbumDrag::decode(e->mimeData(), urls, albumID)           ||
-        DTagListDrag::canDecode(e->mimeData()))
+        DTagListDrag::canDecode(e->mimeData())
+       )
     {
         e->accept();
         return;
@@ -1329,29 +1356,39 @@ void ImageWindow::slotRightSideBarActivateAssignedTags()
 
 DInfoInterface* ImageWindow::infoIface(DPluginAction* const ac)
 {
-    ApplicationSettings::OperationType aset = ApplicationSettings::Unspecified;
+    OperationType aset = UnspecifiedOps;
 
     switch (ac->actionCategory())
     {
         case DPluginAction::GenericExport:
         case DPluginAction::GenericImport:
-            aset = ApplicationSettings::ImportExport;
+        {
+            aset = ImportExportOps;
             break;
+        }
 
         case DPluginAction::GenericMetadata:
-            aset = ApplicationSettings::Metadata;
+        {
+            aset = MetadataOps;
             break;
+        }
 
         case DPluginAction::GenericTool:
-            aset = ApplicationSettings::Tools;
+        {
+            aset = ToolsOps;
             break;
+        }
 
         case DPluginAction::GenericView:
-            aset = ApplicationSettings::Slideshow;
+        {
+            aset = SlideshowOps;
             break;
+        }
 
         default:
+        {
             break;
+        }
     }
 
     DBInfoIface* const iface = new DBInfoIface(this, d->thumbBar->allUrls(), aset);
@@ -1363,3 +1400,5 @@ DInfoInterface* ImageWindow::infoIface(DPluginAction* const ac)
 }
 
 } // namespace Digikam
+
+#include "moc_imagewindow.cpp"
