@@ -369,24 +369,29 @@ void CameraController::run()
         {
             QMutexLocker lock(&d->mutex);
 
-            if      (!d->commands.isEmpty())
+            if (!d->commands.isEmpty())
             {
                 command = d->commands.takeFirst();
                 Q_EMIT signalBusy(true);
             }
-            else if (!d->cmdThumbs.isEmpty())
-            {
-                command = d->cmdThumbs.takeFirst();
-                Q_EMIT signalBusy(false);
-            }
             else
             {
                 Q_EMIT signalBusy(false);
+            }
+
+            if (!command && !d->cmdThumbs.isEmpty())
+            {
+                command = d->cmdThumbs.takeFirst();
+            }
+
+            if (!command)
+            {
                 d->condVar.wait(&d->mutex);
                 continue;
             }
         }
 
+        // cppcheck-suppress knownConditionTrueFalse
         if (command)
         {
             executeCommand(command);
@@ -436,6 +441,7 @@ void CameraController::executeCommand(CameraCommand* const cmd)
             d->camera->cameraAbout(about);
 
             Q_EMIT signalCameraInformation(summary, manual, about);
+
             break;
         }
 
@@ -451,6 +457,7 @@ void CameraController::executeCommand(CameraCommand* const cmd)
             }
 
             Q_EMIT signalFreeSpace(bytesSize, bytesAvail);
+
             break;
         }
 
@@ -465,6 +472,7 @@ void CameraController::executeCommand(CameraCommand* const cmd)
             }
 
             Q_EMIT signalPreview(preview);
+
             break;
         }
 
@@ -479,6 +487,7 @@ void CameraController::executeCommand(CameraCommand* const cmd)
             }
 
             Q_EMIT signalUploaded(itemInfo);
+
             break;
         }
 
@@ -512,11 +521,12 @@ void CameraController::executeCommand(CameraCommand* const cmd)
 
             for (CamItemInfoList::iterator it = itemsList.begin() ; it != itemsList.end() ; )
             {
-                CamItemInfo &info = (*it);
+                const CamItemInfo& info = (*it);
 
                 if (info.mime.isEmpty())
                 {
                     it = itemsList.erase(it);
+
                     continue;
                 }
 
@@ -595,10 +605,16 @@ void CameraController::executeCommand(CameraCommand* const cmd)
             QString   templateTitle  = cmd->map[QLatin1String("template")].toString();
             bool      convertJpeg    = cmd->map[QLatin1String("convertJpeg")].toBool();
             QString   losslessFormat = cmd->map[QLatin1String("losslessFormat")].toString();
-            bool      backupRaw      = cmd->map[QLatin1String("backupRaw")].toBool();
+
+#ifdef HAVE_JXL
+
             bool      convertDng     = cmd->map[QLatin1String("convertDng")].toBool();
+            bool      backupRaw      = cmd->map[QLatin1String("backupRaw")].toBool();
             bool      compressDng    = cmd->map[QLatin1String("compressDng")].toBool();
             int       previewMode    = cmd->map[QLatin1String("previewMode")].toInt();
+
+#endif
+
             QString   script         = cmd->map[QLatin1String("script")].toString();
             int       pickLabel      = cmd->map[QLatin1String("pickLabel")].toInt();
             int       colorLabel     = cmd->map[QLatin1String("colorLabel")].toInt();
@@ -735,6 +751,9 @@ void CameraController::executeCommand(CameraCommand* const cmd)
                     }
                 }
             }
+
+#ifdef HAVE_JXL
+
             else if (convertDng && (mime == QLatin1String("image/x-raw")))
             {
                 qCDebug(DIGIKAM_IMPORTUI_LOG) << "Convert to DNG: " << file;
@@ -788,6 +807,7 @@ void CameraController::executeCommand(CameraCommand* const cmd)
                 }
             }
 
+#endif
             // Run script
 
             if (!script.isEmpty())
@@ -1046,6 +1066,7 @@ void CameraController::slotUploadFailed(const QString& folder, const QString& fi
 void CameraController::slotDeleteFailed(const QString& folder, const QString& file)
 {
     Q_EMIT signalDeleted(folder, file, false);
+
     sendLogMsg(xi18n("Failed to delete <filename>%1</filename>", file),
                DHistoryView::ErrorEntry, folder, file);
 
@@ -1266,10 +1287,16 @@ void CameraController::download(const DownloadSettings& downloadSettings)
     cmd->map.insert(QLatin1String("template"),          QVariant(downloadSettings.templateTitle));
     cmd->map.insert(QLatin1String("convertJpeg"),       QVariant(downloadSettings.convertJpeg));
     cmd->map.insert(QLatin1String("losslessFormat"),    QVariant(downloadSettings.losslessFormat));
-    cmd->map.insert(QLatin1String("backupRaw"),         QVariant(downloadSettings.backupRaw));
+
+#ifdef HAVE_JXL
+
     cmd->map.insert(QLatin1String("convertDng"),        QVariant(downloadSettings.convertDng));
+    cmd->map.insert(QLatin1String("backupRaw"),         QVariant(downloadSettings.backupRaw));
     cmd->map.insert(QLatin1String("compressDng"),       QVariant(downloadSettings.compressDng));
     cmd->map.insert(QLatin1String("previewMode"),       QVariant(downloadSettings.previewMode));
+
+#endif
+
     cmd->map.insert(QLatin1String("script"),            QVariant(downloadSettings.script));
     cmd->map.insert(QLatin1String("pickLabel"),         QVariant(downloadSettings.pickLabel));
     cmd->map.insert(QLatin1String("colorLabel"),        QVariant(downloadSettings.colorLabel));
