@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_SETUP_RAW_H
-#define DIGIKAM_SETUP_RAW_H
+#pragma once
 
 // Qt includes
 
@@ -49,9 +48,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_SETUP_RAW_H
