@@ -12,8 +12,7 @@
  *
  * ============================================================ */
 
-#ifndef DIGIKAM_SYSTEM_SETTINGS_WIDGET_H
-#define DIGIKAM_SYSTEM_SETTINGS_WIDGET_H
+#pragma once
 
 // Qt includes
 
@@ -47,9 +46,7 @@ private Q_SLOTS:
 private:
 
     class Private;
-    Private* const d;
+    Private* const d = nullptr;
 };
 
 } // namespace Digikam
-
-#endif // DIGIKAM_SYSTEM_SETTINGS_WIDGET_H
